@@ -22,7 +22,6 @@
  *
  */
 
-#include <hamlib/config.h>
 
 #include <stdio.h>
 
@@ -63,7 +62,7 @@ const struct amp_caps gemini_amp_caps =
     .mfg_name =     "Gemini",
     .version =      "20230318.0",
     .copyright =    "LGPL",
-    .status =     RIG_STATUS_BETA,
+    .status =     RIG_STATUS_STABLE,
     .amp_type =     AMP_TYPE_OTHER,
     .port_type =    RIG_PORT_NETWORK,
     .write_delay =    0,
@@ -105,7 +104,6 @@ const struct amp_caps gemini_amp_caps =
 
 static int gemini_send_priv_cmd(AMP *amp, const char *cmdstr)
 {
-    struct amp_state *rs;
     int err;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
@@ -115,8 +113,7 @@ static int gemini_send_priv_cmd(AMP *amp, const char *cmdstr)
         return -RIG_EINVAL;
     }
 
-    rs = &amp->state;
-    err = write_block(&rs->ampport, cmdstr, strlen(cmdstr));
+    err = write_block(AMPPORT(amp), cmdstr, strlen(cmdstr));
 
     if (err != RIG_OK)
     {
