@@ -64,7 +64,7 @@ void Rotator::close(void) {
 	CHECK_ROT( rot_close(theRot) );
 }
 
-void Rotator::setConf(token_t token, const char *val)
+void Rotator::setConf(hamlib_token_t token, const char *val)
 {
 	CHECK_ROT( rot_set_conf(theRot, token, val) );
 }
@@ -73,7 +73,7 @@ void Rotator::setConf(const char *name, const char *val)
 	CHECK_ROT( rot_set_conf(theRot, tokenLookup(name), val) );
 }
 
-void Rotator::getConf(token_t token, char *val)
+void Rotator::getConf(hamlib_token_t token, char *val)
 {
 	CHECK_ROT( rot_get_conf(theRot, token, val) );
 }
@@ -82,7 +82,7 @@ void Rotator::getConf(const char *name, char *val)
 	CHECK_ROT( rot_get_conf(theRot, tokenLookup(name), val) );
 }
 
-token_t Rotator::tokenLookup(const char *name)
+hamlib_token_t Rotator::tokenLookup(const char *name)
 {
 	return rot_token_lookup(theRot, name);
 }
