@@ -44,6 +44,99 @@
  */
 
 
+/*
+ * Generic bands -- eventually we should get rid of all the ITU regions -- not Hamlib's job and subject to change -- nobody in the mainstream uses these ranges anyways that we know of -- Mike W9MDB 20220531
+ */
+#if 0 // future use
+/* MF: 300 kHz - 3 MHz */
+#define FRQ_RNG_160m(md,lp,hp,v,a) \
+            { kHz(1800),MHz(2), (md), (lp), (hp), (v), (a), "Generic" }
+
+/* HF: 3 MHz - 30 MHz */
+#define FRQ_RNG_80m(md,lp,hp,v,a) \
+            { kHz(3500),MHz(4), (md), (lp), (hp), (v), (a), "Generic" }
+
+#define FRQ_RNG_60m(md,lp,hp,v,a) \
+            { kHz(5351.5),kHz(5366.5), (md), (lp), (hp), (v), (a), "Generic" }
+
+#define FRQ_RNG_40m(md,lp,hp,v,a) \
+            { MHz(7),kHz(7300), (md), (lp), (hp), (v), (a), "Generic" }
+
+#define FRQ_RNG_30m(md,lp,hp,v,a) \
+            { kHz(10100),kHz(10150), (md), (lp), (hp), (v), (a), "Generic" }
+
+#define FRQ_RNG_20m(md,lp,hp,v,a) \
+            { MHz(14),kHz(14350), (md), (lp), (hp), (v), (a), "Generic" }
+
+#define FRQ_RNG_17m(md,lp,hp,v,a) \
+            { kHz(18068),kHz(18168), (md), (lp), (hp), (v), (a), "Generic" }
+
+#define FRQ_RNG_15m(md,lp,hp,v,a) \
+            { MHz(21),kHz(21450), (md), (lp), (hp), (v), (a), "Generic" }
+
+#define FRQ_RNG_12m(md,lp,hp,v,a) \
+            { kHz(24890),kHz(24990), (md), (lp), (hp), (v), (a), "Generic" }
+
+#define FRQ_RNG_10m(md,lp,hp,v,a) \
+            { MHz(28),kHz(29700), (md), (lp), (hp), (v), (a), "Generic" }
+
+/* VHF: 30 MHz - 300 MHz */
+#define FRQ_RNG_6m(md,lp,hp,v,a) \
+            { MHz(50),MHz(54), (md), (lp), (hp), (v), (a), "Generic" }
+
+#define FRQ_RNG_4m(md,lp,hp,v,a) \
+            { MHz(70),MHz(70.5), (md), (lp), (hp), (v), (a), "Generic" }
+
+#define FRQ_RNG_2m(md,lp,hp,v,a) \
+            { MHz(144),MHz(148), (md), (lp), (hp), (v), (a), "Generic" }
+
+/* UHF: 300 MHz - 3 GHz */
+#define FRQ_RNG_70cm(md,lp,hp,v,a) \
+            { MHz(430),MHz(450), (md), (lp), (hp), (v), (a), "Generic" }
+
+#define FRQ_RNG_23cm(md,lp,hp,v,a) \
+            { MHz(1240),MHz(1300), (md), (lp), (hp), (v), (a), "Generic" }
+
+#define FRQ_RNG_13cm(md,lp,hp,v,a) \
+            { MHz(2320),MHz(2450), (md), (lp), (hp), (v), (a), "Generic" }
+
+#endif
+
+
+/* SHF: 3 GHz to 30GHz */
+#define FRQ_RNG_9cm(md,lp,hp,v,a) \
+            { MHz(3300),MHz(3500), (md), (lp), (hp), (v), (a), "Generic" }
+
+#define FRQ_RNG_6cm(md,lp,hp,v,a) \
+            { MHz(5650),MHz(5925), (md), (lp), (hp), (v), (a), "Generic" }
+
+#define FRQ_RNG_3cm(md,lp,hp,v,a) \
+            { MHz(10000),MHz(10500), (md), (lp), (hp), (v), (a), "Generic" }
+
+#define FRQ_RNG_1_2mm(md,lp,hp,v,a) \
+            { MHz(24000),MHz(24250), (md), (lp), (hp), (v), (a), "Generic" }
+
+/* EHF: 30 Ghz to 300 GHz */
+#define FRQ_RNG_6mm(md,lp,hp,v,a) \
+            { MHz(47000),MHz(47200), (md), (lp), (hp), (v), (a), "Generic" }
+
+#define FRQ_RNG_4mm(md,lp,hp,v,a) \
+            { MHz(75500),MHz(81000), (md), (lp), (hp), (v), (a), "Generic" }
+
+#define FRQ_RNG_2_5mm(md,lp,hp,v,a) \
+            { MHz(119980),MHz(123000), (md), (lp), (hp), (v), (a), "Generic" }
+
+#define FRQ_RNG_2mm(md,lp,hp,v,a) \
+            { MHz(134000),MHz(149000), (md), (lp), (hp), (v), (a), "Generic" }
+
+#define FRQ_RNG_1mm(md,lp,hp,v,a) \
+            { MHz(241000),MHz(250000), (md), (lp), (hp), (v), (a), "Generic" }
+
+/* THF: 0.3 THz to 3 THz */
+
+#define FRQ_RNG_THF(md,lp,hp,v,a) \
+            { GHz(300),GHz(3000), (md), (lp), (hp), (v), (a), "Generic" }
+
 /*
  * ITU Region 1: Europe, Africa and Northern Asia
  */
@@ -60,7 +153,7 @@
             { kHz(5351.5),kHz(5366.5), (md), (lp), (hp), (v), (a), "ITU1" }
 
 #define FRQ_RNG_40m_REGION1(md,lp,hp,v,a) \
-            { MHz(7),kHz(7100), (md), (lp), (hp), (v), (a), "ITU1" }
+            { MHz(7),kHz(7200), (md), (lp), (hp), (v), (a), "ITU1" }
 
 #define FRQ_RNG_30m_REGION1(md,lp,hp,v,a) \
             { kHz(10100),kHz(10150), (md), (lp), (hp), (v), (a), "ITU1" }
