@@ -1,5 +1,5 @@
 
-#include <config.h>
+#include <hamlib/config.h>
 
 #ifdef HAVE_WINDOWS_H
 #include <windows.h>
@@ -12,19 +12,21 @@
 #include <sys/time.h>
 #endif
 
-/* 
- * broken implementation for WIN32. 
+/*
+ * broken implementation for WIN32.
  * FIXME: usec precision
  */
 int gettimeofday(struct timeval *tv, struct timezone *tz)
 {
-	if (tv) {
-		time_t tm;
-		
-		time(&tm);
-		tv->tv_sec = tm;
-		tv->tv_usec = 0;
-	}
-	return 0;
+    if (tv)
+    {
+        time_t tm;
+
+        time(&tm);
+        tv->tv_sec = tm;
+        tv->tv_usec = 0;
+    }
+
+    return 0;
 }
 
