@@ -119,6 +119,29 @@ struct serial_icounter_struct {
 	int reserved[9]; 	/* unused */
 };
 
+struct termios_list
+{
+    char filename[512];
+    int my_errno;
+    int interrupt;
+    int event_flag;
+    int tx_happened;
+    unsigned long *hComm;
+    struct termios *ttyset;
+    struct serial_struct *sstruct;
+    /* for DTR DSR */
+    unsigned char MSR;
+    struct async_struct *astruct;
+    struct serial_icounter_struct *sis;
+    int open_flags;
+    OVERLAPPED rol;
+    OVERLAPPED wol;
+    OVERLAPPED sol;
+    int fd;
+    struct termios_list *next;
+    struct termios_list *prev;
+};
+
 int win32_serial_test( char * );
 int win32_serial_open(const char *File, int flags, ... );
 int win32_serial_close(int fd);
@@ -126,6 +149,7 @@ int win32_serial_read(int fd, void *b, int size);
 int win32_serial_write(int fd, const char *Str, int length);
 int win32_serial_ioctl(int fd, int request, ... );
 int win32_serial_fcntl(int fd, int command, ...);
+struct termios_list *win32_serial_find_port(int);
 /*
  * lcc winsock.h conflicts
  */
