@@ -5,7 +5,7 @@
 //  adat.c
 //
 //  Created by Frank Goenninger DG1SBG.
-//  Copyright © 2011, 2012 Frank Goenninger.
+//  Copyright © 2011, 2012, 2023 Frank Goenninger.
 //
 //   This library is free software; you can redistribute it and/or
 //   modify it under the terms of the GNU Lesser General Public
@@ -21,13 +21,10 @@
 //   License along with this library; if not, write to the Free Software
 //   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
-#include <hamlib/config.h>
-
 // ---------------------------------------------------------------------------
 //    SYSTEM INCLUDES
 // ---------------------------------------------------------------------------
 
-#include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
@@ -38,11 +35,10 @@
 // ---------------------------------------------------------------------------
 
 #include <hamlib/rig.h>
-#include "token.h"
 #include "serial.h"
 #include "misc.h"
 #include "register.h"
-#include "num_stdio.h"
+#include "riglist.h"
 
 // ---------------------------------------------------------------------------
 //    ADAT INCLUDES
@@ -54,19 +50,18 @@
 //    GLOBAL DEFINITIONS
 // ---------------------------------------------------------------------------
 
-#if !defined(NDEDBUG)
+#if !defined(NDEBUG)
 #  define ADAT_DEBUG 1
 #endif
 
-#undef ADAT_DEBUG // manual override ...
-
 // ---------------------------------------------------------------------------
 //    ADAT GLOBAL VARIABLES
 // ---------------------------------------------------------------------------
 
 // DEBUG STUFF
 
-static int gFnLevel = 0;
+static int              gFnLevel = 0;
+static adat_priv_data_t gsADATPrivData; // ADAT private state data
 
 // ADAT MODES
 
@@ -299,20 +294,6 @@ static adat_cmd_def_t adat_cmd_get_callsign =
     }
 };
 
-// -- ADAT SPECIAL: SET CALLSIGN --
-
-static adat_cmd_def_t adat_cmd_set_callsign =
-{
-    ADAT_CMD_DEF_ADAT_SPECIAL,
-    ADAT_CMD_KIND_WITHOUT_RESULT,
-    adat_cmd_fn_set_callsign,
-
-    1,
-    {
-        ADAT_CMD_DEF_STRING_SET_CALLSIGN
-    }
-};
-
 // -- HAMLIB DEFINED COMMANDS --
 
 // -- GET FREQ --
@@ -536,7 +517,7 @@ static adat_cmd_list_t adat_cmd_list_open_adat =
         &adat_cmd_get_gui_fw_version,
         &adat_cmd_get_hw_version,
         &adat_cmd_get_options,
-        &adat_cmd_set_callsign
+        &adat_cmd_get_callsign
     }
 };
 
@@ -1252,7 +1233,7 @@ int adat_send(RIG  *pRig,
               char *pcData)
 {
     int               nRC       = RIG_OK;
-    struct rig_state *pRigState = &pRig->state;
+    hamlib_port_t *pRigPort = RIGPORT(pRig);
 
     gFnLevel++;
 
@@ -1260,9 +1241,9 @@ int adat_send(RIG  *pRig,
               "*** ADAT: %d %s (%s:%d): ENTRY. Params: pRig = %p, pcData = %s\n",
               gFnLevel, __func__, __FILE__, __LINE__, pRig, pcData);
 
-    rig_flush(&pRigState->rigport);
+    rig_flush(pRigPort);
 
-    nRC = write_block(&pRigState->rigport, (unsigned char *) pcData,
+    nRC = write_block(pRigPort, (unsigned char *) pcData,
                       strlen(pcData));
 
     rig_debug(RIG_DEBUG_TRACE,
@@ -1283,7 +1264,6 @@ int adat_receive(RIG  *pRig,
                  char *pcData)
 {
     int               nRC       = RIG_OK;
-    struct rig_state *pRigState = &pRig->state;
 
     gFnLevel++;
 
@@ -1291,7 +1271,7 @@ int adat_receive(RIG  *pRig,
               "*** ADAT: %d %s (%s:%d): ENTRY. Params: pRig = %p\n",
               gFnLevel, __func__, __FILE__, __LINE__, pRig);
 
-    nRC = read_string(&pRigState->rigport, (unsigned char *) pcData, ADAT_RESPSZ,
+    nRC = read_string(RIGPORT(pRig), (unsigned char *) pcData, ADAT_RESPSZ,
                       ADAT_EOL, 1, 0, 1);
 
     if (nRC > 0)
@@ -1329,14 +1309,10 @@ int adat_priv_set_cmd(RIG *pRig, char *pcCmd, int nCmdKind)
     }
     else
     {
-        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) pRig->state.priv;
+        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) STATE(pRig)->priv;
 
-        if (pPriv->pcCmd != NULL)
-        {
-            free(pPriv->pcCmd);
-        }
-
-        pPriv->pcCmd    = strdup(pcCmd);
+        memset(pPriv->acCmd, 0, ADAT_PRIV_DATA_CMD_LENGTH + 1);
+        snprintf(pPriv->acCmd, ADAT_PRIV_DATA_CMD_LENGTH + 1, "%s", pcCmd);
         pPriv->nCmdKind = nCmdKind;
     }
 
@@ -1372,18 +1348,14 @@ int adat_priv_set_result(RIG *pRig, char *pcResult)
     }
     else
     {
-        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) pRig->state.priv;
+        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) STATE(pRig)->priv;
 
-        if (pPriv->pcResult != NULL)
-        {
-            free(pPriv->pcResult);
-        }
-
-        pPriv->pcResult = strdup(pcResult);
+        memset(pPriv->acResult, 0, ADAT_PRIV_DATA_RESULT_LENGTH + 1);
+        snprintf(pPriv->acResult, ADAT_PRIV_DATA_RESULT_LENGTH + 1, "%s", pcResult);
 
         rig_debug(RIG_DEBUG_TRACE,
-                  "*** ADAT: %d pPriv->pcResult = \"%s\"\n",
-                  gFnLevel, pPriv->pcResult);
+                  "*** ADAT: %d pPriv->acResult = \"%s\"\n",
+                  gFnLevel, pPriv->acResult);
     }
 
     // Done !
@@ -1418,14 +1390,8 @@ int adat_priv_clear_result(RIG *pRig)
     }
     else
     {
-        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) pRig->state.priv;
-
-        if (pPriv->pcResult != NULL)
-        {
-            free(pPriv->pcResult);
-        }
-
-        pPriv->pcResult = NULL;
+        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) STATE(pRig)->priv;
+        memset(pPriv->acResult, 0, ADAT_PRIV_DATA_RESULT_LENGTH + 1);
     }
 
     // Done !
@@ -1460,10 +1426,9 @@ int adat_get_single_cmd_result(RIG *pRig)
     }
     else
     {
-        adat_priv_data_ptr   pPriv     = (adat_priv_data_ptr) pRig->state.priv;
-        struct rig_state    *pRigState = &pRig->state;
+        adat_priv_data_ptr   pPriv     = (adat_priv_data_ptr) STATE(pRig)->priv;
 
-        nRC = adat_send(pRig, pPriv->pcCmd);
+        nRC = adat_send(pRig, pPriv->acCmd);
 
         if ((nRC == RIG_OK)
                 && (pPriv->nCmdKind == ADAT_CMD_KIND_WITH_RESULT))
@@ -1490,7 +1455,8 @@ int adat_get_single_cmd_result(RIG *pRig)
             {
                 int   nBufLength  = 0;
 
-                if (*pcPos == '\0') // Adjust for 00 byte at beginning ...
+// cppcheck-suppress knownConditionTrueFalse
+                if (*pcPos == 0) // Adjust for 00 byte at beginning ...
                 {
                     pcPos++;        // No, please don't ask me why this happens ... ;-)
                 }
@@ -1549,18 +1515,16 @@ int adat_get_single_cmd_result(RIG *pRig)
                     nRC = -RIG_EINVAL;
                 }
 
+                adat_priv_clear_result(pRig);
+
                 if (nRC == RIG_OK)
                 {
                     adat_priv_set_result(pRig, pcResult);
                 }
-                else
-                {
-                    adat_priv_clear_result(pRig);
-                }
             }
         }
 
-        rig_flush(&pRigState->rigport);
+        rig_flush(RIGPORT(pRig));
 
         pPriv->nRC = nRC;
     }
@@ -1597,7 +1561,7 @@ int adat_cmd_recover_from_error(RIG *pRig, int nError)
     }
     else
     {
-        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) pRig->state.priv;
+        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) STATE(pRig)->priv;
 
         // Recover from communication error
 
@@ -1653,7 +1617,7 @@ int adat_cmd_fn_get_callsign(RIG *pRig)
     }
     else
     {
-        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) pRig->state.priv;
+        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) STATE(pRig)->priv;
 
         nRC = adat_priv_set_cmd(pRig,
                                 ADAT_CMD_DEF_STRING_GET_CALLSIGN,
@@ -1665,11 +1629,13 @@ int adat_cmd_fn_get_callsign(RIG *pRig)
 
             if (nRC == RIG_OK)
             {
-                pPriv->pcCallsign = strdup(pPriv->pcResult);
+                memset(pPriv->acCallsign, 0, ADAT_PRIV_DATA_CALLSIGN_LENGTH + 1);
+                snprintf(pPriv->acCallsign, ADAT_PRIV_DATA_CALLSIGN_LENGTH + 1, "%s",
+                         pPriv->acResult);
 
                 rig_debug(RIG_DEBUG_TRACE,
-                          "*** ADAT: %d pPriv->pcCallsign = \"%s\"\n",
-                          gFnLevel, pPriv->pcCallsign);
+                          "*** ADAT: %d pPriv->acCallsign = \"%s\"\n",
+                          gFnLevel, pPriv->acCallsign);
             }
         }
     }
@@ -1685,55 +1651,6 @@ int adat_cmd_fn_get_callsign(RIG *pRig)
     return nRC;
 }
 
-
-// ---------------------------------------------------------------------------
-// adat_cmd_fn_set_callsign
-// ---------------------------------------------------------------------------
-// Status: IN WORK
-int adat_cmd_fn_set_callsign(RIG *pRig)
-{
-    int nRC = RIG_OK;
-
-    gFnLevel++;
-
-    rig_debug(RIG_DEBUG_TRACE,
-              "*** ADAT: %d %s (%s:%d): ENTRY. Params: pRig = %p\n",
-              gFnLevel, __func__, __FILE__, __LINE__, pRig);
-
-    if (pRig == NULL)
-    {
-        nRC = -RIG_EARG;
-    }
-    else
-    {
-        char acBuf[ ADAT_BUFSZ + 1 ];
-
-        memset(acBuf, 0, ADAT_BUFSZ + 1);
-
-        strcpy(acBuf, ADAT_CMD_DEF_STRING_SET_CALLSIGN);
-        strcat(acBuf, "DG1SBG"ADAT_CR);
-
-        nRC = adat_priv_set_cmd(pRig, acBuf,
-                                ADAT_CMD_KIND_WITHOUT_RESULT);
-
-        if (nRC == RIG_OK)
-        {
-            nRC = adat_get_single_cmd_result(pRig);
-        }
-    }
-
-    // Done !
-
-    rig_debug(RIG_DEBUG_TRACE,
-              "*** ADAT: %d %s (%s:%d): EXIT. Return Code = %d\n",
-              gFnLevel, __func__, __FILE__, __LINE__, nRC);
-
-    gFnLevel--;
-
-    return nRC;
-}
-
-
 // ---------------------------------------------------------------------------
 // adat_cmd_fn_get_serial_nr
 // ---------------------------------------------------------------------------
@@ -1754,7 +1671,7 @@ int adat_cmd_fn_get_serial_nr(RIG *pRig)
     }
     else
     {
-        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) pRig->state.priv;
+        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) STATE(pRig)->priv;
 
         nRC = adat_priv_set_cmd(pRig,
                                 ADAT_CMD_DEF_STRING_GET_SERIAL_NR,
@@ -1766,11 +1683,13 @@ int adat_cmd_fn_get_serial_nr(RIG *pRig)
 
             if (nRC == RIG_OK)
             {
-                pPriv->pcSerialNr = strdup(pPriv->pcResult);
+                memset(pPriv->acSerialNr, 0, ADAT_PRIV_DATA_SERIALNR_LENGTH + 1);
+                snprintf(pPriv->acSerialNr, ADAT_PRIV_DATA_SERIALNR_LENGTH + 1, "%s",
+                         pPriv->acResult);
 
                 rig_debug(RIG_DEBUG_TRACE,
-                          "*** ADAT: %d pPriv->pcSerialNr = \"%s\"\n",
-                          gFnLevel, pPriv->pcSerialNr);
+                          "*** ADAT: %d pPriv->acSerialNr = \"%s\"\n",
+                          gFnLevel, pPriv->acSerialNr);
             }
         }
     }
@@ -1806,7 +1725,7 @@ int adat_cmd_fn_get_fw_version(RIG *pRig)
     }
     else
     {
-        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) pRig->state.priv;
+        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) STATE(pRig)->priv;
 
         nRC = adat_priv_set_cmd(pRig,
                                 ADAT_CMD_DEF_STRING_GET_FW_VERSION,
@@ -1818,11 +1737,13 @@ int adat_cmd_fn_get_fw_version(RIG *pRig)
 
             if (nRC == RIG_OK)
             {
-                pPriv->pcFWVersion = strdup(pPriv->pcResult);
+                memset(pPriv->acFWVersion, 0, ADAT_PRIV_DATA_FWVERSION_LENGTH + 1);
+                snprintf(pPriv->acFWVersion, ADAT_PRIV_DATA_FWVERSION_LENGTH + 1, "%s",
+                         pPriv->acResult);
 
                 rig_debug(RIG_DEBUG_TRACE,
-                          "*** ADAT: %d pPriv->pcFWVersion = \"%s\"\n",
-                          gFnLevel, pPriv->pcFWVersion);
+                          "*** ADAT: %d pPriv->acFWVersion = \"%s\"\n",
+                          gFnLevel, pPriv->acFWVersion);
             }
         }
     }
@@ -1859,7 +1780,7 @@ int adat_cmd_fn_get_hw_version(RIG *pRig)
     }
     else
     {
-        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) pRig->state.priv;
+        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) STATE(pRig)->priv;
 
         nRC = adat_priv_set_cmd(pRig,
                                 ADAT_CMD_DEF_STRING_GET_HW_VERSION,
@@ -1871,11 +1792,13 @@ int adat_cmd_fn_get_hw_version(RIG *pRig)
 
             if (nRC == RIG_OK)
             {
-                pPriv->pcHWVersion = strdup(pPriv->pcResult);
+                memset(pPriv->acHWVersion, 0, ADAT_PRIV_DATA_HWVERSION_LENGTH + 1);
+                snprintf(pPriv->acHWVersion, ADAT_PRIV_DATA_HWVERSION_LENGTH + 1, "%s",
+                         pPriv->acResult);
 
                 rig_debug(RIG_DEBUG_TRACE,
-                          "*** ADAT: %d pPriv->pcHWVersion = \"%s\"\n",
-                          gFnLevel, pPriv->pcHWVersion);
+                          "*** ADAT: %d pPriv->acHWVersion = \"%s\"\n",
+                          gFnLevel, pPriv->acHWVersion);
             }
         }
     }
@@ -1911,7 +1834,7 @@ int adat_cmd_fn_get_gui_fw_version(RIG *pRig)
     }
     else
     {
-        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) pRig->state.priv;
+        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) STATE(pRig)->priv;
 
         nRC = adat_priv_set_cmd(pRig,
                                 ADAT_CMD_DEF_STRING_GET_GUI_FW_VERSION,
@@ -1923,11 +1846,13 @@ int adat_cmd_fn_get_gui_fw_version(RIG *pRig)
 
             if (nRC == RIG_OK)
             {
-                pPriv->pcGUIFWVersion = strdup(pPriv->pcResult);
+                memset(pPriv->acGUIFWVersion, 0, ADAT_PRIV_DATA_GUIFWVERSION_LENGTH + 1);
+                snprintf(pPriv->acGUIFWVersion, ADAT_PRIV_DATA_GUIFWVERSION_LENGTH + 1, "%s",
+                         pPriv->acResult);
 
                 rig_debug(RIG_DEBUG_TRACE,
-                          "*** ADAT: %d pPriv->pcGUIFWVersion = \"%s\"\n",
-                          gFnLevel, pPriv->pcGUIFWVersion);
+                          "*** ADAT: %d pPriv->acGUIFWVersion = \"%s\"\n",
+                          gFnLevel, pPriv->acGUIFWVersion);
             }
         }
     }
@@ -1964,7 +1889,7 @@ int adat_cmd_fn_get_id_code(RIG *pRig)
     }
     else
     {
-        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) pRig->state.priv;
+        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) STATE(pRig)->priv;
 
         nRC = adat_priv_set_cmd(pRig,
                                 ADAT_CMD_DEF_STRING_GET_ID_CODE,
@@ -1976,11 +1901,13 @@ int adat_cmd_fn_get_id_code(RIG *pRig)
 
             if (nRC == RIG_OK)
             {
-                pPriv->pcIDCode = strdup(pPriv->pcResult);
+                memset(pPriv->acIDCode, 0, ADAT_PRIV_DATA_IDCODE_LENGTH + 1);
+                snprintf(pPriv->acIDCode, ADAT_PRIV_DATA_IDCODE_LENGTH + 1, "%s",
+                         pPriv->acResult);
 
                 rig_debug(RIG_DEBUG_TRACE,
-                          "*** ADAT: %d pPriv->pcIDCode = \"%s\"\n",
-                          gFnLevel, pPriv->pcIDCode);
+                          "*** ADAT: %d pPriv->acIDCode = \"%s\"\n",
+                          gFnLevel, pPriv->acIDCode);
             }
         }
     }
@@ -2016,7 +1943,7 @@ int adat_cmd_fn_get_options(RIG *pRig)
     }
     else
     {
-        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) pRig->state.priv;
+        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) STATE(pRig)->priv;
 
         nRC = adat_priv_set_cmd(pRig,
                                 ADAT_CMD_DEF_STRING_GET_OPTIONS,
@@ -2028,11 +1955,13 @@ int adat_cmd_fn_get_options(RIG *pRig)
 
             if (nRC == RIG_OK)
             {
-                pPriv->pcOptions = strdup(pPriv->pcResult);
+                memset(pPriv->acOptions, 0, ADAT_PRIV_DATA_OPTIONS_LENGTH + 1);
+                snprintf(pPriv->acOptions, ADAT_PRIV_DATA_OPTIONS_LENGTH + 1, "%s",
+                         pPriv->acResult);
 
                 rig_debug(RIG_DEBUG_TRACE,
-                          "*** ADAT: %d pPriv->pcOptions = \"%s\"\n",
-                          gFnLevel, pPriv->pcOptions);
+                          "*** ADAT: %d pPriv->acOptions = \"%s\"\n",
+                          gFnLevel, pPriv->acOptions);
             }
         }
     }
@@ -2068,7 +1997,7 @@ int adat_cmd_fn_get_mode(RIG *pRig)
     }
     else
     {
-        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) pRig->state.priv;
+        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) STATE(pRig)->priv;
 
         nRC = adat_priv_set_cmd(pRig,
                                 ADAT_CMD_DEF_STRING_GET_MODE,
@@ -2080,7 +2009,7 @@ int adat_cmd_fn_get_mode(RIG *pRig)
 
             if (nRC == RIG_OK)
             {
-                nRC = adat_parse_mode(pPriv->pcResult,
+                nRC = adat_parse_mode(pPriv->acResult,
                                       &(pPriv->nRIGMode),
                                       pPriv->acADATMode);
             }
@@ -2118,7 +2047,7 @@ int adat_cmd_fn_set_mode(RIG *pRig)
     }
     else
     {
-        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) pRig->state.priv;
+        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) STATE(pRig)->priv;
 
         // Translate Mode from RIG Mode Nr to ADAT Mode Nr
 
@@ -2132,7 +2061,7 @@ int adat_cmd_fn_set_mode(RIG *pRig)
 
             memset(acBuf, 0, ADAT_BUFSZ + 1);
 
-            SNPRINTF(acBuf, sizeof(acBuf), "%s%02d%s",
+            snprintf(acBuf, sizeof(acBuf), "%s%02d%s",
                      ADAT_CMD_DEF_STRING_SET_MODE,
                      (int) pPriv->nADATMode,
                      ADAT_EOM);
@@ -2180,7 +2109,7 @@ int adat_cmd_fn_get_freq(RIG *pRig)
     }
     else
     {
-        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) pRig->state.priv;
+        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) STATE(pRig)->priv;
 
         nRC = adat_priv_set_cmd(pRig,
                                 ADAT_CMD_DEF_STRING_GET_FREQ,
@@ -2192,7 +2121,7 @@ int adat_cmd_fn_get_freq(RIG *pRig)
 
             if (nRC == RIG_OK)
             {
-                nRC = adat_parse_freq(pPriv->pcResult,
+                nRC = adat_parse_freq(pPriv->acResult,
                                       ADAT_FREQ_PARSE_MODE_WITH_VFO,
                                       &(pPriv->nCurrentVFO),
                                       &(pPriv->nFreq));
@@ -2241,14 +2170,15 @@ int adat_cmd_fn_set_freq(RIG *pRig)
     }
     else
     {
-        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) pRig->state.priv;
-        char               acBuf[ ADAT_BUFSZ + 1 ];
+        // cppcheck-suppress constVariablePointer
+        const adat_priv_data_ptr pPriv = (adat_priv_data_ptr) STATE(pRig)->priv;
+        char acBuf[ ADAT_BUFSZ + 1 ];
 
         // Get frequency of selected VFO
 
         memset(acBuf, 0, ADAT_BUFSZ + 1);
 
-        SNPRINTF(acBuf, sizeof(acBuf), "%s%d%s",
+        snprintf(acBuf, sizeof(acBuf), "%s%d%s",
                  ADAT_CMD_DEF_STRING_SET_FREQ,
                  (int) pPriv->nFreq,
                  ADAT_EOM);
@@ -2296,14 +2226,15 @@ int adat_cmd_fn_set_vfo(RIG *pRig)
     }
     else
     {
-        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) pRig->state.priv;
-        char               acBuf[ ADAT_BUFSZ + 1 ];
+        // cppcheck-suppress constVariablePointer
+        const adat_priv_data_ptr pPriv = (adat_priv_data_ptr) STATE(pRig)->priv;
+        char acBuf[ ADAT_BUFSZ + 1 ];
 
         // Switch on VFO
 
         memset(acBuf, 0, ADAT_BUFSZ + 1);
 
-        SNPRINTF(acBuf, ADAT_BUFSZ, ADAT_CMD_DEF_STRING_SWITCH_ON_VFO,
+        snprintf(acBuf, sizeof(acBuf), ADAT_CMD_DEF_STRING_SWITCH_ON_VFO,
                  (int) pPriv->nCurrentVFO,
                  ADAT_EOM);
 
@@ -2316,7 +2247,7 @@ int adat_cmd_fn_set_vfo(RIG *pRig)
             if (nRC == RIG_OK)
             {
                 memset(acBuf, 0, ADAT_BUFSZ + 1);
-                SNPRINTF(acBuf, ADAT_BUFSZ,
+                snprintf(acBuf, sizeof(acBuf),
                          ADAT_CMD_DEF_STRING_SET_VFO_AS_MAIN_VFO,
                          (int) pPriv->nCurrentVFO,
                          ADAT_EOM);
@@ -2363,7 +2294,7 @@ int adat_cmd_fn_get_ptt(RIG *pRig)
     }
     else
     {
-        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) pRig->state.priv;
+        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) STATE(pRig)->priv;
 
         nRC = adat_priv_set_cmd(pRig,
                                 ADAT_CMD_DEF_STRING_GET_PTT,
@@ -2375,7 +2306,7 @@ int adat_cmd_fn_get_ptt(RIG *pRig)
 
             if (nRC == RIG_OK)
             {
-                nRC = adat_parse_ptt(pPriv->pcResult,
+                nRC = adat_parse_ptt(pPriv->acResult,
                                      &(pPriv->nADATPTTStatus));
 
                 if (nRC == RIG_OK)
@@ -2418,11 +2349,8 @@ int adat_cmd_fn_set_ptt(RIG *pRig)
     }
     else
     {
-        adat_priv_data_ptr  pPriv    = (adat_priv_data_ptr) pRig->state.priv;
-        char                acBuf[ ADAT_BUFSZ + 1 ];
-        char               *pcPTTStr = NULL;
-
-        memset(acBuf, 0, ADAT_BUFSZ + 1);
+        adat_priv_data_ptr  pPriv    = (adat_priv_data_ptr) STATE(pRig)->priv;
+        char *pcPTTStr = NULL;
 
         // Switch PTT
 
@@ -2450,7 +2378,9 @@ int adat_cmd_fn_set_ptt(RIG *pRig)
 
         if (nRC == RIG_OK)
         {
-            SNPRINTF(acBuf, ADAT_BUFSZ, ADAT_CMD_DEF_STRING_SET_PTT,
+            char acBuf[ ADAT_BUFSZ + 1 ];
+            memset(acBuf, 0, ADAT_BUFSZ + 1);
+            snprintf(acBuf, sizeof(acBuf), ADAT_CMD_DEF_STRING_SET_PTT,
                      pcPTTStr,
                      ADAT_EOM);
 
@@ -2498,9 +2428,9 @@ int adat_transaction(RIG                *pRig,
     }
     else
     {
-        int                nI    = 0;
+        int nI    = 0;
         int nFini = 0;  // = 1 -> Stop executing commands
-        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) pRig->state.priv;
+        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) STATE(pRig)->priv;
 
         rig_debug(RIG_DEBUG_TRACE,
                   "*** ADAT: %d %s (%s:%d): Nr of commands = %d\n",
@@ -2508,9 +2438,7 @@ int adat_transaction(RIG                *pRig,
 
         while ((nRC == RIG_OK) && (nFini == 0) && (nI < pCmdList->nNrCmds))
         {
-            adat_cmd_def_ptr pCmd = NULL;
-
-            pCmd = pCmdList->adat_cmds[ nI ];
+            adat_cmd_def_ptr pCmd = pCmdList->adat_cmds[ nI ];
 
             if ((pCmd != NULL) && (pCmd->nCmdId != ADAT_CMD_DEF_NIL))
             {
@@ -2534,9 +2462,6 @@ int adat_transaction(RIG                *pRig,
                     rig_debug(RIG_DEBUG_TRACE,
                               "*** ADAT: %d Sending command string ... \n",
                               gFnLevel);
-// TODO: Quell clang warning of conditional always evaluating to true.
-//                    if( pCmd->pacCmdStrs != NULL )
-//                    {
 
                     if (pCmd->nNrCmdStrs > 0)
                     {
@@ -2570,20 +2495,14 @@ int adat_transaction(RIG                *pRig,
                                         nRC = adat_receive(pRig, acBuf);
                                     }
 
-                                    if (pPriv->pcResult != NULL)
-                                    {
-                                        free(pPriv->pcResult);
-                                    }
-
-                                    pPriv->pcResult = strdup(acBuf);
+                                    memset(pPriv->acResult, 0, ADAT_PRIV_DATA_RESULT_LENGTH + 1);
+                                    snprintf(pPriv->acResult, ADAT_PRIV_DATA_RESULT_LENGTH + 1, "%s", acBuf);
                                 }
                             }
 
                             nJ++;
                         }
                     }
-
-//                    }
                 }
 
                 if (nRC != RIG_OK)
@@ -2614,143 +2533,6 @@ int adat_transaction(RIG                *pRig,
     return nRC;
 }
 
-
-// ---------------------------------------------------------------------------
-// adat_new_priv_data
-// ---------------------------------------------------------------------------
-// Status: RELEASED
-adat_priv_data_ptr adat_new_priv_data(RIG *pRig)
-{
-    int                 nRC   = 0;
-    adat_priv_data_ptr  pPriv = NULL;
-
-    gFnLevel++;
-
-    rig_debug(RIG_DEBUG_TRACE,
-              "*** ADAT: %d %s (%s:%d): ENTRY. Params: pRig = %p\n",
-              gFnLevel, __func__, __FILE__, __LINE__, pRig);
-
-    if (pRig != NULL)
-    {
-        // Init Priv Data
-
-        pPriv = pRig->state.priv = (adat_priv_data_ptr) calloc(sizeof(adat_priv_data_t),
-                                   1);
-
-        if (pRig->state.priv != NULL)
-        {
-            char acBuf[ ADAT_BUFSZ + 1 ];
-            memset(acBuf, 0, ADAT_BUFSZ + 1);
-
-            // FIXME: pointless code at init time
-#if 0
-            nRC = adat_get_conf(pRig, TOKEN_ADAT_PRODUCT_NAME, acBuf);
-
-            if (nRC == 0)
-            {
-                pPriv->pcProductName = strdup(acBuf);
-
-                pRig->state.priv = (void *) pPriv;
-            }
-
-#endif
-        }
-        else
-        {
-            nRC = -RIG_ENOMEM;
-        }
-    }
-    else
-    {
-        nRC = -RIG_EARG;
-    }
-
-    rig_debug(RIG_DEBUG_TRACE,
-              "*** ADAT: %d %s (%s:%d): EXIT. RC = %d, pPriv = %p\n",
-              gFnLevel, __func__, __FILE__, __LINE__, nRC, pPriv);
-    gFnLevel--;
-
-    return pPriv;
-}
-
-
-// ---------------------------------------------------------------------------
-// adat_del_priv_data
-// ---------------------------------------------------------------------------
-// Status: RELEASED
-void adat_del_priv_data(adat_priv_data_t **ppPriv)
-{
-    int nRC = 0;
-
-    gFnLevel++;
-
-    rig_debug(RIG_DEBUG_TRACE,
-              "*** ADAT: %d %s (%s:%d): ENTRY. Params: ppPrivData = %p\n",
-              gFnLevel, __func__, __FILE__, __LINE__, ppPriv);
-
-    if ((ppPriv != NULL) && (*ppPriv != NULL))
-    {
-        // Delete / Free Priv Data
-
-        if ((*ppPriv)->pcProductName != NULL)
-        {
-            free((*ppPriv)->pcProductName);
-        }
-
-        if ((*ppPriv)->pcSerialNr != NULL)
-        {
-            free((*ppPriv)->pcSerialNr);
-        }
-
-        if ((*ppPriv)->pcHWVersion != NULL)
-        {
-            free((*ppPriv)->pcHWVersion);
-        }
-
-        if ((*ppPriv)->pcFWVersion != NULL)
-        {
-            free((*ppPriv)->pcFWVersion);
-        }
-
-        if ((*ppPriv)->pcGUIFWVersion != NULL)
-        {
-            free((*ppPriv)->pcGUIFWVersion);
-        }
-
-        if ((*ppPriv)->pcOptions != NULL)
-        {
-            free((*ppPriv)->pcOptions);
-        }
-
-        if ((*ppPriv)->pcIDCode != NULL)
-        {
-            free((*ppPriv)->pcIDCode);
-        }
-
-        if ((*ppPriv)->pcCallsign != NULL)
-        {
-            free((*ppPriv)->pcCallsign);
-        }
-
-        // Free priv struct itself
-
-        free((*ppPriv));
-        *ppPriv = NULL;
-    }
-    else
-    {
-        nRC = -RIG_EARG;
-    }
-
-    rig_debug(RIG_DEBUG_TRACE,
-              "*** ADAT: %d %s (%s:%d): EXIT. RC = %d.\n",
-              gFnLevel, __func__, __FILE__, __LINE__, nRC);
-    gFnLevel--;
-
-    return;
-}
-
-
 // ---------------------------------------------------------------------------
 // Function adat_init
 // ---------------------------------------------------------------------------
@@ -2765,20 +2547,12 @@ int adat_init(RIG *pRig)
               "*** ADAT: %d %s (%s:%d): ENTRY. Params: pRig = %p\n",
               gFnLevel, __func__, __FILE__, __LINE__, pRig);
 
-    // Check Params
-
     if (pRig != NULL)
     {
-        adat_priv_data_ptr pPriv = NULL;
+        // Set Rig Priv data
 
-        // Get new Priv Data
-
-        pPriv = adat_new_priv_data(pRig);
-
-        if (pPriv == NULL)
-        {
-            nRC = -RIG_ENOMEM;
-        }
+        memset(&gsADATPrivData, 0, sizeof(adat_priv_data_t));
+        STATE(pRig)->priv = &gsADATPrivData;
     }
 
     // Done !
@@ -2812,11 +2586,7 @@ int adat_cleanup(RIG *pRig)
     }
     else
     {
-        if (pRig->state.priv != NULL)
-        {
-            adat_del_priv_data((adat_priv_data_t **) & (pRig->state.priv));
-            pRig->state.priv = NULL;
-        }
+        STATE(pRig)->priv = NULL;
     }
 
     rig_debug(RIG_DEBUG_TRACE,
@@ -2877,19 +2647,13 @@ int adat_open(RIG *pRig)
 int adat_close(RIG *pRig)
 {
     int nRC = RIG_OK;
-    adat_priv_data_ptr pPriv = (adat_priv_data_ptr) pRig->state.priv;
-
-    if (pPriv->pcCmd != NULL) { free(pPriv->pcCmd); }
-
-    if (pPriv->pcResult != NULL) { free(pPriv->pcResult); }
 
     gFnLevel++;
-
     rig_debug(RIG_DEBUG_TRACE,
               "*** ADAT: %d %s (%s:%d): ENTRY. Params: pRig = %p\n",
               gFnLevel, __func__, __FILE__, __LINE__, pRig);
 
-    // Now switch to interactive mode
+    // Now switch to interactive mode (end Remote Operation mode)
 
     nRC = adat_transaction(pRig, &adat_cmd_list_close_adat);
 
@@ -2910,7 +2674,7 @@ int adat_close(RIG *pRig)
 // Status: RELEASED
 const char *adat_get_info(RIG *pRig)
 {
-    static char acBuf[ 512 ];
+    static char acBuf[ 2048 ];
 
     gFnLevel++;
 
@@ -2918,7 +2682,7 @@ const char *adat_get_info(RIG *pRig)
               "*** ADAT: %d %s (%s:%d): ENTRY. Params: pRig = %p\n",
               gFnLevel, __func__, __FILE__, __LINE__, pRig);
 
-    memset(acBuf, 0, 512);
+    memset(acBuf, 0, 2048);
 
     if (pRig != NULL)
     {
@@ -2926,17 +2690,18 @@ const char *adat_get_info(RIG *pRig)
 
         if (nRC == RIG_OK)
         {
-            adat_priv_data_ptr pPriv = (adat_priv_data_ptr) pRig->state.priv;
+            // cppcheck-suppress constVariablePointer
+            const adat_priv_data_ptr pPriv = (adat_priv_data_ptr) STATE(pRig)->priv;
 
-            SNPRINTF(acBuf, sizeof(acBuf),
+            snprintf(acBuf, 2048,
                      "ADAT ADT-200A, Callsign: %s, S/N: %s, ID Code: %s, Options: %s, FW: %s, GUI FW: %s, HW: %s",
-                     pPriv->pcCallsign,
-                     pPriv->pcSerialNr,
-                     pPriv->pcIDCode,
-                     pPriv->pcOptions,
-                     pPriv->pcFWVersion,
-                     pPriv->pcGUIFWVersion,
-                     pPriv->pcHWVersion);
+                     pPriv->acCallsign,
+                     pPriv->acSerialNr,
+                     pPriv->acIDCode,
+                     pPriv->acOptions,
+                     pPriv->acFWVersion,
+                     pPriv->acGUIFWVersion,
+                     pPriv->acHWVersion);
         }
     }
 
@@ -2971,7 +2736,7 @@ int adat_set_freq(RIG *pRig, vfo_t vfo, freq_t freq)
     }
     else
     {
-        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) pRig->state.priv;
+        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) STATE(pRig)->priv;
 
         pPriv->nFreq = freq;
 
@@ -3009,7 +2774,8 @@ int adat_get_freq(RIG *pRig, vfo_t vfo, freq_t *freq)
     }
     else
     {
-        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) pRig->state.priv;
+        // cppcheck-suppress constVariablePointer
+        const adat_priv_data_ptr pPriv = (adat_priv_data_ptr) STATE(pRig)->priv;
 
         nRC = adat_transaction(pRig, &adat_cmd_list_get_freq);
 
@@ -3047,7 +2813,7 @@ int adat_set_level(RIG *pRig, vfo_t vfo, setting_t level, value_t val)
     }
     else
     {
-        //adat_priv_data_ptr pPriv = (adat_priv_data_ptr) pRig->state.priv;
+        //adat_priv_data_ptr pPriv = (adat_priv_data_ptr) STATE(pRig)->priv;
 
     }
 
@@ -3082,7 +2848,7 @@ int adat_get_level(RIG *pRig, vfo_t vfo, setting_t level, value_t *val)
     }
     else
     {
-        //adat_priv_data_ptr pPriv = (adat_priv_data_ptr) pRig->state.priv;
+        //adat_priv_data_ptr pPriv = (adat_priv_data_ptr) STATE(pRig)->priv;
 
     }
 
@@ -3117,7 +2883,7 @@ int adat_set_mode(RIG *pRig, vfo_t vfo, rmode_t mode, pbwidth_t width)
     }
     else
     {
-        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) pRig->state.priv;
+        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) STATE(pRig)->priv;
 
         pPriv->nRIGMode    = mode;
         adat_vfo_rnr2anr(vfo, &(pPriv->nCurrentVFO));
@@ -3166,7 +2932,8 @@ int adat_get_mode(RIG *pRig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
     }
     else
     {
-        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) pRig->state.priv;
+        // cppcheck-suppress constVariablePointer
+        const adat_priv_data_ptr pPriv = (adat_priv_data_ptr) STATE(pRig)->priv;
 
         nRC =  adat_transaction(pRig, &adat_cmd_list_get_mode);
 
@@ -3208,7 +2975,8 @@ int adat_get_vfo(RIG *pRig, vfo_t *vfo)
     }
     else
     {
-        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) pRig->state.priv;
+        // cppcheck-suppress constVariablePointer
+        const adat_priv_data_ptr pPriv = (adat_priv_data_ptr) STATE(pRig)->priv;
 
         nRC = adat_transaction(pRig, &adat_cmd_list_get_vfo);
 
@@ -3246,7 +3014,7 @@ int adat_set_vfo(RIG *pRig, vfo_t vfo)
     }
     else
     {
-        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) pRig->state.priv;
+        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) STATE(pRig)->priv;
 
         nRC = adat_vfo_rnr2anr(vfo, &(pPriv->nCurrentVFO));
 
@@ -3287,7 +3055,8 @@ int adat_get_ptt(RIG *pRig, vfo_t vfo, ptt_t *ptt)
     }
     else
     {
-        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) pRig->state.priv;
+        // cppcheck-suppress constVariablePointer
+        const adat_priv_data_ptr pPriv = (adat_priv_data_ptr) STATE(pRig)->priv;
 
         nRC = adat_transaction(pRig, &adat_cmd_list_get_ptt);
 
@@ -3325,7 +3094,7 @@ int adat_set_ptt(RIG *pRig, vfo_t vfo, ptt_t ptt)
     }
     else
     {
-        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) pRig->state.priv;
+        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) STATE(pRig)->priv;
 
         switch (ptt)
         {
@@ -3455,8 +3224,6 @@ int adat_get_powerstat(RIG *pRig, powerstat_t *status)
     }
     else
     {
-        //adat_priv_data_ptr pPriv = (adat_priv_data_ptr) pRig->state.priv;
-
         nRC = adat_transaction(pRig, &adat_cmd_list_get_powerstatus);
 
         // nRC < 0 -> Power is off.
@@ -3485,7 +3252,7 @@ int adat_get_powerstat(RIG *pRig, powerstat_t *status)
 // Function adat_set_conf
 // ---------------------------------------------------------------------------
 // Status: IN WORK
-int adat_set_conf(RIG *pRig, token_t token, const char *val)
+int adat_set_conf(RIG *pRig, hamlib_token_t token, const char *val)
 {
     int nRC = RIG_OK;
 
@@ -3503,14 +3270,14 @@ int adat_set_conf(RIG *pRig, token_t token, const char *val)
     }
     else
     {
-        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) pRig->state.priv;
+        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) STATE(pRig)->priv;
 
         switch (token)
         {
         case TOKEN_ADAT_PRODUCT_NAME:
-            if (pPriv->pcProductName != NULL) { free(pPriv->pcProductName); }
 
-            pPriv->pcProductName = strdup(val);
+            snprintf(pPriv->acProductName, ADAT_PRIV_DATA_PRODUCTNAME_LENGTH + 1, "%s",
+                     val);
             break;
 
         default:
@@ -3531,7 +3298,7 @@ int adat_set_conf(RIG *pRig, token_t token, const char *val)
 // Function adat_get_conf
 // ---------------------------------------------------------------------------
 // Status: IN WORK
-int adat_get_conf(RIG *pRig, token_t token, char *val)
+int adat_get_conf(RIG *pRig, hamlib_token_t token, char *val)
 {
     int nRC = RIG_OK;
 
@@ -3549,13 +3316,21 @@ int adat_get_conf(RIG *pRig, token_t token, char *val)
     }
     else
     {
-        adat_priv_data_ptr pPriv = (adat_priv_data_ptr) pRig->state.priv;
+        // cppcheck-suppress constVariablePointer
+        const adat_priv_data_ptr pPriv = (adat_priv_data_ptr) STATE(pRig)->priv;
 
         switch (token)
         {
         case TOKEN_ADAT_PRODUCT_NAME:
-            strcpy(val, pPriv->pcProductName != NULL ? pPriv->pcProductName :
-                   "Unknown product");
+            if (strlen(pPriv->acProductName) > 0)
+            {
+                strcpy(val, pPriv->acProductName);
+            }
+            else
+            {
+                strcpy(val, "Unknown product");
+            }
+
             break;
 
         default:
@@ -3594,7 +3369,7 @@ int adat_reset(RIG *pRig, reset_t reset)
     }
     else
     {
-        //adat_priv_data_ptr pPriv = (adat_priv_data_ptr) pRig->state.priv;
+        //adat_priv_data_ptr pPriv = (adat_priv_data_ptr) STATE(pRig)->priv;
 
     }
 
@@ -3629,7 +3404,7 @@ int adat_handle_event(RIG *pRig)
     }
     else
     {
-        //adat_priv_data_ptr pPriv = (adat_priv_data_ptr) pRig->state.priv;
+        //adat_priv_data_ptr pPriv = (adat_priv_data_ptr) STATE(pRig)->priv;
         char               acBuf[ ADAT_RESPSZ + 1 ];
 
         memset(acBuf, 0, ADAT_RESPSZ + 1);
