@@ -19,16 +19,11 @@
  *
  */
 
-#include <hamlib/config.h>
-
 #include <stdio.h>
 #include <string.h>
 
 #include <hamlib/rig.h>
 #include <serial.h>
-#include <misc.h>
-
-#include "aor.h"
 
 static int ar3k_set_freq(RIG *rig, vfo_t vfo, freq_t freq);
 static int ar3k_get_freq(RIG *rig, vfo_t vfo, freq_t *freq);
@@ -67,7 +62,7 @@ static int ar3k_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val);
  * TODO:
  * set_channel, get_channel, set_func MUTE,SQL, get_dcd, ...
  */
-const struct rig_caps ar3000a_caps =
+struct rig_caps ar3000a_caps =
 {
     RIG_MODEL(RIG_MODEL_AR3000A),
     .model_name = "AR3000A",
@@ -181,7 +176,7 @@ const struct rig_caps ar3000a_caps =
 
 /*
  * ar3k_transaction
- * We assume that rig!=NULL, rig->state!= NULL
+ * We assume that rig!=NULL, RIGPORT(rig)!= NULL
  * Otherwise, you'll get a nice seg fault. You've been warned!
  * return value: RIG_OK if everything's fine, negative value otherwise
  * TODO: error case handling
@@ -190,13 +185,11 @@ static int ar3k_transaction(RIG *rig, const char *cmd, int cmd_len, char *data,
                             int *data_len)
 {
     int retval;
-    struct rig_state *rs;
+    hamlib_port_t *rp = RIGPORT(rig);
 
-    rs = &rig->state;
+    rig_flush(rp);
 
-    rig_flush(&rs->rigport);
-
-    retval = write_block(&rs->rigport, (unsigned char *) cmd, cmd_len);
+    retval = write_block(rp, (unsigned char *) cmd, cmd_len);
 
     if (retval != RIG_OK)
     {
@@ -209,7 +202,7 @@ static int ar3k_transaction(RIG *rig, const char *cmd, int cmd_len, char *data,
         return RIG_OK;
     }
 
-    retval = read_string(&rs->rigport, (unsigned char *) data, BUFSZ,
+    retval = read_string(rp, (unsigned char *) data, BUFSZ,
                          EOM, strlen(EOM), 0, 1);
 
     if (retval == -RIG_ETIMEOUT)
