@@ -42,9 +42,12 @@
 extern struct rig_caps dummy_caps;
 extern struct rig_caps dummy_no_vfo_caps;
 extern struct rig_caps netrigctl_caps;
-extern const struct rig_caps flrig_caps;
-extern const struct rig_caps trxmanager_caps;
-extern const struct rig_caps tci1x_caps;
+extern struct rig_caps flrig_caps;
+extern struct rig_caps trxmanager_caps;
+extern struct rig_caps tci1x_caps;
+extern struct rig_caps aclog_caps;
+extern struct rig_caps sdrsharp_caps;
+extern struct rig_caps quisk_caps;
 
 int netrigctl_get_vfo_mode(RIG *);
 
