@@ -19,17 +19,11 @@
  *
  */
 
-#include <hamlib/config.h>
-
 #include <stdlib.h>
 #include <string.h>  /* String function definitions */
-#include <errno.h>
 
 #include "hamlib/amplifier.h"
 #include "iofunc.h"
-#include "misc.h"
-
-#include "amp_dummy.h"
 
 #define CMD_MAX 32
 #define BUF_MAX 64
@@ -40,15 +34,16 @@
 static int netampctl_transaction(AMP *amp, char *cmd, int len, char *buf)
 {
     int ret;
+    hamlib_port_t *ampp = AMPPORT(amp);
 
-    ret = write_block(&amp->state.ampport, (unsigned char *) cmd, len);
+    ret = write_block(ampp, (unsigned char *) cmd, len);
 
     if (ret != RIG_OK)
     {
         return ret;
     }
 
-    ret = read_string(&amp->state.ampport, (unsigned char *) buf, BUF_MAX, "\n",
+    ret = read_string(ampp, (unsigned char *) buf, BUF_MAX, "\n",
                       sizeof("\n"), 0, 1);
 
     if (ret < 0)
@@ -67,7 +62,8 @@ static int netampctl_transaction(AMP *amp, char *cmd, int len, char *buf)
 static int netampctl_open(AMP *amp)
 {
     int ret;
-    //struct amp_state *rs = &amp->state;
+    //struct amp_state *rs = AMPSTATE(amp);
+    hamlib_port_t *ampp = AMPPORT(amp);
     int pamp_ver;
     char cmd[CMD_MAX];
     char buf[BUF_MAX];
@@ -92,9 +88,10 @@ static int netampctl_open(AMP *amp)
         return -RIG_EPROTO;
     }
 
-    ret = read_string(&amp->state.ampport, (unsigned char *) buf, BUF_MAX, "\n",
+    ret = read_string(ampp, (unsigned char *) buf, BUF_MAX, "\n",
                       sizeof("\n"), 0, 1);
 
+
     if (ret <= 0)
     {
         return (ret < 0) ? ret : -RIG_EPROTO;
@@ -102,7 +99,7 @@ static int netampctl_open(AMP *amp)
 
     do
     {
-        ret = read_string(&amp->state.ampport, (unsigned char *) buf, BUF_MAX, "\n",
+        ret = read_string(ampp, (unsigned char *) buf, BUF_MAX, "\n",
                           sizeof("\n"), 0, 1);
 
         if (ret > 0)
@@ -126,7 +123,7 @@ static int netampctl_close(AMP *amp)
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
     /* clean signoff, no read back */
-    write_block(&amp->state.ampport, (unsigned char *) "q\n", 2);
+    write_block(AMPPORT(amp), (unsigned char *) "q\n", 2);
 
     return RIG_OK;
 }
