@@ -19,8 +19,6 @@
  *
  */
 
-#include <hamlib/config.h>
-
 #include <stdlib.h>
 #include <string.h>  /* String function definitions */
 #include <math.h>
@@ -28,10 +26,13 @@
 
 #include "hamlib/rotator.h"
 #include "dummy_common.h"
+#include "rig.h"
 #include "register.h"
 #include "idx_builtin.h"
 
 #include "rot_dummy.h"
+#include "rot_pstrotator.h"
+#include "rotlist.h"
 
 #define DUMMY_ROT_FUNC 0
 #define DUMMY_ROT_LEVEL ROT_LEVEL_SPEED
@@ -120,15 +121,15 @@ static int dummy_rot_init(ROT *rot)
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
-    rot->state.priv = (struct dummy_rot_priv_data *)
-                      calloc(1, sizeof(struct dummy_rot_priv_data));
+    ROTSTATE(rot)->priv = (struct dummy_rot_priv_data *)
+                          calloc(1, sizeof(struct dummy_rot_priv_data));
 
-    if (!rot->state.priv)
+    if (!ROTSTATE(rot)->priv)
     {
         return -RIG_ENOMEM;
     }
 
-    priv = rot->state.priv;
+    priv = ROTSTATE(rot)->priv;
 
     priv->ext_funcs = alloc_init_ext(dummy_ext_funcs);
 
@@ -151,7 +152,7 @@ static int dummy_rot_init(ROT *rot)
         return -RIG_ENOMEM;
     }
 
-    rot->state.rotport.type.rig = RIG_PORT_NONE;
+    ROTPORT(rot)->type.rig = RIG_PORT_NONE;
 
     priv->az = priv->el = 0;
 
@@ -165,7 +166,7 @@ static int dummy_rot_init(ROT *rot)
 static int dummy_rot_cleanup(ROT *rot)
 {
     struct dummy_rot_priv_data *priv = (struct dummy_rot_priv_data *)
-                                       rot->state.priv;
+                                       ROTSTATE(rot)->priv;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
@@ -173,13 +174,9 @@ static int dummy_rot_cleanup(ROT *rot)
     free(priv->ext_levels);
     free(priv->ext_parms);
     free(priv->magic_conf);
+    free(ROTSTATE(rot)->priv);
 
-    if (rot->state.priv)
-    {
-        free(rot->state.priv);
-    }
-
-    rot->state.priv = NULL;
+    ROTSTATE(rot)->priv = NULL;
 
     return RIG_OK;
 }
@@ -205,11 +202,11 @@ static int dummy_rot_close(ROT *rot)
     return RIG_OK;
 }
 
-static int dummy_set_conf(ROT *rot, token_t token, const char *val)
+static int dummy_set_conf(ROT *rot, hamlib_token_t token, const char *val)
 {
     struct dummy_rot_priv_data *priv;
 
-    priv = (struct dummy_rot_priv_data *)rot->state.priv;
+    priv = (struct dummy_rot_priv_data *)ROTSTATE(rot)->priv;
 
     switch (token)
     {
@@ -230,11 +227,12 @@ static int dummy_set_conf(ROT *rot, token_t token, const char *val)
 }
 
 
-static int dummy_get_conf2(ROT *rot, token_t token, char *val, int val_len)
+static int dummy_get_conf2(ROT *rot, hamlib_token_t token, char *val,
+                           int val_len)
 {
     struct dummy_rot_priv_data *priv;
 
-    priv = (struct dummy_rot_priv_data *)rot->state.priv;
+    priv = (struct dummy_rot_priv_data *)ROTSTATE(rot)->priv;
 
     switch (token)
     {
@@ -249,7 +247,7 @@ static int dummy_get_conf2(ROT *rot, token_t token, char *val, int val_len)
     return RIG_OK;
 }
 
-static int dummy_get_conf(ROT *rot, token_t token, char *val)
+static int dummy_get_conf(ROT *rot, hamlib_token_t token, char *val)
 {
     return dummy_get_conf2(rot, token, val, 128);
 }
@@ -259,7 +257,7 @@ static int dummy_get_conf(ROT *rot, token_t token, char *val)
 static int dummy_rot_set_position(ROT *rot, azimuth_t az, elevation_t el)
 {
     struct dummy_rot_priv_data *priv = (struct dummy_rot_priv_data *)
-                                       rot->state.priv;
+                                       ROTSTATE(rot)->priv;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called: %.2f %.2f\n", __func__,
               az, el);
@@ -283,7 +281,7 @@ static int dummy_rot_set_position(ROT *rot, azimuth_t az, elevation_t el)
 static void dummy_rot_simulate_rotation(ROT *rot)
 {
     struct dummy_rot_priv_data *priv = (struct dummy_rot_priv_data *)
-                                       rot->state.priv;
+                                       ROTSTATE(rot)->priv;
     struct timeval tv;
     unsigned elapsed; /* ms */
 
@@ -357,8 +355,8 @@ static void dummy_rot_simulate_rotation(ROT *rot)
  */
 static int dummy_rot_get_position(ROT *rot, azimuth_t *az, elevation_t *el)
 {
-    struct dummy_rot_priv_data *priv = (struct dummy_rot_priv_data *)
-                                       rot->state.priv;
+    const struct dummy_rot_priv_data *priv = (struct dummy_rot_priv_data *)
+            ROTSTATE(rot)->priv;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
@@ -385,7 +383,7 @@ static int dummy_rot_get_position(ROT *rot, azimuth_t *az, elevation_t *el)
 static int dummy_rot_stop(ROT *rot)
 {
     struct dummy_rot_priv_data *priv = (struct dummy_rot_priv_data *)
-                                       rot->state.priv;
+                                       ROTSTATE(rot)->priv;
     azimuth_t az;
     elevation_t el;
 
@@ -419,8 +417,8 @@ static int dummy_rot_reset(ROT *rot, rot_reset_t reset)
 
 static int dummy_rot_move(ROT *rot, int direction, int speed)
 {
-    struct dummy_rot_priv_data *priv = (struct dummy_rot_priv_data *)
-                                       rot->state.priv;
+    const struct dummy_rot_priv_data *priv = (struct dummy_rot_priv_data *)
+            ROTSTATE(rot)->priv;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
     rig_debug(RIG_DEBUG_TRACE, "%s: Direction = %d, Speed = %d\n", __func__,
@@ -440,6 +438,22 @@ static int dummy_rot_move(ROT *rot, int direction, int speed)
     case ROT_MOVE_CW:
         return dummy_rot_set_position(rot, 180, priv->target_el);
 
+    case ROT_MOVE_UP_LEFT:
+        dummy_rot_set_position(rot, priv->target_az, 90);
+        return dummy_rot_set_position(rot, -180, priv->target_el);
+
+    case ROT_MOVE_UP_RIGHT:
+        dummy_rot_set_position(rot, priv->target_az, 90);
+        return dummy_rot_set_position(rot, 180, priv->target_el);
+
+    case ROT_MOVE_DOWN_LEFT:
+        dummy_rot_set_position(rot, priv->target_az, 0);
+        return dummy_rot_set_position(rot, -180, priv->target_el);
+
+    case ROT_MOVE_DOWN_RIGHT:
+        dummy_rot_set_position(rot, priv->target_az, 0);
+        return dummy_rot_set_position(rot, 180, priv->target_el);
+
     default:
         return -RIG_EINVAL;
     }
@@ -457,7 +471,7 @@ static const char *dummy_rot_get_info(ROT *rot)
 static int dummy_set_func(ROT *rot, setting_t func, int status)
 {
     struct dummy_rot_priv_data *priv = (struct dummy_rot_priv_data *)
-                                       rot->state.priv;
+                                       ROTSTATE(rot)->priv;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called: %s %d\n", __func__,
               rot_strfunc(func), status);
@@ -477,8 +491,8 @@ static int dummy_set_func(ROT *rot, setting_t func, int status)
 
 static int dummy_get_func(ROT *rot, setting_t func, int *status)
 {
-    struct dummy_rot_priv_data *priv = (struct dummy_rot_priv_data *)
-                                       rot->state.priv;
+    const struct dummy_rot_priv_data *priv = (struct dummy_rot_priv_data *)
+            ROTSTATE(rot)->priv;
 
     *status = (priv->funcs & func) ? 1 : 0;
 
@@ -492,7 +506,7 @@ static int dummy_get_func(ROT *rot, setting_t func, int *status)
 static int dummy_set_level(ROT *rot, setting_t level, value_t val)
 {
     struct dummy_rot_priv_data *priv = (struct dummy_rot_priv_data *)
-                                       rot->state.priv;
+                                       ROTSTATE(rot)->priv;
     int idx;
     char lstr[32];
 
@@ -524,7 +538,7 @@ static int dummy_set_level(ROT *rot, setting_t level, value_t val)
 static int dummy_get_level(ROT *rot, setting_t level, value_t *val)
 {
     struct dummy_rot_priv_data *priv = (struct dummy_rot_priv_data *)
-                                       rot->state.priv;
+                                       ROTSTATE(rot)->priv;
     int idx;
 
     idx = rig_setting2idx(level);
@@ -542,10 +556,10 @@ static int dummy_get_level(ROT *rot, setting_t level, value_t *val)
     return RIG_OK;
 }
 
-static int dummy_set_ext_level(ROT *rot, token_t token, value_t val)
+static int dummy_set_ext_level(ROT *rot, hamlib_token_t token, value_t val)
 {
     struct dummy_rot_priv_data *priv = (struct dummy_rot_priv_data *)
-                                       rot->state.priv;
+                                       ROTSTATE(rot)->priv;
     char lstr[64];
     const struct confparams *cfp;
     struct ext_list *elp;
@@ -611,10 +625,10 @@ static int dummy_set_ext_level(ROT *rot, token_t token, value_t val)
     return RIG_OK;
 }
 
-static int dummy_get_ext_level(ROT *rot, token_t token, value_t *val)
+static int dummy_get_ext_level(ROT *rot, hamlib_token_t token, value_t *val)
 {
     struct dummy_rot_priv_data *priv = (struct dummy_rot_priv_data *)
-                                       rot->state.priv;
+                                       ROTSTATE(rot)->priv;
     const struct confparams *cfp;
     struct ext_list *elp;
 
@@ -654,10 +668,10 @@ static int dummy_get_ext_level(ROT *rot, token_t token, value_t *val)
 }
 
 
-static int dummy_set_ext_func(ROT *rot, token_t token, int status)
+static int dummy_set_ext_func(ROT *rot, hamlib_token_t token, int status)
 {
     struct dummy_rot_priv_data *priv = (struct dummy_rot_priv_data *)
-                                       rot->state.priv;
+                                       ROTSTATE(rot)->priv;
     const struct confparams *cfp;
     struct ext_list *elp;
 
@@ -706,10 +720,10 @@ static int dummy_set_ext_func(ROT *rot, token_t token, int status)
 }
 
 
-static int dummy_get_ext_func(ROT *rot, token_t token, int *status)
+static int dummy_get_ext_func(ROT *rot, hamlib_token_t token, int *status)
 {
     struct dummy_rot_priv_data *priv = (struct dummy_rot_priv_data *)
-                                       rot->state.priv;
+                                       ROTSTATE(rot)->priv;
     const struct confparams *cfp;
     struct ext_list *elp;
 
@@ -749,7 +763,7 @@ static int dummy_get_ext_func(ROT *rot, token_t token, int *status)
 static int dummy_set_parm(ROT *rot, setting_t parm, value_t val)
 {
     struct dummy_rot_priv_data *priv = (struct dummy_rot_priv_data *)
-                                       rot->state.priv;
+                                       ROTSTATE(rot)->priv;
     int idx;
     char pstr[32];
 
@@ -781,7 +795,7 @@ static int dummy_set_parm(ROT *rot, setting_t parm, value_t val)
 static int dummy_get_parm(ROT *rot, setting_t parm, value_t *val)
 {
     struct dummy_rot_priv_data *priv = (struct dummy_rot_priv_data *)
-                                       rot->state.priv;
+                                       ROTSTATE(rot)->priv;
     int idx;
 
     idx = rig_setting2idx(parm);
@@ -799,10 +813,10 @@ static int dummy_get_parm(ROT *rot, setting_t parm, value_t *val)
     return RIG_OK;
 }
 
-static int dummy_set_ext_parm(ROT *rot, token_t token, value_t val)
+static int dummy_set_ext_parm(ROT *rot, hamlib_token_t token, value_t val)
 {
     struct dummy_rot_priv_data *priv = (struct dummy_rot_priv_data *)
-                                       rot->state.priv;
+                                       ROTSTATE(rot)->priv;
     char lstr[64];
     const struct confparams *cfp;
     struct ext_list *epp;
@@ -865,10 +879,10 @@ static int dummy_set_ext_parm(ROT *rot, token_t token, value_t val)
     return RIG_OK;
 }
 
-static int dummy_get_ext_parm(ROT *rot, token_t token, value_t *val)
+static int dummy_get_ext_parm(ROT *rot, hamlib_token_t token, value_t *val)
 {
     struct dummy_rot_priv_data *priv = (struct dummy_rot_priv_data *)
-                                       rot->state.priv;
+                                       ROTSTATE(rot)->priv;
     const struct confparams *cfp;
     struct ext_list *epp;
 
@@ -907,8 +921,8 @@ static int dummy_get_ext_parm(ROT *rot, token_t token, value_t *val)
 
 static int dummy_rot_get_status(ROT *rot, rot_status_t *status)
 {
-    struct dummy_rot_priv_data *priv = (struct dummy_rot_priv_data *)
-                                       rot->state.priv;
+    const struct dummy_rot_priv_data *priv = (struct dummy_rot_priv_data *)
+            ROTSTATE(rot)->priv;
 
     if (simulating)
     {
@@ -997,6 +1011,8 @@ DECLARE_INITROT_BACKEND(dummy)
 
     rot_register(&dummy_rot_caps);
     rot_register(&netrotctl_caps);
+    rot_register(&pstrotator_caps);
+    rot_register(&satrotctl_caps);
 
     return RIG_OK;
 }
