@@ -19,8 +19,6 @@
  *
  */
 
-#include <hamlib/config.h>
-
 #include <stdlib.h>
 
 #include "hamlib/rig.h"
@@ -51,14 +49,14 @@ static const struct icom_priv_caps ic271_priv_caps =
     ic737_ts_sc_list
 };
 
-const struct rig_caps ic271_caps =
+struct rig_caps ic271_caps =
 {
     RIG_MODEL(RIG_MODEL_IC271),
     .model_name = "IC-271",
     .mfg_name =  "Icom",
     .version =  BACKEND_VER ".0",
     .copyright =  "LGPL",
-    .status =  RIG_STATUS_ALPHA,
+    .status =  RIG_STATUS_BETA,
     .rig_type =  RIG_TYPE_TRANSCEIVER,
     .ptt_type =  RIG_PTT_NONE,
     .dcd_type =  RIG_DCD_NONE,
@@ -119,7 +117,7 @@ const struct rig_caps ic271_caps =
     },
 
     .tuning_steps =     {
-        {IC271_MODES, 10}, /* TBC: does this rig supports settin tuning step? */
+        {IC271_MODES, 10}, /* TBC: does this rig supports setting tuning step? */
         RIG_TS_END,
     },
     /* mode/filter list, remember: order matters! */
