@@ -20,8 +20,6 @@
  *
  */
 
-#include <hamlib/config.h>
-
 #include <stdlib.h>
 
 #include "hamlib/rig.h"
@@ -74,7 +72,7 @@ static const struct icom_priv_caps IC718_priv_caps =
     ic718_ts_sc_list
 };
 
-const struct rig_caps ic718_caps =
+struct rig_caps ic718_caps =
 {
     RIG_MODEL(RIG_MODEL_IC718),
     .model_name = "IC-718",
@@ -105,8 +103,6 @@ const struct rig_caps ic718_caps =
     .level_gran =
     {
 #include "level_gran_icom.h"
-        // cppcheck-suppress *
-        [LVL_RAWSTR] = { .min = { .i = 0 }, .max = { .i = 255 } },
     },
     .parm_gran =  {},
     .str_cal = IC718_STR_CAL,
@@ -186,7 +182,7 @@ const struct rig_caps ic718_caps =
     .set_mode =  icom_set_mode,
     .get_mode =  icom_get_mode,
     .set_vfo =  icom_set_vfo,
-    .get_vfo =  icom_get_vfo,
+//    .get_vfo =  icom_get_vfo,
 
     .decode_event =  icom_decode_event,
     .set_level =  icom_set_level,
