@@ -23,15 +23,15 @@
 #define _KACHINA_H 1
 
 #include <hamlib/rig.h>
-#include <tones.h>
 
-#define BACKEND_VER "20061007"
+#define BACKEND_VER "20240420"
 
 int kachina_set_freq(RIG *rig, vfo_t vfo, freq_t freq);
 int kachina_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width);
+int kachina_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt);
 int kachina_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val);
 
-extern const struct rig_caps k505dsp_caps;
+extern struct rig_caps k505dsp_caps;
 
 
 #endif /* _KACHINA_H */
