@@ -24,11 +24,12 @@
  */
 
 #include <string.h>
-#include <stdlib.h>
+#include <stdio.h>
 
 #include "serial.h"
 #include "elecraft.h"
 #include "kenwood.h"
+#include "misc.h"
 
 
 static const struct elec_ext_id_str elec_ext_id_str_lst[] =
@@ -95,13 +96,21 @@ int elecraft_open(RIG *rig)
 {
     int err;
     char buf[KENWOOD_MAX_BUF_LEN];
-    struct kenwood_priv_data *priv = rig->state.priv;
     char *model = "Unknown";
-
+    struct rig_state *rs = STATE(rig);
+    struct hamlib_port *rp = RIGPORT(rig);
+    struct kenwood_priv_data *priv = rs->priv;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called, rig version=%s\n", __func__,
               rig->caps->version);
 
+    if (rs->auto_power_on && priv->poweron == 0)
+    {
+        rig_set_powerstat(rig, 1);
+        priv->poweron = 1;
+    }
+
+
     /* Actual read extension levels from radio.
      *
      * The value stored in the k?_ext_lvl variables map to
@@ -121,13 +130,12 @@ int elecraft_open(RIG *rig)
 
     if (rig->caps->rig_model == RIG_MODEL_XG3)   // XG3 doesn't have ID
     {
-        struct rig_state *rs = &rig->state;
         char *cmd = "V;";
         char data[32];
 
         strcpy(data, "EMPTY");
         // Not going to get carried away with retries and such
-        err = write_block(&rs->rigport, (unsigned char *) cmd, strlen(cmd));
+        err = write_block(rp, (unsigned char *) cmd, strlen(cmd));
 
         if (err != RIG_OK)
         {
@@ -135,7 +143,7 @@ int elecraft_open(RIG *rig)
             return err;
         }
 
-        err = read_string(&rs->rigport, (unsigned char *) buf, sizeof(buf),
+        err = read_string(rp, (unsigned char *) buf, sizeof(buf),
                           ";", 1, 0, 1);
 
         if (err < 0)
@@ -165,8 +173,19 @@ int elecraft_open(RIG *rig)
         }
     }
 
+    priv->save_k2_ext_lvl = -1; // so we don't restore if not neeede
+
     if (rig->caps->rig_model != RIG_MODEL_XG3)   // XG3 doesn't have extended
     {
+        err = elecraft_get_extension_level(rig, "K2", &priv->save_k2_ext_lvl);
+
+        if (err != RIG_OK)
+        {
+            rig_debug(RIG_DEBUG_ERR, "%s: error getting K2 ext_lvl: %s\n", __func__,
+                      rigerror(err));
+            return err;
+        }
+
         // turn on k2 extended to get PC values in more resolution
         err = kenwood_transaction(rig, "K22;", NULL, 0);
 
@@ -299,9 +318,45 @@ int elecraft_open(RIG *rig)
 
         if (err != RIG_OK)
         {
+            rig_debug(RIG_DEBUG_ERR, "%s: Firmware RVM failed\n", __func__);
             return err;
         }
 
+        err = elecraft_get_firmware_revision_level(rig, "RVD", priv->fw_rev,
+                (sizeof(k3_fw_rev) / sizeof(k3_fw_rev[0])));
+
+        if (err != RIG_OK)
+        {
+            rig_debug(RIG_DEBUG_ERR, "%s: Firmware RVD failed\n", __func__);
+        }
+
+        if (priv->is_k3)
+        {
+            err = elecraft_get_firmware_revision_level(rig, "RVA", priv->fw_rev,
+                    (sizeof(k3_fw_rev) / sizeof(k3_fw_rev[0])));
+
+            if (err != RIG_OK)
+            {
+                rig_debug(RIG_DEBUG_ERR, "%s: Firmware RVA failed\n", __func__);
+            }
+
+            err = elecraft_get_firmware_revision_level(rig, "RVR", priv->fw_rev,
+                    (sizeof(k3_fw_rev) / sizeof(k3_fw_rev[0])));
+
+            if (err != RIG_OK)
+            {
+                rig_debug(RIG_DEBUG_ERR, "%s: Firmware RVR failed\n", __func__);
+            }
+
+            err = elecraft_get_firmware_revision_level(rig, "RVF", priv->fw_rev,
+                    (sizeof(k3_fw_rev) / sizeof(k3_fw_rev[0])));
+
+            if (err != RIG_OK)
+            {
+                rig_debug(RIG_DEBUG_ERR, "%s: Firmware RVF failed\n", __func__);
+            }
+        }
+
         break;
 
     case RIG_MODEL_XG3:
@@ -338,7 +393,27 @@ int elecraft_open(RIG *rig)
     return RIG_OK;
 }
 
+int elecraft_close(RIG *rig)
+{
+    const struct kenwood_priv_data *priv = STATE(rig)->priv;
 
+    if (priv->save_k2_ext_lvl >= 0)
+    {
+        int err;
+        char cmd[32];
+        sprintf(cmd, "K2%d;", priv->save_k2_ext_lvl);
+        err = kenwood_transaction(rig, cmd, NULL, 0);
+
+        if (err != RIG_OK)
+        {
+            rig_debug(RIG_DEBUG_ERR, "%s: error restoring %s='%s'...continuing\n", __func__,
+                      cmd,
+                      rigerror(err));
+        }
+    }
+
+    return kenwood_close(rig);
+}
 
 /* Private helper functions */
 
@@ -382,12 +457,13 @@ int verify_kenwood_id(RIG *rig, char *id)
 
     if (strcmp("017", idptr) != 0)
     {
-        rig_debug(RIG_DEBUG_VERBOSE, "%s: Rig (%s) is not a K2 or K3\n", __func__, id);
+        rig_debug(RIG_DEBUG_VERBOSE, "%s: Rig (%.4095s) is not a K2 or K3\n", __func__,
+                  id);
 //        return -RIG_EPROTO;
     }
     else
     {
-        rig_debug(RIG_DEBUG_VERBOSE, "%s: Rig ID is %s\n", __func__, id);
+        rig_debug(RIG_DEBUG_VERBOSE, "%s: Rig ID is %.4095s\n", __func__, id);
     }
 
     return RIG_OK;
@@ -422,11 +498,6 @@ int elecraft_get_extension_level(RIG *rig, const char *cmd, int *ext_level)
 
     for (i = 0; elec_ext_id_str_lst[i].level != EXT_LEVEL_NONE; i++)
     {
-        if (strcmp(elec_ext_id_str_lst[i].id, bufptr) != 0)
-        {
-            continue;
-        }
-
         if (strcmp(elec_ext_id_str_lst[i].id, bufptr) == 0)
         {
             *ext_level = elec_ext_id_str_lst[i].level;
@@ -446,6 +517,37 @@ int elecraft_get_firmware_revision_level(RIG *rig, const char *cmd,
     int err;
     char *bufptr;
     char buf[KENWOOD_MAX_BUF_LEN];
+    char rvp = cmd[2];
+    char *rv = "UNK";
+
+    if (rig->caps->rig_model == RIG_MODEL_K4)
+    {
+        switch (rvp)
+        {
+        case 'F':
+        case 'M': rv = "FPF"; break;
+
+        case 'A':
+        case 'D': rv = "DSP"; break;
+
+        case 'R': rv = "DAP"; break;
+        }
+    }
+    else
+    {
+        switch (rvp)
+        {
+        case 'M': rv = "MCU"; break;
+
+        case 'D': rv = "DSP"; break;
+
+        case 'A': rv = "AUX"; break;
+
+        case 'R': rv = "DVR"; break;
+
+        case 'F': rv = "FPF"; break;
+        }
+    }
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
@@ -479,8 +581,9 @@ int elecraft_get_firmware_revision_level(RIG *rig, const char *cmd,
     /* Copy out */
     strncpy(fw_rev, bufptr, fw_rev_sz - 1);
 
-    rig_debug(RIG_DEBUG_VERBOSE, "%s: Elecraft firmware revision is %s\n", __func__,
-              fw_rev);
+    rig_debug(RIG_DEBUG_VERBOSE, "%s: Elecraft %s firmware revision is %s\n",
+              __func__,
+              rv, fw_rev);
 
     return RIG_OK;
 }
@@ -494,13 +597,15 @@ int elecraft_get_vfo_tq(RIG *rig, vfo_t *vfo)
     char cmdbuf[10];
     char splitbuf[12];
 
+    ENTERFUNC2;
+
     memset(splitbuf, 0, sizeof(splitbuf));
     SNPRINTF(cmdbuf, sizeof(cmdbuf), "FR;");
     retval = kenwood_safe_transaction(rig, cmdbuf, splitbuf, 12, 3);
 
     if (retval != RIG_OK)
     {
-        RETURNFUNC(retval);
+        RETURNFUNC2(retval);
     }
 
     if (sscanf(splitbuf, "FR%1d", &fr) != 1)
@@ -513,7 +618,7 @@ int elecraft_get_vfo_tq(RIG *rig, vfo_t *vfo)
 
     if (retval != RIG_OK)
     {
-        RETURNFUNC(retval);
+        RETURNFUNC2(retval);
     }
 
     if (sscanf(splitbuf, "FT%1d", &ft) != 1)
@@ -521,25 +626,42 @@ int elecraft_get_vfo_tq(RIG *rig, vfo_t *vfo)
         rig_debug(RIG_DEBUG_ERR, "%s: unable to parse FT '%s'\n", __func__, splitbuf);
     }
 
-    SNPRINTF(cmdbuf, sizeof(cmdbuf), "TQ;");
+// We can use the TQX; command but we have to check that we have R32 firmware or higher
+// Not sure it's much better than TQ; since it still seems to take 350ms
+// So we have to sleep for a while after sending it to avoid TCP timeouts which still needs to be fixed
+// See
+
+#if 0
+
+    if (rig->caps->rig_model == RIG_MODEL_K4)
+    {
+        SNPRINTF(cmdbuf, sizeof(cmdbuf), "TQX;");
+    }
+    else
+#endif
+    {
+        SNPRINTF(cmdbuf, sizeof(cmdbuf), "TQ;");
+    }
+
     retval = kenwood_safe_transaction(rig, cmdbuf, splitbuf, 12, 3);
 
     if (retval != RIG_OK)
     {
-        RETURNFUNC(retval);
+        RETURNFUNC2(retval);
     }
 
     if (sscanf(splitbuf, "TQ%1d", &tq) != 1)
     {
-        rig_debug(RIG_DEBUG_ERR, "%s: unable to parse TQ '%s'\n", __func__, splitbuf);
+        rig_debug(RIG_DEBUG_ERR, "%s: unable to parse TQ or TQX response of '%s'\n",
+                  __func__, splitbuf);
     }
 
-    *vfo = rig->state.tx_vfo = RIG_VFO_A;
+    *vfo = STATE(rig)->tx_vfo = RIG_VFO_A;
 
-    if (tq && ft == 1) { *vfo = rig->state.tx_vfo = RIG_VFO_B; }
-    else if (tq && ft == 0) { *vfo = rig->state.tx_vfo = RIG_VFO_A; }
+    if (tq && ft == 1) { *vfo = STATE(rig)->tx_vfo = RIG_VFO_B; }
+    else if (tq && ft == 0) { *vfo = STATE(rig)->tx_vfo = RIG_VFO_A; }
 
-    if (!tq && fr == 1) { *vfo = rig->state.rx_vfo = rig->state.tx_vfo = RIG_VFO_B; }
+    if (!tq && fr == 1) { *vfo = STATE(rig)->rx_vfo = STATE(rig)->tx_vfo = RIG_VFO_B; }
 
     RETURNFUNC2(RIG_OK);
 }
