@@ -22,19 +22,19 @@
  *
  */
 
-#include <hamlib/config.h>
-
+#include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <math.h>
 
 #include <hamlib/rig.h>
+
 #include "idx_builtin.h"
 #include "kenwood.h"
+#include "misc.h"
 #include "bandplan.h"
 #include "elecraft.h"
-#include "token.h"
 #include "cal.h"
-#include "iofunc.h"
 
 #define K3_MODES (RIG_MODE_CW|RIG_MODE_CWR|RIG_MODE_SSB|\
     RIG_MODE_RTTY|RIG_MODE_RTTYR|RIG_MODE_FM|RIG_MODE_AM|RIG_MODE_PKTUSB|\
@@ -52,7 +52,7 @@
     RIG_LEVEL_NR|RIG_LEVEL_MONITOR_GAIN|RIG_LEVEL_RAWSTR|RIG_LEVEL_RFPOWER_METER|RIG_LEVEL_RFPOWER_METER_WATTS)
 
 #define K3_VFO (RIG_VFO_A|RIG_VFO_B)
-#define K3_VFO_OP (RIG_OP_UP|RIG_OP_DOWN)
+#define K3_VFO_OP (RIG_OP_UP|RIG_OP_DOWN|RIG_OP_TUNE)
 
 #define K3_ANTS (RIG_ANT_1|RIG_ANT_2)
 #define K4_ANTS (RIG_ANT_1|RIG_ANT_2|RIG_ANT_3|RIG_ANT_4)
@@ -63,7 +63,8 @@
 #define KX3_LEVEL_ALL (RIG_LEVEL_ATT|RIG_LEVEL_PREAMP|RIG_LEVEL_AGC|RIG_LEVEL_SQL|\
     RIG_LEVEL_STRENGTH|RIG_LEVEL_RFPOWER|RIG_LEVEL_KEYSPD|\
     RIG_LEVEL_AF|RIG_LEVEL_RF|RIG_LEVEL_MICGAIN|RIG_LEVEL_COMP|\
-    RIG_LEVEL_NR|RIG_LEVEL_MONITOR_GAIN|RIG_LEVEL_RAWSTR|RIG_LEVEL_RFPOWER_METER|RIG_LEVEL_RFPOWER_METER_WATTS)
+    RIG_LEVEL_NR|RIG_LEVEL_MONITOR_GAIN|RIG_LEVEL_RAWSTR|RIG_LEVEL_RFPOWER_METER|\
+    RIG_LEVEL_RFPOWER_METER_WATTS|RIG_LEVEL_SWR)
 
 /*
  * Elecraft K3/K3S extra level definitions
@@ -147,8 +148,8 @@ int k3_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width);
 int k3_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width);
 int k3_get_vfo(RIG *rig, vfo_t *vfo);
 int k3_set_vfo(RIG *rig, vfo_t vfo);
-int k3_set_ext_level(RIG *rig, vfo_t vfo, token_t token, value_t val);
-int k3_get_ext_level(RIG *rig, vfo_t vfo, token_t token, value_t *val);
+int k3_set_ext_level(RIG *rig, vfo_t vfo, hamlib_token_t token, value_t val);
+int k3_get_ext_level(RIG *rig, vfo_t vfo, hamlib_token_t token, value_t *val);
 int k3_set_rit(RIG *rig, vfo_t vfo, shortfreq_t rit);
 int k3_set_xit(RIG *rig, vfo_t vfo, shortfreq_t rit);
 int k3_set_split_mode(RIG *rig, vfo_t vfo, rmode_t tx_mode, pbwidth_t tx_width);
@@ -160,6 +161,7 @@ int kx3_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val);
 int kx3_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val);
 int k3_set_func(RIG *rig, vfo_t vfo, setting_t func, int status);
 int k3_get_func(RIG *rig, vfo_t vfo, setting_t func, int *status);
+int k3_vfo_op(RIG *rig, vfo_t vfo, vfo_op_t op);
 int k3_power2mW(RIG *rig, unsigned int *mwpower, float power, freq_t freq,
                 rmode_t mode);
 
@@ -169,11 +171,40 @@ int k3_set_nb_level(RIG *rig, float dsp_nb, float if_nb);
 int k3_get_nb_level(RIG *rig, float *dsp_nb, float *if_nb);
 int k3_get_bar_graph_level(RIG *rig, float *smeter, float *pwr, float *alc,
                            int *mode_tx);
+int k4_get_bar_graph_level(RIG *rig, float *swr, float *pwr, float *alc,
+                           int *mode_tx);
 int kx3_get_bar_graph_level(RIG *rig, float *level);
+int k3_send_voice_mem(RIG *rig, vfo_t vfo, int ch);
+int k3_stop_voice_mem(RIG *rig, vfo_t vfo);
+int k3_stop_morse(RIG *rig, vfo_t vfo);
 
 /* K4 functions */
 int k4_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt);
 int k4_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt);
+int k4_send_voice_mem(RIG *rig, vfo_t vfo, int ch);
+int k4_stop_voice_mem(RIG *rig, vfo_t vfo);
+int k4_stop_morse(RIG *rig, vfo_t vfo);
+
+/*
+ * K3 rig capabilities.
+ * This kit can recognize a large subset of TS-570/K2 commands and has many
+ * extensions of its own.  Extension backend functions to standard Kenwood
+ * command are defined in elecraft.c (shared with K2) and in this file.
+ *
+ * Part of info comes from http://www.elecraft.com/K2_Manual_Download_Page.htm#K3
+ * look for K3 Programmer's Reference PDF
+ */
+int kx3_get_bar_graph_level(RIG *rig, float *level);
+int k3_send_voice_mem(RIG *rig, vfo_t vfo, int ch);
+int k3_stop_voice_mem(RIG *rig, vfo_t vfo);
+int k3_stop_morse(RIG *rig, vfo_t vfo);
+
+/* K4 functions */
+int k4_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt);
+int k4_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt);
+int k4_send_voice_mem(RIG *rig, vfo_t vfo, int ch);
+int k4_stop_voice_mem(RIG *rig, vfo_t vfo);
+int k4_stop_morse(RIG *rig, vfo_t vfo);
 
 /*
  * K3 rig capabilities.
@@ -185,12 +216,12 @@ int k4_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt);
  * look for K3 Programmer's Reference PDF
  *
  */
-const struct rig_caps k3_caps =
+struct rig_caps k3_caps =
 {
     RIG_MODEL(RIG_MODEL_K3),
     .model_name =       "K3",
     .mfg_name =     "Elecraft",
-    .version =      BACKEND_VER ".26",
+    .version =      BACKEND_VER ".31",
     .copyright =        "LGPL",
     .status =       RIG_STATUS_STABLE,
     .rig_type =     RIG_TYPE_TRANSCEIVER,
@@ -216,7 +247,7 @@ const struct rig_caps k3_caps =
     .has_set_parm =     RIG_PARM_NONE,  /* FIXME: parms */
     .level_gran = {
         // cppcheck-suppress *
-        [LVL_KEYSPD] = { .min = { .i = 8 }, .max = { .i = 50 }, .step = { .i = 1 } },
+#include "level_gran_elecraft.h"
     },
     .parm_gran =        {},
     .extlevels =        k3_ext_levels,
@@ -232,7 +263,11 @@ const struct rig_caps k3_caps =
     .bank_qty =     0,
     .chan_desc_sz =     0,
 
-    .chan_list =        { RIG_CHAN_END },
+    .chan_list =    {
+        {   1, 4, RIG_MTYPE_VOICE },
+        {   1, 4, RIG_MTYPE_MORSE },
+        RIG_CHAN_END
+    },
 
     .rx_range_list1 =  {
         {kHz(500), MHz(30), K3_MODES, -1, -1, K3_VFO, K3_ANTS},
@@ -298,7 +333,7 @@ const struct rig_caps k3_caps =
     .rig_init =     kenwood_init,
     .rig_cleanup =      kenwood_cleanup,
     .rig_open =     elecraft_open,
-    .rig_close =        kenwood_close,
+    .rig_close =        elecraft_close,
     .set_freq =     k3_set_freq,
     .get_freq =     kenwood_get_freq,
     .set_mode =     k3_set_mode,
@@ -313,8 +348,8 @@ const struct rig_caps k3_caps =
     .get_rit =      kenwood_get_rit,
     .set_xit =      k3_set_xit,
     .get_xit =      kenwood_get_xit,
-    .get_ptt =      kenwood_get_ptt,
-    .set_ptt =      kenwood_set_ptt,
+    .get_ptt =      k4_get_ptt,
+    .set_ptt =      k4_set_ptt,
     .get_dcd =      kenwood_get_dcd,
     .set_func =     k3_set_func,
     .get_func =     k3_get_func,
@@ -324,7 +359,7 @@ const struct rig_caps k3_caps =
     .get_level =        k3_get_level,
     .set_ext_level =    k3_set_ext_level,
     .get_ext_level =    k3_get_ext_level,
-    .vfo_op =       kenwood_vfo_op,
+    .vfo_op =       k3_vfo_op,
     .set_trn =      kenwood_set_trn,
     .get_trn =      kenwood_get_trn,
     .set_powerstat =    kenwood_set_powerstat,
@@ -333,17 +368,20 @@ const struct rig_caps k3_caps =
     .get_ant =      kenwood_get_ant,
     .send_morse =       kenwood_send_morse,
     .wait_morse =       rig_wait_morse,
+    .stop_morse =       k3_stop_morse,
+    .send_voice_mem =   k3_send_voice_mem,
+    .stop_voice_mem =   k3_stop_voice_mem,
     .power2mW =     k3_power2mW,
-
+    .morse_qsize = 24,
     .hamlib_check_rig_caps = HAMLIB_CHECK_RIG_CAPS
 };
 
-const struct rig_caps k3s_caps =
+struct rig_caps k3s_caps =
 {
     RIG_MODEL(RIG_MODEL_K3S),
     .model_name =       "K3S",
     .mfg_name =     "Elecraft",
-    .version =      BACKEND_VER ".21",
+    .version =      BACKEND_VER ".25",
     .copyright =        "LGPL",
     .status =       RIG_STATUS_STABLE,
     .rig_type =     RIG_TYPE_TRANSCEIVER,
@@ -368,7 +406,10 @@ const struct rig_caps k3s_caps =
     .has_get_parm =     RIG_PARM_NONE,
     .has_set_parm =     RIG_PARM_NONE,  /* FIXME: parms */
     .level_gran = {
-        [LVL_KEYSPD] = { .min = { .i = 8 }, .max = { .i = 50 }, .step = { .i = 1 } },
+#define NO_LVL_ATT
+#include "level_gran_elecraft.h"
+#undef NO_LVL_ATT
+        [LVL_ATT] = { .min = { .i = 0 }, .max = { .i = 15 }, .step = { .i = 5 } },
     },
     .parm_gran =        {},
     .extlevels =        k3_ext_levels,
@@ -384,7 +425,11 @@ const struct rig_caps k3s_caps =
     .bank_qty =     0,
     .chan_desc_sz =     0,
 
-    .chan_list =        { RIG_CHAN_END },
+    .chan_list =    {
+        {   1, 4, RIG_MTYPE_VOICE },
+        {   1, 4, RIG_MTYPE_MORSE },
+        RIG_CHAN_END
+    },
 
     .rx_range_list1 =  {
         {kHz(500), MHz(30), K3_MODES, -1, -1, K3_VFO, K3_ANTS},
@@ -450,7 +495,7 @@ const struct rig_caps k3s_caps =
     .rig_init =     kenwood_init,
     .rig_cleanup =      kenwood_cleanup,
     .rig_open =     elecraft_open,
-    .rig_close =        kenwood_close,
+    .rig_close =        elecraft_close,
     .set_freq =     k3_set_freq,
     .get_freq =     kenwood_get_freq,
     .set_mode =     k3_set_mode,
@@ -465,8 +510,8 @@ const struct rig_caps k3s_caps =
     .get_rit =      kenwood_get_rit,
     .set_xit =      k3_set_xit,
     .get_xit =      kenwood_get_xit,
-    .get_ptt =      kenwood_get_ptt,
-    .set_ptt =      kenwood_set_ptt,
+    .get_ptt =      k4_get_ptt,
+    .set_ptt =      k4_set_ptt,
     .get_dcd =      kenwood_get_dcd,
     .set_func =     k3_set_func,
     .get_func =     k3_get_func,
@@ -476,7 +521,7 @@ const struct rig_caps k3s_caps =
     .get_level =        k3_get_level,
     .set_ext_level =    k3_set_ext_level,
     .get_ext_level =    k3_get_ext_level,
-    .vfo_op =       kenwood_vfo_op,
+    .vfo_op =       k3_vfo_op,
     .set_trn =      kenwood_set_trn,
     .get_trn =      kenwood_get_trn,
     .set_powerstat =    kenwood_set_powerstat,
@@ -485,17 +530,21 @@ const struct rig_caps k3s_caps =
     .get_ant =      kenwood_get_ant,
     .send_morse =       kenwood_send_morse,
     .wait_morse =       rig_wait_morse,
+    .stop_morse =       k3_stop_morse,
+    .send_voice_mem =   k3_send_voice_mem,
+    .stop_voice_mem =   k3_stop_voice_mem,
     .power2mW =     k3_power2mW,
+    .morse_qsize = 24,
     .hamlib_check_rig_caps = HAMLIB_CHECK_RIG_CAPS
 };
 
 // How similar is this to the K3S?
-const struct rig_caps k4_caps =
+struct rig_caps k4_caps =
 {
     RIG_MODEL(RIG_MODEL_K4),
     .model_name =       "K4",
     .mfg_name =     "Elecraft",
-    .version =      BACKEND_VER ".25",
+    .version =      BACKEND_VER ".32",
     .copyright =        "LGPL",
     .status =       RIG_STATUS_STABLE,
     .rig_type =     RIG_TYPE_TRANSCEIVER,
@@ -520,12 +569,24 @@ const struct rig_caps k4_caps =
     .has_get_parm =     RIG_PARM_NONE,
     .has_set_parm =     RIG_PARM_NONE,  /* FIXME: parms */
     .level_gran = {
-        [LVL_KEYSPD] = { .min = { .i = 8 }, .max = { .i = 50 }, .step = { .i = 1 } },
+#define NO_LVL_ATT
+#define NO_LVL_CWPITCH
+#define NO_LVL_VOXDELAY
+#define NO_LVL_PREAMP
+#include "level_gran_elecraft.h"
+#undef NO_LVL_ATT
+#undef NO_LVL_CWPITCH
+#undef NO_LVL_VOXDELAY
+#undef NO_LVL_PREAMP
+        [LVL_CWPITCH]  = { .min = { .i = 250 }, .max = { .i = 950 }, .step = { .i = 10 } },
+        [LVL_ATT]      = { .min = { .i = 0 },   .max = { .i = 15 },  .step = { .i = 5 }  },
+        [LVL_VOXDELAY] = { .min = { .i = 0 },   .max = { .i = 255 }, .step = { .i = 10 } },
+        [LVL_PREAMP]   = { .min = { .i = 0 },   .max = { .i = 30},   .step = { .i = 10 } },
     },
     .parm_gran =        {},
     .extlevels =        k3_ext_levels,
     .extparms =     kenwood_cfg_params,
-    .preamp =       { 1, RIG_DBLST_END, },
+    .preamp =       { 10, 20, 30, RIG_DBLST_END, },
     .attenuator =       { 5, 10, 15, RIG_DBLST_END, },
     .max_rit =      Hz(9990),
     .max_xit =      Hz(9990),
@@ -533,10 +594,16 @@ const struct rig_caps k4_caps =
     .vfo_ops =      K3_VFO_OP,
     .targetable_vfo =   RIG_TARGETABLE_FREQ | RIG_TARGETABLE_MODE,
     .transceive =       RIG_TRN_RIG,
+    .agc_level_count = 3,
+    .agc_levels = { RIG_AGC_OFF, RIG_AGC_SLOW, RIG_AGC_FAST },
     .bank_qty =     0,
     .chan_desc_sz =     0,
 
-    .chan_list =        { RIG_CHAN_END },
+    .chan_list =    {
+        {   1,  4, RIG_MTYPE_VOICE },
+        {   1,  4, RIG_MTYPE_MORSE },
+        RIG_CHAN_END
+    },
 
     .rx_range_list1 =  {
         {kHz(500), MHz(30), K3_MODES, -1, -1, K3_VFO, K4_ANTS},
@@ -602,7 +669,7 @@ const struct rig_caps k4_caps =
     .rig_init =     kenwood_init,
     .rig_cleanup =      kenwood_cleanup,
     .rig_open =     elecraft_open,
-    .rig_close =        kenwood_close,
+    .rig_close =        elecraft_close,
     .set_freq =     kenwood_set_freq,
     .get_freq =     kenwood_get_freq,
     .set_mode =     k3_set_mode,
@@ -628,7 +695,7 @@ const struct rig_caps k4_caps =
     .get_level =        k3_get_level,
     .set_ext_level =    k3_set_ext_level,
     .get_ext_level =    k3_get_ext_level,
-    .vfo_op =       kenwood_vfo_op,
+    .vfo_op =       k3_vfo_op,
     .set_trn =      kenwood_set_trn,
     .get_trn =      kenwood_get_trn,
     .set_powerstat =    kenwood_set_powerstat,
@@ -637,16 +704,20 @@ const struct rig_caps k4_caps =
     .get_ant =      kenwood_get_ant,
     .send_morse =       kenwood_send_morse,
     .wait_morse =       rig_wait_morse,
+    .stop_morse =       k4_stop_morse,
+    .send_voice_mem =   k4_send_voice_mem,
+    .stop_voice_mem =   k4_stop_voice_mem,
     .power2mW =     k3_power2mW,
+    .morse_qsize = 24,
     .hamlib_check_rig_caps = HAMLIB_CHECK_RIG_CAPS
 };
 
-const struct rig_caps kx3_caps =
+struct rig_caps kx3_caps =
 {
     RIG_MODEL(RIG_MODEL_KX3),
     .model_name =       "KX3",
     .mfg_name =     "Elecraft",
-    .version =      BACKEND_VER ".18",
+    .version =      BACKEND_VER ".22",
     .copyright =        "LGPL",
     .status =       RIG_STATUS_STABLE,
     .rig_type =     RIG_TYPE_TRANSCEIVER,
@@ -671,7 +742,7 @@ const struct rig_caps kx3_caps =
     .has_get_parm =     RIG_PARM_NONE,
     .has_set_parm =     RIG_PARM_NONE,  /* FIXME: parms */
     .level_gran = {
-        [LVL_KEYSPD] = { .min = { .i = 8 }, .max = { .i = 50 }, .step = { .i = 1 } },
+#include "level_gran_elecraft.h"
     },
     .parm_gran =        {},
     .extlevels =        kx3_ext_levels,
@@ -687,7 +758,11 @@ const struct rig_caps kx3_caps =
     .bank_qty =     0,
     .chan_desc_sz =     0,
 
-    .chan_list =        { RIG_CHAN_END },
+    .chan_list =    {
+        {   1, 4, RIG_MTYPE_VOICE },
+        {   1, 4, RIG_MTYPE_MORSE },
+        RIG_CHAN_END
+    },
 
     .rx_range_list1 =  {
         {kHz(500), MHz(30), K3_MODES, -1, -1, K3_VFO, K3_ANTS},
@@ -753,7 +828,7 @@ const struct rig_caps kx3_caps =
     .rig_init =     kenwood_init,
     .rig_cleanup =      kenwood_cleanup,
     .rig_open =     elecraft_open,
-    .rig_close =        kenwood_close,
+    .rig_close =        elecraft_close,
     .set_freq =     kenwood_set_freq,
     .get_freq =     kenwood_get_freq,
     .set_mode =     k3_set_mode,
@@ -768,8 +843,8 @@ const struct rig_caps kx3_caps =
     .get_rit =      kenwood_get_rit,
     .set_xit =      k3_set_xit,
     .get_xit =      kenwood_get_xit,
-    .get_ptt =      kenwood_get_ptt,
-    .set_ptt =      kenwood_set_ptt,
+    .get_ptt =      k4_get_ptt,
+    .set_ptt =      k4_set_ptt,
     .get_dcd =      kenwood_get_dcd,
     .set_func =     k3_set_func,
     .get_func =     k3_get_func,
@@ -779,7 +854,7 @@ const struct rig_caps kx3_caps =
     .get_level =        kx3_get_level,
     .set_ext_level =    k3_set_ext_level,
     .get_ext_level =    k3_get_ext_level,
-    .vfo_op =       kenwood_vfo_op,
+    .vfo_op =       k3_vfo_op,
     .set_trn =      kenwood_set_trn,
     .get_trn =      kenwood_get_trn,
     .set_powerstat =    kenwood_set_powerstat,
@@ -788,16 +863,20 @@ const struct rig_caps kx3_caps =
     .get_ant =      kenwood_get_ant,
     .send_morse =       kenwood_send_morse,
     .wait_morse =       rig_wait_morse,
+    .stop_morse =       k3_stop_morse,
+    .send_voice_mem =   k3_send_voice_mem,
+    .stop_voice_mem =   k3_stop_voice_mem,
     .power2mW =     k3_power2mW,
+    .morse_qsize = 24,
     .hamlib_check_rig_caps = HAMLIB_CHECK_RIG_CAPS
 };
 
-const struct rig_caps kx2_caps =
+struct rig_caps kx2_caps =
 {
     RIG_MODEL(RIG_MODEL_KX2),
     .model_name =       "KX2",
     .mfg_name =     "Elecraft",
-    .version =      BACKEND_VER ".17",
+    .version =      BACKEND_VER ".21",
     .copyright =        "LGPL",
     .status =       RIG_STATUS_STABLE,
     .rig_type =     RIG_TYPE_TRANSCEIVER,
@@ -822,7 +901,7 @@ const struct rig_caps kx2_caps =
     .has_get_parm =     RIG_PARM_NONE,
     .has_set_parm =     RIG_PARM_NONE,  /* FIXME: parms */
     .level_gran = {
-        [LVL_KEYSPD] = { .min = { .i = 8 }, .max = { .i = 50 }, .step = { .i = 1 } },
+#include "level_gran_elecraft.h"
     },
     .parm_gran =        {},
     .extlevels =        kx3_ext_levels,
@@ -838,7 +917,10 @@ const struct rig_caps kx2_caps =
     .bank_qty =     0,
     .chan_desc_sz =     0,
 
-    .chan_list =        { RIG_CHAN_END },
+    .chan_list =    {
+        {   1, 4, RIG_MTYPE_MORSE },
+        RIG_CHAN_END
+    },
 
     .rx_range_list1 =  {
         {kHz(500), MHz(30), K3_MODES, -1, -1, K3_VFO, K3_ANTS},
@@ -904,7 +986,7 @@ const struct rig_caps kx2_caps =
     .rig_init =     kenwood_init,
     .rig_cleanup =      kenwood_cleanup,
     .rig_open =     elecraft_open,
-    .rig_close =        kenwood_close,
+    .rig_close =        elecraft_close,
     .set_freq =     kenwood_set_freq,
     .get_freq =     kenwood_get_freq,
     .set_mode =     k3_set_mode,
@@ -930,7 +1012,7 @@ const struct rig_caps kx2_caps =
     .get_level =        kx3_get_level,
     .set_ext_level =    k3_set_ext_level,
     .get_ext_level =    k3_get_ext_level,
-    .vfo_op =       kenwood_vfo_op,
+    .vfo_op =       k3_vfo_op,
     .set_trn =      kenwood_set_trn,
     .get_trn =      kenwood_get_trn,
     .set_powerstat =    kenwood_set_powerstat,
@@ -939,6 +1021,7 @@ const struct rig_caps kx2_caps =
     .get_ant =      kenwood_get_ant,
     .send_morse =       kenwood_send_morse,
     .wait_morse =       rig_wait_morse,
+    .stop_morse =       k3_stop_morse,
     .power2mW =     k3_power2mW,
     .hamlib_check_rig_caps = HAMLIB_CHECK_RIG_CAPS
 };
@@ -963,7 +1046,7 @@ int k3_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
     char *cmd_data = "DT";
     char *cmd_bw = "BW";
     int cmd_bw_len = 6;
-    struct kenwood_priv_data *priv = rig->state.priv;
+    const struct kenwood_priv_data *priv = STATE(rig)->priv;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called vfo=%s\n", __func__, rig_strvfo(vfo));
 
@@ -987,7 +1070,7 @@ int k3_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
 
     if (vfo == RIG_VFO_CURR)
     {
-        vfo = rig->state.current_vfo;
+        vfo = STATE(rig)->current_vfo;
     }
 
     err = kenwood_get_mode(rig, vfo, &temp_m, &temp_w);
@@ -1115,14 +1198,15 @@ int k3_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
     char buf[KENWOOD_MAX_BUF_LEN];
     char *dtcmd;
     struct kenwood_priv_caps *caps = kenwood_caps(rig);
-    struct kenwood_priv_data *priv = rig->state.priv;
+    struct kenwood_priv_data *priv = STATE(rig)->priv;
 
+    ENTERFUNC;
     rig_debug(RIG_DEBUG_VERBOSE, "%s called vfo=%s mode=%s width=%d\n", __func__,
               rig_strvfo(vfo), rig_strrmode(mode), (int)width);
 
     if (vfo == RIG_VFO_CURR)
     {
-        vfo = rig->state.current_vfo;
+        vfo = STATE(rig)->current_vfo;
     }
 
     rmode_t tmodeA, tmodeB;
@@ -1137,7 +1221,7 @@ int k3_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
     {
         rig_debug(RIG_DEBUG_TRACE, "%s(%d): mode/width no change, skipping\n", __FILE__,
                   __LINE__);
-        return RIG_OK;
+        RETURNFUNC(RIG_OK);
     }
     else
     {
@@ -1287,7 +1371,7 @@ int k3_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
 
         if (err != RIG_OK)
         {
-            return err;
+            RETURNFUNC(err);
         }
     }
 
@@ -1301,11 +1385,11 @@ int k3_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
 
         if (err != RIG_OK)
         {
-            return err;
+            RETURNFUNC(err);
         }
     }
 
-    return RIG_OK;
+    RETURNFUNC(RIG_OK);
 }
 
 /* Elecraft rigs don't really know about swappings vfos.
@@ -1317,7 +1401,7 @@ int k3_set_vfo(RIG *rig, vfo_t vfo)
     ENTERFUNC;
 
     // we emulate vfo selection for Elecraft
-    rig->state.current_vfo = vfo;
+    STATE(rig)->current_vfo = vfo;
 
     RETURNFUNC(RIG_OK);
 }
@@ -1326,7 +1410,7 @@ int k3_get_vfo(RIG *rig, vfo_t *vfo)
 {
     ENTERFUNC;
 
-    *vfo = rig->state.current_vfo;
+    *vfo = STATE(rig)->current_vfo;
 
     RETURNFUNC(RIG_OK);
 }
@@ -1343,7 +1427,7 @@ int k3_get_vfo(RIG *rig, vfo_t *vfo)
  * See Private Elecraft extra levels definitions in elecraft.c and
  * private token #define in elecraft.h
  */
-int k3_set_ext_level(RIG *rig, vfo_t vfo, token_t token, value_t val)
+int k3_set_ext_level(RIG *rig, vfo_t vfo, hamlib_token_t token, value_t val)
 {
     char buf[10];
 
@@ -1392,7 +1476,7 @@ int k3_set_ext_level(RIG *rig, vfo_t vfo, token_t token, value_t val)
  *      STRING: val.cs for set, val.s for get
  *      CHECKBUTTON: val.i 0/1
  */
-int k3_get_ext_level(RIG *rig, vfo_t vfo, token_t token, value_t *val)
+int k3_get_ext_level(RIG *rig, vfo_t vfo, hamlib_token_t token, value_t *val)
 {
     char buf[KENWOOD_MAX_BUF_LEN];
     int err;
@@ -1508,7 +1592,7 @@ int k3_set_split_mode(RIG *rig, vfo_t vfo, rmode_t tx_mode, pbwidth_t tx_width)
     char kmode;
     int err;
     char cmd_m[16];
-    struct kenwood_priv_data *priv = rig->state.priv;
+    const struct kenwood_priv_data *priv = STATE(rig)->priv;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
@@ -1784,22 +1868,20 @@ static int k3_get_maxpower(RIG *rig)
     //int retval;
     int maxpower = 15; // K3 default power level
     //char levelbuf[KENWOOD_MAX_BUF_LEN];
-    struct kenwood_priv_data *priv = rig->state.priv;
+    const struct kenwood_priv_data *priv = STATE(rig)->priv;
 
     // default range is 0-15 if there is no KPA3 installed
     if (priv->has_kpa3 || priv->has_kpa100)
     {
         maxpower = 110;
     }
-
-// Elecraft makes max power pretty variable
-// So we will stick with 15W or 110W and scale everything to that
-#if 0
     else if (RIG_IS_KX2 || RIG_IS_KX3)
     {
 
         int bandnum = -1;
-        retval = kenwood_safe_transaction(rig, "BN", levelbuf, KENWOOD_MAX_BUF_LEN, 4);
+        char levelbuf[KENWOOD_MAX_BUF_LEN];
+        int retval = kenwood_safe_transaction(rig, "BN", levelbuf, KENWOOD_MAX_BUF_LEN,
+                                              4);
 
         if (retval != RIG_OK) { return retval; }
 
@@ -1833,8 +1915,6 @@ static int k3_get_maxpower(RIG *rig)
         }
     }
 
-#endif
-
     rig_debug(RIG_DEBUG_TRACE, "%s: maxpower=%d\n", __func__, maxpower);
     return maxpower;
 }
@@ -1845,7 +1925,9 @@ int k3_power2mW(RIG *rig,
                 freq_t freq,
                 rmode_t mode)
 {
-    *mwpower = power * k3_get_maxpower(rig) * 1000;
+    char buf[32];
+    snprintf(buf, sizeof(buf), "%.0f", power * k3_get_maxpower(rig) * 1000);
+    *mwpower = atoi(buf);
     return RIG_OK;
 }
 
@@ -1853,6 +1935,7 @@ int k3_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
 {
     char levelbuf[16];
     int kenwood_val;
+    float pwr;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
@@ -1906,9 +1989,9 @@ int k3_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
             int i;
             int foundit = 0;
 
-            for (i = 0; i < HAMLIB_MAXDBLSTSIZ && rig->state.attenuator[i]; i++)
+            for (i = 0; i < HAMLIB_MAXDBLSTSIZ && STATE(rig)->attenuator[i]; i++)
             {
-                if (val.i == rig->state.attenuator[i])
+                if (val.i == STATE(rig)->attenuator[i])
                 {
                     SNPRINTF(levelbuf, sizeof(levelbuf), "RA%02d", i + 1);
                     foundit = 1;
@@ -1952,9 +2035,9 @@ int k3_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
         break;
 
     case RIG_LEVEL_RFPOWER:
-        kenwood_val = (int)(val.f * k3_get_maxpower(rig));
-        SNPRINTF(levelbuf, sizeof(levelbuf), "PC%03d%s", kenwood_val,
-                 kenwood_val > 15 ? "1" : "0");
+        pwr = val.f * k3_get_maxpower(rig);
+        SNPRINTF(levelbuf, sizeof(levelbuf), "PC%03.f%c", pwr > 15.0 ? pwr : 10.0 * pwr,
+                 pwr > 15.0 ? '1' : '0');
         break;
 
     default:
@@ -1973,7 +2056,7 @@ int k3_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
     int retval;
     int lvl;
     size_t len;
-    struct kenwood_priv_data *priv = rig->state.priv;
+    const struct kenwood_priv_data *priv = STATE(rig)->priv;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
@@ -2036,7 +2119,15 @@ int k3_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
         int tx_mode;
         float alc;
 
-        retval = k3_get_bar_graph_level(rig, NULL, NULL, &alc, &tx_mode);
+        if (RIG_IS_K4)
+        {
+            retval = k4_get_bar_graph_level(rig, NULL, NULL, &alc, &tx_mode);
+            tx_mode = 1;  // Assume ALC is zero when in Tx so we don't care about ptt status
+        }
+        else
+        {
+            retval = k3_get_bar_graph_level(rig, NULL, NULL, &alc, &tx_mode);
+        }
 
         if (retval != RIG_OK)
         {
@@ -2064,7 +2155,15 @@ int k3_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
         int tx_mode;
         float pwr;
 
-        retval = k3_get_bar_graph_level(rig, NULL, &pwr, NULL, &tx_mode);
+        if (RIG_IS_K4)
+        {
+            retval = k4_get_bar_graph_level(rig, NULL, &pwr, NULL, &tx_mode);
+            tx_mode = 1;  // Does K4 return pwr=0 when in Rx?  Hope so.
+        }
+        else
+        {
+            retval = k3_get_bar_graph_level(rig, NULL, &pwr, NULL, &tx_mode);
+        }
 
         if (retval != RIG_OK)
         {
@@ -2145,7 +2244,7 @@ int k3_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 
             for (i = 0; i < lvl && i < HAMLIB_MAXDBLSTSIZ; i++)
             {
-                if (rig->state.attenuator[i] == 0)
+                if (STATE(rig)->attenuator[i] == 0)
                 {
                     rig_debug(RIG_DEBUG_ERR, "%s: unexpected att level %d\n", __func__, lvl);
                     return -RIG_EPROTO;
@@ -2157,7 +2256,7 @@ int k3_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
                 return -RIG_EINTERNAL;
             }
 
-            val->i = rig->state.attenuator[i - 1];
+            val->i = STATE(rig)->attenuator[i - 1];
         }
 
         break;
@@ -2268,6 +2367,27 @@ int k3_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 
         break;
 
+    case RIG_LEVEL_SWR:
+        if (RIG_IS_K4)
+        {
+            retval = k4_get_bar_graph_level(rig, &val->f, NULL, NULL, NULL);
+            return RIG_OK;
+        }
+        else
+        {
+            retval = kenwood_safe_transaction(rig, "SW", levelbuf, sizeof(levelbuf), 5);
+
+            if (retval != RIG_OK)
+            {
+                return retval;
+            }
+
+            sscanf(levelbuf + 2, "%d", &val->i);
+        }
+
+        val->f = (float) val->i / 10.0f;
+        break;
+
     default:
         return kenwood_get_level(rig, vfo, level, val);
     }
@@ -2308,6 +2428,7 @@ int kx3_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
 int kx3_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 {
     int retval;
+    float f;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
@@ -2319,7 +2440,8 @@ int kx3_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
         if (retval != RIG_OK) { return retval; }
 
         // manual says 0-255 as of Rev G5 but experiment says 0-60
-        val->f = val->i / 60.0;
+        f = val->i / 60.0;
+        val->f = f;
         return retval;
 
     case RIG_LEVEL_RF:
@@ -2327,7 +2449,8 @@ int kx3_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 
         if (retval != RIG_OK) { return retval; }
 
-        val->f = (val->i - 190.0) / (250.0 - 190.0);
+        f = (val->i - 190.0) / (250.0 - 190.0);
+        val->f = f;
         return retval;
 
     case RIG_LEVEL_MICGAIN:
@@ -2335,7 +2458,8 @@ int kx3_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 
         if (retval != RIG_OK) { return retval; }
 
-        val->f = val->i / 80.0;
+        f = val->i / 80.0;
+        val->f = f;
         return retval;
 
     case RIG_LEVEL_RFPOWER_METER:
@@ -2370,7 +2494,7 @@ int kx3_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 
     case RIG_LEVEL_RFPOWER_METER_WATTS:
     {
-        struct kenwood_priv_data *priv = rig->state.priv;
+        struct kenwood_priv_data *priv = STATE(rig)->priv;
         char levelbuf[KENWOOD_MAX_BUF_LEN];
         int pwr;
 
@@ -2420,6 +2544,10 @@ int k3_set_func(RIG *rig, vfo_t vfo, setting_t func, int status)
         SNPRINTF(buf, sizeof(buf), "AG%c", (status == 0) ? '/' : '0');
         break;
 
+    case RIG_FUNC_TUNER: // K2 KX2 K3 K3S KX3 K4
+        SNPRINTF(buf, sizeof(buf), "SWT16");
+        break;
+
     default:
         return kenwood_set_func(rig, vfo, func, status);
     }
@@ -2427,6 +2555,39 @@ int k3_set_func(RIG *rig, vfo_t vfo, setting_t func, int status)
     return kenwood_transaction(rig, buf, NULL, 0);
 }
 
+int k3_vfo_op(RIG *rig, vfo_t vfo, vfo_op_t op)
+{
+    char buf[32];
+    ENTERFUNC;
+
+    switch (op)
+    {
+    case RIG_OP_TUNE: // KX2 K3 K3S KX3 K4 -- K2 needs SWH20 to it's in k2.c
+        switch (rig->caps->rig_model)
+        {
+        case RIG_MODEL_KX2: SNPRINTF(buf, sizeof(buf), "SWT20"); break;
+
+        case RIG_MODEL_K3S:
+        case RIG_MODEL_K3:  SNPRINTF(buf, sizeof(buf), "SWT19"); break;
+
+        case RIG_MODEL_KX3: SNPRINTF(buf, sizeof(buf), "SWT44"); break;
+
+        case RIG_MODEL_K4:  SNPRINTF(buf, sizeof(buf), "SW40"); break;
+
+        default:
+            rig_debug(RIG_DEBUG_ERR, "%s: unknown rig=%d\n", __func__,
+                      rig->caps->rig_model);
+            RETURNFUNC(-RIG_EINVAL);
+        }
+
+        break;
+
+    default: RETURNFUNC(kenwood_vfo_op(rig, vfo, op));
+    }
+
+    RETURNFUNC(kenwood_transaction(rig, buf, NULL, 0));
+}
+
 /*
  * Some functions, notably RIT and XIT On/Off status, can be queried
  * on the K3.  Those functions are handled here and others are passed
@@ -2592,6 +2753,33 @@ int k3_get_nb_level(RIG *rig, float *dsp_nb, float *if_nb)
     return RIG_OK;
 }
 
+int k4_get_bar_graph_level(RIG *rig, float *swr, float *pwr, float *alc,
+                           int *mode_tx)
+{
+    int retval;
+    int ialc, icmp, ifwd, iswr;
+    char levelbuf[16];
+
+    rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
+
+    retval = kenwood_safe_transaction(rig, "TM", levelbuf, sizeof(levelbuf), 14);
+
+    if (retval != RIG_OK)
+    {
+        return retval;
+    }
+
+    sscanf(levelbuf, "TM%03d%03d%03d%03d", &ialc, &icmp, &ifwd, &iswr);
+
+    if (swr) { *swr = iswr / 10.0; }
+
+    if (pwr) { *pwr = ifwd / 100.0; } // pwr is returned in 0-1 sscale
+
+    if (alc) { *alc = ialc; }
+
+    return RIG_OK;
+}
+
 int k3_get_bar_graph_level(RIG *rig, float *smeter, float *pwr, float *alc,
                            int *mode_tx)
 {
@@ -2603,7 +2791,7 @@ int k3_get_bar_graph_level(RIG *rig, float *smeter, float *pwr, float *alc,
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
-    // Determine transmit metering mode: 0 = RF POWER, 1 = ALC
+// Determine transmit metering mode: 0 = RF POWER, 1 = ALC
     retval = get_kenwood_func(rig, "TM", &tm_raw);
 
     if (retval != RIG_OK)
@@ -2755,7 +2943,7 @@ int k4_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt)
 
 
 // The K4 has a problem in Fake It mode where the FA command is ignored
-// We will use it's special TQ command to try and ensure PTT is really off
+// We will use its special TQ command to try and ensure PTT is really off
 int k4_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt)
 {
     char pttbuf[6];
@@ -2801,7 +2989,7 @@ int k4_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt)
     return RIG_OK;
 }
 
-// K3S band memory needs some time to do it's thing after freq change
+// K3S band memory needs some time to do its thing after freq change
 // K3 probably does too
 // But what about the K4?
 int k3_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
@@ -2823,3 +3011,75 @@ int k3_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 
     return retval;
 }
+
+int k3_send_voice_mem(RIG *rig, vfo_t vfo, int ch)
+{
+    char *cmd;
+    int retval;
+
+    if (ch < 1 || ch > 4)
+    {
+        rig_debug(RIG_DEBUG_ERR, "%s: expected 1<=ch<=4, got %d\n", __func__, ch);
+        return (-RIG_EINVAL);
+    }
+
+    switch (ch)
+    {
+    case 1: cmd = "SWT21;"; break;
+
+    case 2: cmd = "SWT31;"; break;
+
+    case 3: cmd = "SWT35;"; break;
+
+    case 4: cmd = "SWT39;"; break;
+    }
+
+    retval = kenwood_transaction(rig, cmd, NULL, 0);
+    return retval;
+}
+
+int k3_stop_voice_mem(RIG *rig, vfo_t vfo)
+{
+    int retval;
+    retval = kenwood_transaction(rig, "SWT37;", NULL, 0);
+    return retval;
+}
+
+int k4_send_voice_mem(RIG *rig, vfo_t vfo, int ch)
+{
+    int retval;
+    char cmd[32];
+
+    if (ch < 1 || ch > 8)
+    {
+        rig_debug(RIG_DEBUG_ERR, "%s: expected 1<=ch<=8, got %d\n", __func__, ch);
+        return (-RIG_EINVAL);
+    }
+
+    sprintf(cmd, "DAMP%d00000;", ch);
+    retval = kenwood_transaction(rig, cmd, NULL, 0);
+    return retval;
+}
+
+int k4_stop_voice_mem(RIG *rig, vfo_t vfo)
+{
+    int retval;
+    retval = kenwood_transaction(rig, "DA0;", NULL, 0);
+    return retval;
+}
+
+int k4_stop_morse(RIG *rig, vfo_t vfo)
+{
+    int retval;
+    retval = kenwood_transaction(rig, "KY @;", NULL, 0);
+    return retval;
+}
+
+int k3_stop_morse(RIG *rig, vfo_t vfo)
+{
+    int retval;
+    char cmd[32];
+    SNPRINTF(cmd, sizeof(cmd), "KY %c;", 0x04);
+    retval = kenwood_transaction(rig, cmd, NULL, 0);
+    return retval;
+}
