@@ -20,8 +20,7 @@
  *
  */
 
-#include <hamlib/config.h>
-
+#include <stdint.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <math.h>
@@ -30,7 +29,6 @@
 #include "hamlib/rig.h"
 #include "kenwood.h"
 #include "th.h"
-#include "serial.h"
 #include "misc.h"
 #include "num_stdio.h"
 
@@ -74,8 +72,8 @@ th_decode_event(RIG *rig)
         int step, shift, rev, tone, ctcss, tonefq, ctcssfq;
 
         retval = num_sscanf(asyncbuf,
-                            "BUF %d,%"SCNfreq",%X,%d,%d,%d,%d,,%d,,%d,%"SCNfreq",%d",
-                            &vfo, &freq, &step, &shift, &rev, &tone,
+                            "BUF %u,%"SCNfreq",%X,%d,%d,%d,%d,,%d,,%d,%"SCNfreq",%d",
+                            &vfo, &freq, (unsigned int *)&step, &shift, &rev, &tone,
                             &ctcss, &tonefq, &ctcssfq, &offset, &mode);
 
         if (retval != 11)
@@ -89,7 +87,7 @@ th_decode_event(RIG *rig)
         vfo = (vfo == 0) ? RIG_VFO_A : RIG_VFO_B;
         mode = (mode == 0) ? RIG_MODE_FM : RIG_MODE_AM;
 
-        rig_debug(RIG_DEBUG_TRACE, "%s: Buffer (vfo %d, freq %"PRIfreq" Hz, mode %d)\n",
+        rig_debug(RIG_DEBUG_TRACE, "%s: Buffer (vfo %u, freq %"PRIfreq" Hz, mode %d)\n",
                   __func__, vfo, freq, mode);
 
         /* Callback execution */
@@ -115,7 +113,7 @@ th_decode_event(RIG *rig)
 
         vfo_t vfo;
         int lev;
-        retval = sscanf(asyncbuf, "SM %d,%d", &vfo, &lev);
+        retval = sscanf(asyncbuf, "SM %u,%d", &vfo, &lev);
 
         if (retval != 2)
         {
@@ -146,7 +144,7 @@ th_decode_event(RIG *rig)
         vfo_t vfo;
         int busy;
 
-        retval = sscanf(asyncbuf, "BY %d,%d", &vfo, &busy);
+        retval = sscanf(asyncbuf, "BY %u,%d", &vfo, &busy);
 
         if (retval != 2)
         {
@@ -166,7 +164,7 @@ th_decode_event(RIG *rig)
     {
 
         vfo_t vfo;
-        retval = sscanf(asyncbuf, "BC %d", &vfo);
+        retval = sscanf(asyncbuf, "BC %u", &vfo);
 
         if (retval != 1)
         {
@@ -177,7 +175,7 @@ th_decode_event(RIG *rig)
 
         vfo = (vfo == 0) ? RIG_VFO_A : RIG_VFO_B;
 
-        rig_debug(RIG_DEBUG_TRACE, "%s: VFO event - vfo = %d\n", __func__, vfo);
+        rig_debug(RIG_DEBUG_TRACE, "%s: VFO event - vfo = %u\n", __func__, vfo);
 
         if (rig->callbacks.vfo_event)
         {
@@ -216,7 +214,7 @@ th_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 
     rig_debug(RIG_DEBUG_TRACE, "%s: called %s\n", __func__, rig_strvfo(vfo));
 
-    if (vfo != RIG_VFO_CURR && vfo != rig->state.current_vfo)
+    if (vfo != RIG_VFO_CURR && vfo != STATE(rig)->current_vfo)
     {
         return kenwood_wrong_vfo(__func__, vfo);
     }
@@ -239,7 +237,6 @@ th_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
     step = freq_sent >= MHz(470) ? 4 : step;
     freq_sent = freq_sent >= MHz(470) ? (round(freq_sent / 10000) * 10000) :
                 freq_sent;
-    // cppcheck-suppress *
     SNPRINTF(buf, sizeof(buf), "FQ %011"PRIll",%X\r", (int64_t) freq_sent, step);
 
     return kenwood_transaction(rig, buf, buf, strlen(buf));
@@ -257,7 +254,7 @@ th_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
 
     rig_debug(RIG_DEBUG_TRACE, "%s: called\n", __func__);
 
-    if (vfo != RIG_VFO_CURR && vfo != rig->state.current_vfo)
+    if (vfo != RIG_VFO_CURR && vfo != STATE(rig)->current_vfo)
     {
         return kenwood_wrong_vfo(__func__, vfo);
     }
@@ -271,7 +268,7 @@ th_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
         return retval;
     }
 
-    retval = num_sscanf(buf, "FQ %"SCNfreq",%x", freq, &step);
+    retval = num_sscanf(buf, "FQ %"SCNfreq",%x", freq, (unsigned *)&step);
 
     if (retval != 2)
     {
@@ -295,7 +292,7 @@ th_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
 
     rig_debug(RIG_DEBUG_TRACE, "%s: called\n", __func__);
 
-    if (vfo != RIG_VFO_CURR && vfo != rig->state.current_vfo)
+    if (vfo != RIG_VFO_CURR && vfo != STATE(rig)->current_vfo)
     {
         return kenwood_wrong_vfo(__func__, vfo);
     }
@@ -351,7 +348,7 @@ th_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
 
     rig_debug(RIG_DEBUG_TRACE, "%s: called\n", __func__);
 
-    if (vfo != RIG_VFO_CURR && vfo != rig->state.current_vfo)
+    if (vfo != RIG_VFO_CURR && vfo != STATE(rig)->current_vfo)
     {
         return kenwood_wrong_vfo(__func__, vfo);
     }
@@ -524,7 +521,7 @@ th_get_vfo_char(RIG *rig, vfo_t *vfo, char *vfoch)
         break;
 
     case 6: /*intended for D700 BC 0,0*/
-        if ((buf[0] == 'B') && (buf[1] == 'C') && (buf[2] == ' ') && (buf[4] = ','))
+        if ((buf[0] == 'B') && (buf[1] == 'C') && (buf[2] == ' ') && (buf[4] == ','))
         {
             vfoc = buf[3];
         }
@@ -627,7 +624,8 @@ th_get_vfo(RIG *rig, vfo_t *vfo)
  */
 int tm_set_vfo_bc2(RIG *rig, vfo_t vfo)
 {
-    struct kenwood_priv_data *priv = rig->state.priv;
+    struct rig_state *rs = STATE(rig);
+    const struct kenwood_priv_data *priv = rs->priv;
     char cmd[16];
     int vfonum, txvfonum, vfomode = 0;
     int retval;
@@ -641,14 +639,14 @@ int tm_set_vfo_bc2(RIG *rig, vfo_t vfo)
         vfonum = 0;
         /* put back split mode when toggling */
         txvfonum = (priv->split == RIG_SPLIT_ON &&
-                    rig->state.tx_vfo == RIG_VFO_B) ? 1 : vfonum;
+                    rs->tx_vfo == RIG_VFO_B) ? 1 : vfonum;
         break;
 
     case RIG_VFO_B:
         vfonum = 1;
         /* put back split mode when toggling */
         txvfonum = (priv->split == RIG_SPLIT_ON &&
-                    rig->state.tx_vfo == RIG_VFO_A) ? 0 : vfonum;
+                    rs->tx_vfo == RIG_VFO_A) ? 0 : vfonum;
         break;
 
     case RIG_VFO_MEM:
@@ -666,7 +664,7 @@ int tm_set_vfo_bc2(RIG *rig, vfo_t vfo)
         break;
 
     default:
-        rig_debug(RIG_DEBUG_ERR, "%s: Unsupported VFO %d\n", __func__, vfo);
+        rig_debug(RIG_DEBUG_ERR, "%s: Unsupported VFO %u\n", __func__, vfo);
         return -RIG_EVFO;
     }
 
@@ -690,7 +688,7 @@ int tm_set_vfo_bc2(RIG *rig, vfo_t vfo)
 
 int th_set_split_vfo(RIG *rig, vfo_t vfo, split_t split, vfo_t txvfo)
 {
-    struct kenwood_priv_data *priv = rig->state.priv;
+    struct kenwood_priv_data *priv = STATE(rig)->priv;
     char vfobuf[16];
     int vfonum, txvfonum;
     int retval;
@@ -761,7 +759,7 @@ int th_set_split_vfo(RIG *rig, vfo_t vfo, split_t split, vfo_t txvfo)
 
 int th_get_split_vfo(RIG *rig, vfo_t vfo, split_t *split, vfo_t *txvfo)
 {
-    struct kenwood_priv_data *priv = rig->state.priv;
+    struct kenwood_priv_data *priv = STATE(rig)->priv;
     char buf[10];
     int retval;
 
@@ -1128,12 +1126,13 @@ th_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
     char vch, buf[10], ackbuf[20];
     int retval, v;
     unsigned int l;
+    struct rig_state *rs = STATE(rig);
 
     vfo_t tvfo;
 
     rig_debug(RIG_DEBUG_TRACE, "%s: called\n", __func__);
 
-    tvfo = (vfo == RIG_VFO_CURR) ? rig->state.current_vfo : vfo;
+    tvfo = (vfo == RIG_VFO_CURR) ? rs->current_vfo : vfo;
 
     switch (tvfo)
     {
@@ -1253,7 +1252,7 @@ th_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
             return retval;
         }
 
-        if (ackbuf[4] < '0' || ackbuf[4] > '9')
+        if (ackbuf[4] < '0' || ackbuf[4] > '8')
         {
             return -RIG_EPROTO;
         }
@@ -1269,7 +1268,7 @@ th_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
             return retval;
         }
 
-        if (ackbuf[4] < '0' || ackbuf[4] > '9')
+        if (ackbuf[4] < '0' || ackbuf[4] > '8')
         {
             return -RIG_EPROTO;
         }
@@ -1280,7 +1279,7 @@ th_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
         }
         else
         {
-            val->i = rig->state.attenuator[ackbuf[4] - '1'];
+            val->i = rs->attenuator[ackbuf[4] - '1'];
         }
 
         break;
@@ -1321,7 +1320,7 @@ int th_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
 
     rig_debug(RIG_DEBUG_TRACE, "%s: called\n", __func__);
 
-    tvfo = (vfo == RIG_VFO_CURR) ? rig->state.current_vfo : vfo;
+    tvfo = (vfo == RIG_VFO_CURR) ? STATE(rig)->current_vfo : vfo;
 
     switch (tvfo)
     {
@@ -1395,7 +1394,7 @@ int th_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
 int
 th_set_ctcss_tone(RIG *rig, vfo_t vfo, tone_t tone)
 {
-    const struct rig_caps *caps;
+    struct rig_caps *caps;
     char tonebuf[16];
     int i;
 
@@ -1456,7 +1455,7 @@ th_get_ctcss_tone(RIG *rig, vfo_t vfo, tone_t *tone)
     /* verify tone index for TH-7DA rig */
     if (tone_idx == 0 || tone_idx == 2 || tone_idx > 39)
     {
-        rig_debug(RIG_DEBUG_ERR, "%s: Unexpected CTCSS tone no (%04d)\n",
+        rig_debug(RIG_DEBUG_ERR, "%s: Unexpected CTCSS tone no (%04u)\n",
                   __func__, tone_idx);
         return -RIG_EPROTO;
     }
@@ -1473,7 +1472,7 @@ th_get_ctcss_tone(RIG *rig, vfo_t vfo, tone_t *tone)
 int
 th_set_ctcss_sql(RIG *rig, vfo_t vfo, tone_t tone)
 {
-    const struct rig_caps *caps;
+    struct rig_caps *caps;
     char tonebuf[16];
     int i;
 
@@ -1534,7 +1533,7 @@ th_get_ctcss_sql(RIG *rig, vfo_t vfo, tone_t *tone)
     /* verify tone index for TH-7DA rig */
     if (tone_idx == 0 || tone_idx == 2 || tone_idx > 39)
     {
-        rig_debug(RIG_DEBUG_ERR, "%s: Unexpected CTCSS no (%04d)\n",
+        rig_debug(RIG_DEBUG_ERR, "%s: Unexpected CTCSS no (%04u)\n",
                   __func__, tone_idx);
         return -RIG_EPROTO;
     }
@@ -1555,7 +1554,7 @@ th_get_ctcss_sql(RIG *rig, vfo_t vfo, tone_t *tone)
 int
 th_set_dcs_sql(RIG *rig, vfo_t vfo, tone_t code)
 {
-    const struct rig_caps *caps;
+    struct rig_caps *caps;
     char codebuf[16];
     int i, retval;
 
@@ -1703,7 +1702,7 @@ th_set_mem(RIG *rig, vfo_t vfo, int ch)
 
     rig_debug(RIG_DEBUG_TRACE, "%s: called\n", __func__);
 
-    tvfo = (vfo == RIG_VFO_CURR) ? rig->state.current_vfo : vfo;
+    tvfo = (vfo == RIG_VFO_CURR) ? STATE(rig)->current_vfo : vfo;
 
     switch (tvfo)
     {
@@ -1744,7 +1743,7 @@ th_get_mem(RIG *rig, vfo_t vfo, int *ch)
     rig_debug(RIG_DEBUG_TRACE, "%s: called\n", __func__);
 
     /* store current VFO */
-    cvfo = rig->state.current_vfo;
+    cvfo = STATE(rig)->current_vfo;
 
     /* check if we should switch VFO */
     if (cvfo != RIG_VFO_MEM)
@@ -1869,7 +1868,7 @@ int th_vfo_op(RIG *rig, vfo_t vfo, vfo_op_t op)
 {
     rig_debug(RIG_DEBUG_TRACE, "%s: called\n", __func__);
 
-    if (vfo != RIG_VFO_CURR && vfo != rig->state.current_vfo)
+    if (vfo != RIG_VFO_CURR && vfo != STATE(rig)->current_vfo)
     {
         return kenwood_wrong_vfo(__func__, vfo);
     }
@@ -2056,7 +2055,7 @@ int th_get_channel(RIG *rig, vfo_t vfo, channel_t *chan, int read_only)
     chan->flags = lockout ? RIG_CHFLAG_SKIP : 0;
     chan->freq = freq;
     chan->vfo = RIG_VFO_MEM;
-    chan->tuning_step = rig->state.tuning_steps[step].ts;
+    chan->tuning_step = STATE(rig)->tuning_steps[step].ts;
 
     if (priv->mode_table)
     {
@@ -2231,8 +2230,8 @@ int th_set_channel(RIG *rig, vfo_t vfo, const channel_t *chan)
 
     channel_num = chan->channel_num;
 
-    for (step = 0; rig->state.tuning_steps[step].ts != 0; step++)
-        if (chan->tuning_step <= rig->state.tuning_steps[step].ts)
+    for (step = 0; STATE(rig)->tuning_steps[step].ts != 0; step++)
+        if (chan->tuning_step <= STATE(rig)->tuning_steps[step].ts)
         {
             break;
         }
@@ -2501,7 +2500,7 @@ int th_set_ant(RIG *rig, vfo_t vfo, ant_t ant, value_t option)
 {
     char cmd[6];
 
-    rig_debug(RIG_DEBUG_TRACE, "%s: ant = %d\n", __func__, ant);
+    rig_debug(RIG_DEBUG_TRACE, "%s: ant = %u\n", __func__, ant);
 
     switch (ant)
     {
@@ -2550,7 +2549,7 @@ int th_get_ant(RIG *rig, vfo_t vfo, ant_t dummy, value_t *option,
 
     *ant_curr = RIG_ANT_N(buf[4] - '0');
 
-    rig_debug(RIG_DEBUG_TRACE, "%s: ant = %d\n", __func__, *ant_curr);
+    rig_debug(RIG_DEBUG_TRACE, "%s: ant = %u\n", __func__, *ant_curr);
 
     return RIG_OK;
 }
