@@ -19,8 +19,6 @@
  *
  */
 
-#include <hamlib/config.h>
-
 #include <stdlib.h>
 
 #include <hamlib/rig.h>
@@ -79,7 +77,7 @@ static struct kenwood_priv_caps  thd7_priv_caps  =
  *
  * http://www.qsl.net/ta1dx/kenwood/thd7kom.htm
  */
-const struct rig_caps thd7a_caps =
+struct rig_caps thd7a_caps =
 {
     RIG_MODEL(RIG_MODEL_THD7A),
     .model_name = "TH-D7A",
@@ -112,7 +110,9 @@ const struct rig_caps thd7a_caps =
     {
 #include "level_gran_kenwood.h"
     },
-    .parm_gran =  {},
+    .parm_gran =  {
+        [PARM_BACKLIGHT] = {.min = {.f = 0.0f}, .max = {.f = 1.0f}, .step = {.f = 1.0f / 255.0f}},
+    },
     .ctcss_list =  kenwood38_ctcss_list,
     .dcs_list =  NULL,
     .preamp =   { RIG_DBLST_END, },
