@@ -19,8 +19,6 @@
  *
  */
 
-#include <hamlib/config.h>
-
 #include <stdlib.h>
 
 #include <hamlib/rig.h>
@@ -51,7 +49,7 @@ static const struct pcr_priv_caps pcr1500_priv =
 /*
  * IC PCR1500 rigs capabilities.
  */
-const struct rig_caps pcr1500_caps =
+struct rig_caps pcr1500_caps =
 {
     RIG_MODEL(RIG_MODEL_PCR1500),
     .model_name     = "IC-PCR1500",
@@ -85,7 +83,6 @@ const struct rig_caps pcr1500_caps =
     .has_set_parm       = RIG_PARM_NONE,
 
     .level_gran = {
-        // cppcheck-suppress *
         [LVL_RAWSTR] = { .min = { .i = 0 }, .max = { .i = 255 }, .step = { .i = 1 } },
         [LVL_NR] = { .min = { .f = 0 }, .max = { .f = 16.0 }, .step = { .f = 1.0 } },
         /* XXX check this */
