@@ -18,8 +18,6 @@
  *
  */
 
-#include <hamlib/config.h>
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>  /* String function definitions */
@@ -27,9 +25,6 @@
 #include "hamlib/rig.h"
 #include "serial.h"
 #include "misc.h"
-#include "cal.h"
-#include "register.h"
-#include "token.h"
 
 #include "ra37xx.h"
 
@@ -73,8 +68,9 @@ const struct confparams ra37xx_cfg_params[] =
 static int ra37xx_one_transaction(RIG *rig, const char *cmd, char *data,
                                   int *data_len)
 {
-    struct ra37xx_priv_data *priv = (struct ra37xx_priv_data *)rig->state.priv;
-    struct rig_state *rs = &rig->state;
+    const struct ra37xx_priv_data *priv = (struct ra37xx_priv_data *)
+                                          STATE(rig)->priv;
+    hamlib_port_t *rp = RIGPORT(rig);
     char cmdbuf[BUFSZ];
     char respbuf[BUFSZ];
     int retval;
@@ -99,9 +95,9 @@ static int ra37xx_one_transaction(RIG *rig, const char *cmd, char *data,
         SNPRINTF(cmdbuf, sizeof(cmdbuf), SOM "%s" EOM, cmd);
     }
 
-    rig_flush(&rs->rigport);
+    rig_flush(rp);
 
-    retval = write_block(&rs->rigport, (unsigned char *) cmdbuf, strlen(cmdbuf));
+    retval = write_block(rp, (unsigned char *) cmdbuf, strlen(cmdbuf));
 
     if (retval != RIG_OK)
     {
@@ -117,7 +113,7 @@ static int ra37xx_one_transaction(RIG *rig, const char *cmd, char *data,
 
     do
     {
-        retval = read_string(&rs->rigport, (unsigned char *) respbuf, BUFSZ, EOM,
+        retval = read_string(rp, (unsigned char *) respbuf, BUFSZ, EOM,
                              strlen(EOM), 0, 1);
 
         if (retval < 0)
@@ -128,7 +124,7 @@ static int ra37xx_one_transaction(RIG *rig, const char *cmd, char *data,
         /* drop short/invalid packets */
         if (retval <= pkt_header_len + 1 || respbuf[0] != '\x0a')
         {
-            if (!rig_check_cache_timeout(&tv, rs->rigport.timeout))
+            if (!rig_check_cache_timeout(&tv, rp->timeout))
             {
                 continue;
             }
@@ -141,7 +137,7 @@ static int ra37xx_one_transaction(RIG *rig, const char *cmd, char *data,
         /* drop other receiver id, and "pause" (empty) packets */
         if ((priv->receiver_id != -1 && (respbuf[1] - '0') != priv->receiver_id))
         {
-            if (!rig_check_cache_timeout(&tv, rs->rigport.timeout))
+            if (!rig_check_cache_timeout(&tv, rp->timeout))
             {
                 continue;
             }
@@ -169,7 +165,7 @@ static int ra37xx_one_transaction(RIG *rig, const char *cmd, char *data,
             rig_debug(RIG_DEBUG_WARN, "%s: unexpected revertive frame\n",
                       __func__);
 
-            if (!rig_check_cache_timeout(&tv, rs->rigport.timeout))
+            if (!rig_check_cache_timeout(&tv, rp->timeout))
             {
                 continue;
             }
@@ -193,7 +189,7 @@ static int ra37xx_transaction(RIG *rig, const char *cmd, char *data,
 {
     int retval, retry;
 
-    retry = rig->state.rigport.retry;
+    retry = RIGPORT(rig)->retry;
 
     do
     {
@@ -219,16 +215,16 @@ int ra37xx_init(RIG *rig)
         return -RIG_EINVAL;
     }
 
-    rig->state.priv = (struct ra37xx_priv_data *)calloc(1, sizeof(
-                          struct ra37xx_priv_data));
+    STATE(rig)->priv = (struct ra37xx_priv_data *)calloc(1, sizeof(
+                           struct ra37xx_priv_data));
 
-    if (!rig->state.priv)
+    if (!STATE(rig)->priv)
     {
         /* whoops! memory shortage! */
         return -RIG_ENOMEM;
     }
 
-    priv = rig->state.priv;
+    priv = STATE(rig)->priv;
 
     priv->receiver_id = -1;
 
@@ -244,22 +240,23 @@ int ra37xx_cleanup(RIG *rig)
         return -RIG_EINVAL;
     }
 
-    if (rig->state.priv)
+    if (STATE(rig)->priv)
     {
-        free(rig->state.priv);
+        free(STATE(rig)->priv);
     }
 
-    rig->state.priv = NULL;
+    STATE(rig)->priv = NULL;
 
     return RIG_OK;
 }
 
 /*
- * Assumes rig!=NULL, rig->state.priv!=NULL
+ * Assumes rig!=NULL, STATE(rig)->priv!=NULL
  */
-int ra37xx_set_conf2(RIG *rig, token_t token, const char *val, int val_len)
+int ra37xx_set_conf2(RIG *rig, hamlib_token_t token, const char *val,
+                     int val_len)
 {
-    struct ra37xx_priv_data *priv = (struct ra37xx_priv_data *)rig->state.priv;
+    struct ra37xx_priv_data *priv = (struct ra37xx_priv_data *)STATE(rig)->priv;
     int receiver_id;
 
     switch (token)
@@ -282,19 +279,20 @@ int ra37xx_set_conf2(RIG *rig, token_t token, const char *val, int val_len)
     return RIG_OK;
 }
 
-int ra37xx_set_conf(RIG *rig, token_t token, const char *val)
+int ra37xx_set_conf(RIG *rig, hamlib_token_t token, const char *val)
 {
     return ra37xx_set_conf2(rig, token, val, 128);
 }
 
 /*
  * assumes rig!=NULL,
- * Assumes rig!=NULL, rig->state.priv!=NULL
+ * Assumes rig!=NULL, STATE(rig)->priv!=NULL
  *  and val points to a buffer big enough to hold the conf value.
  */
-int ra37xx_get_conf2(RIG *rig, token_t token, char *val, int val_len)
+int ra37xx_get_conf2(RIG *rig, hamlib_token_t token, char *val, int val_len)
 {
-    struct ra37xx_priv_data *priv = (struct ra37xx_priv_data *)rig->state.priv;
+    const struct ra37xx_priv_data *priv = (struct ra37xx_priv_data *)
+                                          STATE(rig)->priv;
 
     switch (token)
     {
@@ -309,7 +307,7 @@ int ra37xx_get_conf2(RIG *rig, token_t token, char *val, int val_len)
     return RIG_OK;
 }
 
-int ra37xx_get_conf(RIG *rig, token_t token, char *val)
+int ra37xx_get_conf(RIG *rig, hamlib_token_t token, char *val)
 {
     return ra37xx_get_conf2(rig, token, val, 128);
 }
@@ -374,7 +372,7 @@ int ra37xx_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
  */
 int ra37xx_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
 {
-    //struct ra37xx_priv_data *priv = (struct ra37xx_priv_data*)rig->state.priv;
+    //struct ra37xx_priv_data *priv = (struct ra37xx_priv_data*)STATE(rig)->priv;
     int ra_mode, widthtype, widthnum = 0;
     char buf[BUFSZ];
 
@@ -634,7 +632,7 @@ int ra37xx_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
         }
 
         sscanf(resbuf + 5, "%d", &i);
-        val->i = i ? rig->state.preamp[0] : 0;
+        val->i = i ? STATE(rig)->preamp[0] : 0;
         break;
 
     case RIG_LEVEL_RAWSTR:
