@@ -32,8 +32,6 @@
  * implement dual VFO & split capability
  */
 
-#include <hamlib/config.h>
-
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
@@ -125,12 +123,12 @@ static int tt538_set_func(RIG *rig, vfo_t vfo, setting_t func, int status);
  * Protocol is documented at
  *      http://www.rfsquared.com/
  */
-const struct rig_caps tt538_caps =
+struct rig_caps tt538_caps =
 {
     RIG_MODEL(RIG_MODEL_TT538),
     .model_name = "TT-538 Jupiter",
     .mfg_name =  "Ten-Tec",
-    .version =  "20221205.0",
+    .version =  "20240913.0",
     .copyright =  "LGPL",
     .status =  RIG_STATUS_STABLE,
     .rig_type =  RIG_TYPE_TRANSCEIVER,
@@ -231,7 +229,7 @@ const struct rig_caps tt538_caps =
     .hamlib_check_rig_caps = HAMLIB_CHECK_RIG_CAPS
 };
 
-/* Filter table for 538 reciver support. */
+/* Filter table for 538 receiver support. */
 static int tt538_rxFilter[] =
 {
     8000, 6000, 5700, 5400, 5100, 4800, 4500, 4200, 3900, 3600, 3300,
@@ -259,7 +257,7 @@ static int tt538_transaction(RIG *rig, const char *cmd, int cmd_len,
 
     retval = tentec_transaction(rig, cmd, cmd_len, data, data_len);
 
-    if (retval == RIG_OK)
+    if (data == NULL || (data != NULL && data_len > 0))
     {
         return retval;
     }
@@ -293,16 +291,16 @@ int tt538_init(RIG *rig)
 {
     struct tt538_priv_data *priv;
 
-    rig->state.priv = (struct tt538_priv_data *) calloc(1, sizeof(
-                          struct tt538_priv_data));
+    STATE(rig)->priv = (struct tt538_priv_data *) calloc(1, sizeof(
+                           struct tt538_priv_data));
 
-    if (!rig->state.priv)
+    if (!STATE(rig)->priv)
     {
         /* whoops! memory shortage! */
         return -RIG_ENOMEM;
     }
 
-    priv = rig->state.priv;
+    priv = STATE(rig)->priv;
 
     memset(priv, 0, sizeof(struct tt538_priv_data));
 
@@ -317,7 +315,7 @@ int tt538_init(RIG *rig)
 
 static char which_vfo(const RIG *rig, vfo_t vfo)
 {
-    struct tt538_priv_data *priv = (struct tt538_priv_data *)rig->state.priv;
+    const struct tt538_priv_data *priv = (struct tt538_priv_data *)STATE(rig)->priv;
 
     if (vfo == RIG_VFO_CURR)
     {
@@ -342,7 +340,8 @@ static char which_vfo(const RIG *rig, vfo_t vfo)
 int tt538_get_vfo(RIG *rig, vfo_t *vfo)
 {
 
-    struct tt538_priv_data *priv = (struct tt538_priv_data *) rig->state.priv;
+    const struct tt538_priv_data *priv = (struct tt538_priv_data *) STATE(
+            rig)->priv;
     *vfo = priv->vfo_curr;
     return RIG_OK;
 }
@@ -353,7 +352,7 @@ int tt538_get_vfo(RIG *rig, vfo_t *vfo)
  */
 int tt538_set_vfo(RIG *rig, vfo_t vfo)
 {
-    struct tt538_priv_data *priv = (struct tt538_priv_data *)rig->state.priv;
+    struct tt538_priv_data *priv = (struct tt538_priv_data *)STATE(rig)->priv;
 
     if (vfo == RIG_VFO_CURR)
     {
@@ -438,7 +437,7 @@ int tt538_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
 
 /*
  * tt538_set_freq
- * assumes rig!=NULL, rig->state.priv!=NULL
+ * assumes rig!=NULL, STATE(rig)->priv!=NULL
  * assumes priv->mode in AM,CW,LSB or USB.
  */
 
@@ -446,19 +445,34 @@ int tt538_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 {
     unsigned char bytes[4];
     unsigned char cmdbuf[16];
+    int retval = -RIG_EINTERNAL;
+    int retry = STATE(rig)->retry;
+    freq_t freqchk = 0;
 
     /* Freq is 4 bytes long, MSB sent first. */
     bytes[3] = ((unsigned int) freq >> 24) & 0xff;
     bytes[2] = ((unsigned int) freq >> 16) & 0xff;
     bytes[1] = ((unsigned int) freq >>  8) & 0xff;
-    bytes[0] = ((unsigned int) freq      ) & 0xff;
+    bytes[0] = ((unsigned int) freq) & 0xff;
 
-    SNPRINTF((char *) cmdbuf, sizeof(cmdbuf), "*%c%c%c%c%c" EOM,
-             which_vfo(rig, vfo),
-             bytes[3], bytes[2], bytes[1], bytes[0]);
+    do
+    {
+        SNPRINTF((char *) cmdbuf, sizeof(cmdbuf), "*%c%c%c%c%c" EOM,
+                 which_vfo(rig, vfo),
+                 bytes[3], bytes[2], bytes[1], bytes[0]);
 
-    return tt538_transaction(rig, (char *) cmdbuf, 6,  NULL,
-                             NULL);
+        retval = tt538_transaction(rig, (char *) cmdbuf, 6,  NULL,
+                                   NULL);
+
+        if (retval != RIG_OK) { continue; }
+
+        retval = tt538_get_freq(rig, vfo, &freqchk);
+
+        if (retval != RIG_OK) { return retval; }
+    }
+    while (freq != freqchk && --retry >= 0);
+
+    return retval;
 }
 
 /*
@@ -636,7 +650,8 @@ int tt538_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
     unsigned char cmdbuf[32], respbuf[32], ttmode;
     int resp_len, retval;
 
-    struct tt538_priv_data *priv = (struct tt538_priv_data *) rig->state.priv;
+    const struct tt538_priv_data *priv = (struct tt538_priv_data *) STATE(
+            rig)->priv;
 
     /* Query mode for both VFOs. */
     SNPRINTF((char *) cmdbuf, sizeof(cmdbuf), "?M" EOM);
