@@ -1,5 +1,6 @@
 /*
  *  Hamlib TenTenc backend - TT-565 description
+ *  Copyright (c) 2024      by Michael Black W9MDB
  *  Copyright (c) 2004-2011 by Martin Ewing
  *  Copyright (c) 2004-2010 by Stephane Fillod
  *
@@ -65,21 +66,18 @@
  * This backend supports the Ten-Tec Orion (565) and Orion II (566) transceivers.
  * \n This backend tested mostly with firmware versions 1.372 and 2.062a
  */
-#include <hamlib/config.h>
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <stdint.h>
 #include <ctype.h>
 #include <string.h>  /* String function definitions */
 #include <math.h>
 
 #include <hamlib/rig.h>
-#include "bandplan.h"
 #include "serial.h"
 #include "misc.h"
-#include "idx_builtin.h"
 #include "orion.h"
-#include <cal.h>
 
 #ifdef TT565_TIME
 /**
@@ -104,7 +102,7 @@ double tt565_timenow()  /* returns current time in secs+microsecs */
  *
  * This is the basic I/O transaction to/from the Orion.
  * \n Read variable number of bytes, up to buffer size, if data & data_len != NULL.
- * \n We assume that rig!=NULL, rig->state!= NULL.
+ * \n We assume that rig!=NULL, STATE(rig)!= NULL.
  * Otherwise, you'll get a nice seg fault. You've been warned!
  */
 
@@ -112,11 +110,12 @@ static int tt565_transaction(RIG *rig, const char *cmd, int cmd_len, char *data,
                              int *data_len)
 {
     int data_len_init, itry;
-    struct rig_state *rs;
+    hamlib_port_t *rp = RIGPORT(rig);
     static int passcount = 0;
 #ifdef TT565_TIME
     double ft1, ft2;
 #endif
+    MUTEX_LOCK(mutex);
     passcount++;        // for debugging
     /* Capture buffer length for possible read re-try. */
     data_len_init = (data && data_len) ? *data_len : 0;
@@ -125,12 +124,12 @@ static int tt565_transaction(RIG *rig, const char *cmd, int cmd_len, char *data,
     for (itry = 0; itry < rig->caps->retry; itry++)
     {
         int retval;
-        rs = &rig->state;
-        rig_flush(&rs->rigport); /* discard pending i/p */
-        retval = write_block(&rs->rigport, (unsigned char *) cmd, cmd_len);
+        rig_flush(rp); /* discard pending i/p */
+        retval = write_block(rp, (unsigned char *) cmd, cmd_len);
 
         if (retval != RIG_OK)
         {
+            MUTEX_UNLOCK(mutex);
             return retval;
         }
 
@@ -141,9 +140,11 @@ static int tt565_transaction(RIG *rig, const char *cmd, int cmd_len, char *data,
             if ((*cmd != '*') && (*cmd != '/'))
             {
                 rig_debug(RIG_DEBUG_ERR, "%s: cmd reject 1\n", __func__);
+                MUTEX_UNLOCK(mutex);
                 return -RIG_ERJCTED;
             }
 
+            MUTEX_UNLOCK(mutex);
             return RIG_OK;  /* normal exit if write, but no read */
         }
 
@@ -151,35 +152,42 @@ static int tt565_transaction(RIG *rig, const char *cmd, int cmd_len, char *data,
         ft1 = tt565_timenow();
 #endif
         *data_len = data_len_init;  /* restore orig. buffer length */
-        *data_len = read_string(&rs->rigport, (unsigned char *) data, *data_len,
-                                EOM, strlen(EOM), 0, 1);
+        read_string(rp, (unsigned char *) data, *data_len,
+                    EOM, strlen(EOM), 0, 1);
+        *data_len = strlen(data);
+        rig_debug(RIG_DEBUG_ERR, "%s: data_len = %d\n", __func__, *data_len);
 
         if (!strncmp(data, "Z!", 2))     // command unrecognized??
         {
             rig_debug(RIG_DEBUG_ERR, "%s: cmd reject 2\n", __func__);
+            MUTEX_UNLOCK(mutex);
             return -RIG_ERJCTED;    // what is a better error return?
         }
 
         /* XX and ?V are oddball commands.  Thanks, Ten-Tec! */
         if (!strncmp(cmd, "XX", 2)) // Was it a firmware reset cmd?
         {
+            MUTEX_UNLOCK(mutex);
             return RIG_OK;      // Then we accept the response.
         }
 
         if (!strncmp(cmd, "?V", 2)) // Was it a read firmware version cmd?
         {
+            MUTEX_UNLOCK(mutex);
             return RIG_OK;      // ditto
         }
 
         if (cmd[0] != '?')          // was this a read cmd?
         {
             rig_debug(RIG_DEBUG_ERR, "%s: cmd reject 3\n", __func__);
+            MUTEX_UNLOCK(mutex);
             return -RIG_ERJCTED;    // No, but it should have been!
         }
         else                            // Yes, it was a 'read', phew!
         {
-            if (!strncmp(data + 1, cmd + 1, cmd_len - 2)) //response matches cmd?
+            if (strncmp(data + 1, cmd + 1, cmd_len - 2) == 0) //response matches cmd?
             {
+                MUTEX_UNLOCK(mutex);
                 return RIG_OK;  // all is well, normal exit
             }
             else
@@ -192,7 +200,7 @@ static int tt565_transaction(RIG *rig, const char *cmd, int cmd_len, char *data,
                           "** retry after delay (io=%d, retry=%d) **\n",
                           passcount, itry);
                 *data_len = data_len_init;  /* restore orig. buffer length */
-                read_string(&rs->rigport, (unsigned char *) data, *data_len,
+                read_string(rp, (unsigned char *) data, *data_len,
                             EOM, strlen(EOM), 0, 1);      // purge the input stream...
                 continue;                   // now go retry the full command
             }
@@ -214,6 +222,7 @@ static int tt565_transaction(RIG *rig, const char *cmd, int cmd_len, char *data,
 
     rig_debug(RIG_DEBUG_ERR, "** Ran out of retries io=%d **\n",
               passcount);
+    MUTEX_UNLOCK(mutex);
     return -RIG_ETIMEOUT;
 }
 
@@ -225,12 +234,12 @@ static int tt565_transaction(RIG *rig, const char *cmd, int cmd_len, char *data,
 int tt565_init(RIG *rig)
 {
     struct tt565_priv_data *priv;
-    rig->state.priv = (struct tt565_priv_data *)calloc(1, sizeof(
-                          struct tt565_priv_data));
+    STATE(rig)->priv = (struct tt565_priv_data *)calloc(1, sizeof(
+                           struct tt565_priv_data));
 
-    if (!rig->state.priv) { return -RIG_ENOMEM; } /* no memory available */
+    if (!STATE(rig)->priv) { return -RIG_ENOMEM; } /* no memory available */
 
-    priv = rig->state.priv;
+    priv = STATE(rig)->priv;
 
     memset(priv, 0, sizeof(struct tt565_priv_data));
     priv->ch = 0; /* set arbitrary initial status */
@@ -238,6 +247,14 @@ int tt565_init(RIG *rig)
     return RIG_OK;
 }
 
+int tt565_close(RIG *rig)
+{
+    struct tt565_priv_data *priv = (struct tt565_priv_data *)STATE(rig)->priv;
+    priv->threadrun = 0;
+    pthread_join(priv->threadid, NULL);
+    return RIG_OK;
+}
+
 /**
  * \param rig
  * \brief tt565_cleanup routine
@@ -246,16 +263,50 @@ int tt565_init(RIG *rig)
  */
 int tt565_cleanup(RIG *rig)
 {
-    if (rig->state.priv)
+    if (STATE(rig)->priv)
     {
-        free(rig->state.priv);
+        free(STATE(rig)->priv);
     }
 
-    rig->state.priv = NULL;
+    STATE(rig)->priv = NULL;
 
     return RIG_OK;
 }
 
+static void *read_device(void *p)
+{
+    RIG *rig = p;
+    struct tt565_priv_data *priv = (struct tt565_priv_data *)STATE(rig)->priv;
+
+    priv->threadrun = 1;
+
+    while (priv->threadrun)
+    {
+        tt565_get_freq(rig, RIG_VFO_A, &priv->freqA);
+        tt565_get_mode(rig, RIG_VFO_A, &priv->mode, &priv->width);
+        tt565_get_freq(rig, RIG_VFO_B, &priv->freqB);
+        tt565_get_split_vfo(rig, RIG_VFO_A, &priv->tx_vfo, &priv->split);
+        hl_usleep(100 * 1000);
+    }
+
+    return NULL;
+}
+
+static void start_thread(RIG *rig)
+{
+    struct tt565_priv_data *priv = (struct tt565_priv_data *)STATE(rig)->priv;
+    pthread_attr_t attr;
+    int ret;
+
+    pthread_attr_init(&attr);
+    ret = pthread_create(&priv->threadid, &attr, read_device, rig);
+
+    if (ret != 0)
+    {
+        rig_debug(RIG_DEBUG_ERR, "%s: Orion unable to start thread\n", __func__);
+    }
+}
+
 /**
  * \param rig
  * \brief tt565_open routine
@@ -278,13 +329,15 @@ int tt565_open(RIG *rig)
     if (!strstr(buf, "1."))
     {
         /* Not v1 means probably v2 */
-        memcpy(&rig->state.str_cal, &cal2, sizeof(cal_table_t));
+        memcpy(&STATE(rig)->str_cal, &cal2, sizeof(cal_table_t));
     }
     else
     {
-        memcpy(&rig->state.str_cal, &cal1, sizeof(cal_table_t));
+        memcpy(&STATE(rig)->str_cal, &cal1, sizeof(cal_table_t));
     }
 
+    start_thread(rig);
+
     return RIG_OK;
 }
 
@@ -300,7 +353,7 @@ int tt565_open(RIG *rig)
  */
 static char which_receiver(const RIG *rig, vfo_t vfo)
 {
-    struct tt565_priv_data *priv = (struct tt565_priv_data *)rig->state.priv;
+    const struct tt565_priv_data *priv = (struct tt565_priv_data *)STATE(rig)->priv;
 
     if (vfo == RIG_VFO_CURR)
     {
@@ -329,7 +382,7 @@ static char which_receiver(const RIG *rig, vfo_t vfo)
  */
 static char which_vfo(const RIG *rig, vfo_t vfo)
 {
-    struct tt565_priv_data *priv = (struct tt565_priv_data *)rig->state.priv;
+    const struct tt565_priv_data *priv = (struct tt565_priv_data *)STATE(rig)->priv;
 
     if (vfo == RIG_VFO_CURR)
     {
@@ -355,9 +408,9 @@ static char which_vfo(const RIG *rig, vfo_t vfo)
  * \param rig must != NULL
  * \param vfo RIG_VFO_A or RIG_VFO_B
  * \param freq
- * \brief Set a frequence into the specified VFO
+ * \brief Set a frequency into the specified VFO
  *
- * assumes rig->state.priv!=NULL
+ * assumes STATE(rig)->priv!=NULL
  * \n assumes priv->mode in AM,CW,LSB or USB.
  */
 
@@ -377,7 +430,7 @@ int tt565_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 
     for (i = 0; i < HAMLIB_FRQRANGESIZ; i++)
     {
-        this_range = rig->state.rx_range_list[i];
+        this_range = STATE(rig)->rx_range_list[i];
 
         if (this_range.startf == 0 && this_range.endf == 0)
         {
@@ -386,7 +439,7 @@ int tt565_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 
         /* We don't care about mode setting, but vfo must match. */
         if (freq >= this_range.startf && freq <= this_range.endf &&
-                (this_range.vfo == rig->state.current_vfo))
+                (this_range.vfo == STATE(rig)->current_vfo))
         {
             in_range = TRUE;
             break;
@@ -397,7 +450,6 @@ int tt565_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 
 #ifdef TT565_ASCII_FREQ
     /*  Use ASCII mode to set frequencies */
-    // cppcheck-suppress *
     SNPRINTF(cmdbuf, sizeof(cmdbuf), "*%cF%"PRIll EOM,
              which_vfo(rig, vfo),
              (int64_t)freq);
@@ -421,6 +473,14 @@ int tt565_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 #endif
     retval = tt565_transaction(rig, cmdbuf, strlen(cmdbuf), NULL, NULL);
 
+    if (retval == RIG_OK)
+    {
+        struct tt565_priv_data *priv = (struct tt565_priv_data *)STATE(rig)->priv;
+
+        if (vfo == RIG_VFO_A) { priv->freqA = freq; }
+        else if (vfo == RIG_VFO_B) { priv->freqB = freq; }
+    }
+
     return retval;
 }
 
@@ -432,6 +492,16 @@ int tt565_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
  *
  * Performs query on physical rig
  */
+int tt565_get_freq_cache(RIG *rig, vfo_t vfo, freq_t *freq)
+{
+    struct tt565_priv_data *priv = (struct tt565_priv_data *)STATE(rig)->priv;
+
+    if (vfo == RIG_VFO_B) { *freq = priv->freqB; }
+    else { *freq = priv->freqA; }
+
+    return RIG_OK;
+}
+
 int tt565_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
 {
     int resp_len, retval;
@@ -486,7 +556,7 @@ int tt565_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
  */
 int tt565_set_vfo(RIG *rig, vfo_t vfo)
 {
-    struct tt565_priv_data *priv = (struct tt565_priv_data *)rig->state.priv;
+    struct tt565_priv_data *priv = (struct tt565_priv_data *)STATE(rig)->priv;
 
     if (vfo == RIG_VFO_CURR)
     {
@@ -515,7 +585,7 @@ int tt565_set_vfo(RIG *rig, vfo_t vfo)
  */
 int tt565_get_vfo(RIG *rig, vfo_t *vfo)
 {
-    struct tt565_priv_data *priv = (struct tt565_priv_data *)rig->state.priv;
+    const struct tt565_priv_data *priv = (struct tt565_priv_data *)STATE(rig)->priv;
 
     *vfo = priv->vfo_curr;
 
@@ -574,8 +644,18 @@ static vfo_t tt2vfo(char c)
  * \returns RIG_OK or < 0
  * \brief Get the current split status and Tx vfo selection.
  */
+int tt565_get_split_vfo_cache(RIG *rig, vfo_t vfo, split_t *split,
+                              vfo_t *tx_vfo)
+{
+    struct tt565_priv_data *priv = (struct tt565_priv_data *)STATE(rig)->priv;
+    *split = priv->split;
+    *tx_vfo = priv->tx_vfo;
+    return RIG_OK;
+}
+
 int tt565_get_split_vfo(RIG *rig, vfo_t vfo, split_t *split, vfo_t *tx_vfo)
 {
+    struct tt565_priv_data *priv = (struct tt565_priv_data *)STATE(rig)->priv;
     int resp_len, retval;
     char cmdbuf[TT565_BUFSIZE], respbuf[TT565_BUFSIZE];
     char ttreceiver;
@@ -602,6 +682,9 @@ int tt565_get_split_vfo(RIG *rig, vfo_t vfo, split_t *split, vfo_t *tx_vfo)
 
     *split = ttreceiver == respbuf[5] ? RIG_SPLIT_OFF : RIG_SPLIT_ON;
 
+    priv->tx_vfo = *tx_vfo;
+    priv->split = *split;
+
     return RIG_OK;
 }
 
@@ -622,7 +705,7 @@ int tt565_get_split_vfo(RIG *rig, vfo_t vfo, split_t *split, vfo_t *tx_vfo)
  */
 int tt565_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
 {
-    struct rig_state *rs = &rig->state;
+    struct tt565_priv_data *priv = (struct tt565_priv_data *)STATE(rig)->priv;
     char ttmode, ttreceiver;
     int retval;
     char mdbuf[TT565_BUFSIZE];
@@ -678,7 +761,9 @@ int tt565_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
                 );
     }
 
-    retval = write_block(&rs->rigport, (unsigned char *) mdbuf, strlen(mdbuf));
+    retval = write_block(RIGPORT(rig), (unsigned char *) mdbuf, strlen(mdbuf));
+    priv->mode = mode;
+    priv->width = width;
 
     return retval;
 }
@@ -693,11 +778,23 @@ int tt565_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
  *
  * \remarks Confusion of VFO and Main/Sub TRx/Rx. See tt565_set_mode.
  */
+int tt565_get_mode_cache(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
+{
+    struct tt565_priv_data *priv = (struct tt565_priv_data *)STATE(rig)->priv;
+    *mode = priv->mode;
+    *width = priv->width;
+    return RIG_OK;
+}
+
 int tt565_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
 {
     int resp_len, retval;
     char cmdbuf[TT565_BUFSIZE], respbuf[TT565_BUFSIZE];
     char ttmode, ttreceiver;
+    int retry;
+    int timeout;
+    int widthOld = CACHE(rig)->widthMainA;
+    struct rig_state *rs = STATE(rig);
 
     ttreceiver = which_receiver(rig, vfo);
 
@@ -708,10 +805,11 @@ int tt565_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
 
     if (retval != RIG_OK)
     {
+        rig_debug(RIG_DEBUG_ERR, "%s: tt565_transaction failed\n", __func__);
         return retval;
     }
 
-    if (respbuf[1] != 'R' || respbuf[3] != 'M' || resp_len <= 4)
+    if (respbuf[1] != 'R' || respbuf[3] != 'M' || resp_len <= 3)
     {
         rig_debug(RIG_DEBUG_ERR, "%s: unexpected answer '%s'\n",
                   __func__, respbuf);
@@ -742,16 +840,24 @@ int tt565_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
         return -RIG_EPROTO;
     }
 
-    /* Orion may need some time to "recover" from ?RxM before ?RxF */
-    hl_usleep(80000);      // try 80 ms
     /* Query passband width (filter) */
+    // since this fails at 80ms sometimes we won't retry and will reduce the timeout
+    // Normally this comes back in about 30ms
+    retry = rs->retry;
+    timeout = rs->timeout;
+    rs->retry = 0;
+    rs->timeout = 100;
     SNPRINTF(cmdbuf, sizeof(cmdbuf), "?R%cF" EOM, ttreceiver);
     resp_len = sizeof(respbuf);
     retval = tt565_transaction(rig, cmdbuf, strlen(cmdbuf), respbuf, &resp_len);
+    rs->retry = retry;
+    rs->timeout = timeout;
 
     if (retval != RIG_OK)
     {
-        return retval;
+        // if the width call fails we will just reuse the old width
+        *width = widthOld;
+        return RIG_OK;
     }
 
     if (respbuf[1] != 'R' || respbuf[3] != 'F' || resp_len <= 4)
@@ -947,10 +1053,16 @@ int tt565_get_xit(RIG *rig, vfo_t vfo, shortfreq_t *xit)
  */
 int tt565_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt)
 {
-    struct rig_state *rs = &rig->state;
+    struct tt565_priv_data *priv = (struct tt565_priv_data *)STATE(rig)->priv;
+    int retval = write_block(RIGPORT(rig),
+                             (unsigned char *)(ptt == RIG_PTT_ON ? "*TK" EOM : "*TU" EOM), 4);
 
-    return write_block(&rs->rigport,
-                       (unsigned char *)(ptt == RIG_PTT_ON ? "*TK" EOM : "*TU" EOM), 4);
+    if (retval == RIG_OK)
+    {
+        priv->ptt = ptt;
+    }
+
+    return retval;
 }
 
 /**
@@ -962,25 +1074,9 @@ int tt565_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt)
  */
 int tt565_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt)
 {
-    int resp_len, retval;
-    char respbuf[TT565_BUFSIZE];
+    struct tt565_priv_data *priv = (struct tt565_priv_data *)STATE(rig)->priv;
 
-    resp_len = sizeof(respbuf);
-    retval = tt565_transaction(rig, "?S" EOM, 3, respbuf, &resp_len);
-
-    if (retval != RIG_OK)
-    {
-        return retval;
-    }
-
-    if (respbuf[1] != 'S' || resp_len < 5)
-    {
-        rig_debug(RIG_DEBUG_ERR, "%s: unexpected answer '%s'\n",
-                  __func__, respbuf);
-        return -RIG_EPROTO;
-    }
-
-    *ptt = respbuf[2] == 'T' ? RIG_PTT_ON : RIG_PTT_OFF ;
+    *ptt = priv->ptt;
 
     return RIG_OK;
 }
@@ -1305,8 +1401,6 @@ int tt565_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 
         if (rig->caps->rig_model == RIG_MODEL_TT599)
         {
-            double fwd, ref;
-
             /* in Xmit, response is @STF99R10<cr> 99 watts forward,1.0 watt reflected
                 uu = fwd watts
                 vv = rev watts x 10
@@ -1324,6 +1418,8 @@ int tt565_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 
             if (lvlbuf[2] == 'T')
             {
+                double fwd, ref;
+
                 ref = atof(strchr(lvlbuf + 2, 'R') + 1) / 10.0;   /* reflected power */
                 fwd = atof(strchr(lvlbuf + 2, 'F') + 1);          /* forward power */
 
@@ -1803,7 +1899,7 @@ int tt565_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
  */
 int tt565_set_mem(RIG *rig, vfo_t vfo, int ch)
 {
-    struct tt565_priv_data *priv = (struct tt565_priv_data *)rig->state.priv;
+    struct tt565_priv_data *priv = (struct tt565_priv_data *)STATE(rig)->priv;
 
     priv->ch = ch;  /* See RIG_OP_TO/FROM_VFO */
     return RIG_OK;
@@ -1818,7 +1914,7 @@ int tt565_set_mem(RIG *rig, vfo_t vfo, int ch)
  */
 int tt565_get_mem(RIG *rig, vfo_t vfo, int *ch)
 {
-    struct tt565_priv_data *priv = (struct tt565_priv_data *)rig->state.priv;
+    const struct tt565_priv_data *priv = (struct tt565_priv_data *)STATE(rig)->priv;
 
     *ch = priv->ch;
     return RIG_OK;
@@ -1840,7 +1936,7 @@ int tt565_get_mem(RIG *rig, vfo_t vfo, int *ch)
  */
 int tt565_vfo_op(RIG *rig, vfo_t vfo, vfo_op_t op)
 {
-    struct tt565_priv_data *priv = (struct tt565_priv_data *)rig->state.priv;
+    const struct tt565_priv_data *priv = (struct tt565_priv_data *)STATE(rig)->priv;
     char cmdbuf[TT565_BUFSIZE];
     int retval;
 
