@@ -19,8 +19,6 @@
  *
  */
 
-#include <hamlib/config.h>
-
 #include <stdlib.h>
 
 #include <hamlib/rig.h>
@@ -68,7 +66,7 @@
  *
  * TODO:
  */
-const struct rig_caps rx320_caps =
+struct rig_caps rx320_caps =
 {
     RIG_MODEL(RIG_MODEL_RX320),
     .model_name = "RX-320",
@@ -102,7 +100,6 @@ const struct rig_caps rx320_caps =
     .has_get_parm =  RIG_PARM_NONE,
     .has_set_parm =  RIG_PARM_NONE,
     .level_gran = {
-        // cppcheck-suppress *
         [LVL_RAWSTR] = { .min = { .i = 0 }, .max = { .i = 10000 } },
         [LVL_AF] = { .min = { .f = 0 }, .max = { .f = 1 }, .step = { .f = 1.0 / 64 } },
         [LVL_IF] = { .min = { .i = -2000 }, .max = { .i = 2000 }, .step = { .i = 10} },
