@@ -19,7 +19,6 @@
  *
  */
 
-#include <hamlib/config.h>
 
 #include <stdlib.h>
 
@@ -42,14 +41,14 @@
  *
  * TODO: check this with manual or web site.
  */
-const struct rig_caps bc245_caps =
+struct rig_caps bc245_caps =
 {
     RIG_MODEL(RIG_MODEL_BC245),
     .model_name = "BC245xlt",
     .mfg_name =  "Uniden",
     .version =  BACKEND_VER ".0",
     .copyright =  "LGPL",
-    .status =  RIG_STATUS_ALPHA,
+    .status =  RIG_STATUS_BETA,
     .rig_type =  RIG_TYPE_TRUNKSCANNER,
     .ptt_type =  RIG_PTT_NONE,
     .dcd_type =  RIG_DCD_RIG,
