@@ -19,7 +19,6 @@
  *
  */
 
-#include <hamlib/config.h>
 
 #include <stdlib.h>
 
@@ -68,14 +67,14 @@ static tone_t bc898_ctcss_list[] =
  * TODO: check this with manual or web site.
  * http://www.uniden.com/products/productdetail.cfm?product=BC898T&filter=Mobile
  */
-const struct rig_caps bc898_caps =
+struct rig_caps bc898_caps =
 {
     RIG_MODEL(RIG_MODEL_BC898),
     .model_name = "BC898T",
     .mfg_name =  "Uniden",
     .version =  BACKEND_VER ".0",
     .copyright =  "LGPL",
-    .status =  RIG_STATUS_ALPHA,
+    .status =  RIG_STATUS_BETA,
     .rig_type =  RIG_TYPE_TRUNKSCANNER,
     .ptt_type =  RIG_PTT_NONE,
     .dcd_type =  RIG_DCD_RIG,
