@@ -70,8 +70,8 @@ static int g313_get_powerstat(RIG *rig, powerstat_t *status);
 static int g313_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val);
 static int g313_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val);
 static const char *g313_get_info(RIG *rig);
-int g313_set_conf(RIG *rig, token_t token, const char *val);
-int g313_get_conf(RIG *rig, token_t token, char *val);
+int g313_set_conf(RIG *rig, hamlib_token_t token, const char *val);
+int g313_get_conf(RIG *rig, hamlib_token_t token, char *val);
 
 /* #pragma pack(1)       // set byte packing */
 typedef struct
@@ -157,7 +157,7 @@ struct g313_priv_data
 };
 
 
-const struct rig_caps g313_caps =
+struct rig_caps g313_caps =
 {
     RIG_MODEL(RIG_MODEL_G313),
     .model_name =     "WR-G313",
@@ -232,16 +232,16 @@ int g313_init(RIG *rig)
 {
     struct g313_priv_data *priv;
 
-    rig->state.priv = (struct g313_priv_data *)calloc(1, sizeof(
-                          struct g313_priv_data));
+    STATE(rig)->priv = (struct g313_priv_data *)calloc(1, sizeof(
+                           struct g313_priv_data));
 
-    if (!rig->state.priv)
+    if (!STATE(rig)->priv)
     {
         /* whoops! memory shortage! */
         return -RIG_ENOMEM;
     }
 
-    priv = rig->state.priv;
+    priv = STATE(rig)->priv;
 
     priv->WaveOutDeviceID = -1;
 
@@ -374,12 +374,12 @@ int g313_findVSC(struct g313_priv_data *priv)
 
 int g313_open(RIG *rig)
 {
-    struct g313_priv_data *priv = (struct g313_priv_data *)rig->state.priv;
+    struct g313_priv_data *priv = (struct g313_priv_data *)STATE(rig)->priv;
     int device_num;
     int Count;
     int id;
 
-    device_num = atoi(rig->state.rigport.pathname);
+    device_num = atoi(RIGPORT(rig)->pathname);
 
     Count = priv->waveOutGetNumDevs();
 
@@ -432,7 +432,7 @@ int g313_open(RIG *rig)
 
 int g313_close(RIG *rig)
 {
-    struct g313_priv_data *priv = (struct g313_priv_data *)rig->state.priv;
+    struct g313_priv_data *priv = (struct g313_priv_data *)STATE(rig)->priv;
 
 
     if (!priv->Opened)
@@ -461,23 +461,23 @@ int g313_cleanup(RIG *rig)
         return -RIG_EINVAL;
     }
 
-    priv = (struct g313_priv_data *)rig->state.priv;
+    priv = (struct g313_priv_data *)STATE(rig)->priv;
 
     /* Clean up the dll access */
     FreeLibrary(priv->dll);
     FreeLibrary(priv->WinMM);
     FreeLibrary(priv->hWRG313WO);
 
-    free(rig->state.priv);
+    free(STATE(rig)->priv);
 
-    rig->state.priv = NULL;
+    STATE(rig)->priv = NULL;
 
     return RIG_OK;
 }
 
 int g313_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 {
-    struct g313_priv_data *priv = (struct g313_priv_data *)rig->state.priv;
+    struct g313_priv_data *priv = (struct g313_priv_data *)STATE(rig)->priv;
     int ret;
 
     ret = priv->G3SetFrequency(priv->hRadio, (DWORD)(freq));
@@ -488,7 +488,7 @@ int g313_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 
 int g313_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
 {
-    struct g313_priv_data *priv = (struct g313_priv_data *)rig->state.priv;
+    struct g313_priv_data *priv = (struct g313_priv_data *)STATE(rig)->priv;
 
     *freq = (freq_t) priv->G3GetFrequency(priv->hRadio);
 
@@ -497,7 +497,7 @@ int g313_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
 
 int g313_set_powerstat(RIG *rig, powerstat_t status)
 {
-    struct g313_priv_data *priv = (struct g313_priv_data *)rig->state.priv;
+    struct g313_priv_data *priv = (struct g313_priv_data *)STATE(rig)->priv;
     int ret;
 
     ret = priv->SetPower(priv->hRadio, status == RIG_POWER_ON ? TRUE : FALSE);
@@ -508,7 +508,7 @@ int g313_set_powerstat(RIG *rig, powerstat_t status)
 
 int g313_get_powerstat(RIG *rig, powerstat_t *status)
 {
-    struct g313_priv_data *priv = (struct g313_priv_data *)rig->state.priv;
+    struct g313_priv_data *priv = (struct g313_priv_data *)STATE(rig)->priv;
     int ret;
 
     ret = priv->GetPower(priv->hRadio);
@@ -519,7 +519,7 @@ int g313_get_powerstat(RIG *rig, powerstat_t *status)
 
 int g313_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
 {
-    struct g313_priv_data *priv = (struct g313_priv_data *)rig->state.priv;
+    struct g313_priv_data *priv = (struct g313_priv_data *)STATE(rig)->priv;
     int ret, agc;
 
     switch (level)
@@ -568,7 +568,7 @@ int g313_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
 
 int g313_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 {
-    struct g313_priv_data *priv = (struct g313_priv_data *)rig->state.priv;
+    struct g313_priv_data *priv = (struct g313_priv_data *)STATE(rig)->priv;
     int ret;
 
     ret = RIG_OK;
@@ -626,7 +626,7 @@ int g313_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 
 static const char *g313_get_info(RIG *rig)
 {
-    struct g313_priv_data *priv = (struct g313_priv_data *)rig->state.priv;
+    struct g313_priv_data *priv = (struct g313_priv_data *)STATE(rig)->priv;
     static RADIO_INFO info;
 
     info.bLength = sizeof(RADIO_INFO);
@@ -640,9 +640,9 @@ static const char *g313_get_info(RIG *rig)
 }
 
 
-int g313_set_conf(RIG *rig, token_t token, const char *val)
+int g313_set_conf(RIG *rig, hamlib_token_t token, const char *val)
 {
-    struct g313_priv_data *priv = (struct g313_priv_data *)rig->state.priv;
+    struct g313_priv_data *priv = (struct g313_priv_data *)STATE(rig)->priv;
     int id;
 
     switch (token)
@@ -695,9 +695,9 @@ int g313_set_conf(RIG *rig, token_t token, const char *val)
     return RIG_OK;
 }
 
-int g313_get_conf2(RIG *rig, token_t token, char *val, int val_len)
+int g313_get_conf2(RIG *rig, hamlib_token_t token, char *val, int val_len)
 {
-    struct g313_priv_data *priv = (struct g313_priv_data *)rig->state.priv;
+    const struct g313_priv_data *priv = (struct g313_priv_data *)STATE(rig)->priv;
 
     switch (token)
     {
@@ -712,7 +712,7 @@ int g313_get_conf2(RIG *rig, token_t token, char *val, int val_len)
     return RIG_OK;
 }
 
-int g313_get_conf(RIG *rig, token_t token, char *val)
+int g313_get_conf(RIG *rig, hamlib_token_t token, char *val)
 {
     return g313_get_conf2(rig, token, val, 128);
 }
