@@ -29,7 +29,6 @@
 
 #include "hamlib/rig.h"
 #include "serial.h"
-#include "misc.h"
 #include "register.h"
 
 
@@ -45,9 +44,9 @@
 
 int wr_rig_init(RIG *rig)
 {
-    rig->state.rigport.type.rig = RIG_PORT_DEVICE;
-    strncpy(rig->state.rigport.pathname, DEFAULT_WINRADIO_PATH,
-            HAMLIB_FILPATHLEN - 1);
+    hamlib_port_t *rp = RIGPORT(rig);
+    rp->type.rig = RIG_PORT_DEVICE;
+    strncpy(rp->pathname, DEFAULT_WINRADIO_PATH, HAMLIB_FILPATHLEN - 1);
 
     return RIG_OK;
 }
@@ -63,7 +62,7 @@ int wr_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 
     f = (unsigned long)freq;
 
-    if (ioctl(rig->state.rigport.fd, RADIO_SET_FREQ, &f)) { return -RIG_EINVAL; }
+    if (ioctl(RIGPORT(rig)->fd, RADIO_SET_FREQ, &f)) { return -RIG_EINVAL; }
 
     return RIG_OK;
 }
@@ -72,7 +71,7 @@ int wr_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
 {
     unsigned long f;
 
-    if (ioctl(rig->state.rigport.fd, RADIO_GET_FREQ, &f) < 0) { return -RIG_EINVAL; }
+    if (ioctl(RIGPORT(rig)->fd, RADIO_GET_FREQ, &f) < 0) { return -RIG_EINVAL; }
 
     *freq = (freq_t)f;
     return RIG_OK;
@@ -113,7 +112,7 @@ int wr_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
     default: return -RIG_EINVAL;
     }
 
-    if (ioctl(rig->state.rigport.fd, RADIO_SET_MODE, &m)) { return -RIG_EINVAL; }
+    if (ioctl(RIGPORT(rig)->fd, RADIO_SET_MODE, &m)) { return -RIG_EINVAL; }
 
     return  RIG_OK;
 }
@@ -122,7 +121,7 @@ int wr_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
 {
     unsigned long m;
 
-    if (ioctl(rig->state.rigport.fd, RADIO_GET_MODE, &m)) { return -RIG_EINVAL; }
+    if (ioctl(RIGPORT(rig)->fd, RADIO_GET_MODE, &m)) { return -RIG_EINVAL; }
 
     *width = RIG_PASSBAND_NORMAL;
 
@@ -160,7 +159,7 @@ int wr_set_powerstat(RIG *rig, powerstat_t status)
     unsigned long p = 1;
     p = status == RIG_POWER_ON ? 1 : 0;
 
-    if (ioctl(rig->state.rigport.fd, RADIO_SET_POWER, &p)) { return -RIG_EINVAL; }
+    if (ioctl(RIGPORT(rig)->fd, RADIO_SET_POWER, &p)) { return -RIG_EINVAL; }
 
     return RIG_OK;
 }
@@ -168,7 +167,7 @@ int wr_get_powerstat(RIG *rig, powerstat_t *status)
 {
     unsigned long p;
 
-    if (ioctl(rig->state.rigport.fd, RADIO_GET_POWER, &p)) { return -RIG_EINVAL; }
+    if (ioctl(RIGPORT(rig)->fd, RADIO_GET_POWER, &p)) { return -RIG_EINVAL; }
 
     *status = p ? RIG_POWER_ON : RIG_POWER_OFF;
     return RIG_OK;
@@ -182,7 +181,7 @@ int wr_set_func(RIG *rig, vfo_t vfo, setting_t func, int status)
     {
         unsigned long v = status ? 1 : 0;
 
-        if (ioctl(rig->state.rigport.fd, RADIO_SET_AGC, &v)) { return -RIG_EINVAL; }
+        if (ioctl(RIGPORT(rig)->fd, RADIO_SET_AGC, &v)) { return -RIG_EINVAL; }
 
         return RIG_OK;
     }
@@ -200,7 +199,7 @@ int wr_get_func(RIG *rig, vfo_t vfo, setting_t func, int *status)
     {
         unsigned long v;
 
-        if (ioctl(rig->state.rigport.fd, RADIO_GET_AGC, &v)) { return -RIG_EINVAL; }
+        if (ioctl(RIGPORT(rig)->fd, RADIO_GET_AGC, &v)) { return -RIG_EINVAL; }
 
         *status = v;
         return RIG_OK;
@@ -214,17 +213,19 @@ int wr_get_func(RIG *rig, vfo_t vfo, setting_t func, int *status)
 
 int wr_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
 {
+    hamlib_port_t *rp = RIGPORT(rig);
+
     switch (level)
     {
     case RIG_LEVEL_AF:
     {
         unsigned long v;
 
-        if (ioctl(rig->state.rigport.fd, RADIO_GET_MAXVOL, &v)) { return -RIG_EINVAL; }
+        if (ioctl(rp->fd, RADIO_GET_MAXVOL, &v)) { return -RIG_EINVAL; }
 
         v *= val.f;
 
-        if (ioctl(rig->state.rigport.fd, RADIO_SET_VOL, &v)) { return -RIG_EINVAL; }
+        if (ioctl(rp->fd, RADIO_SET_VOL, &v)) { return -RIG_EINVAL; }
 
         return RIG_OK;
     }
@@ -233,7 +234,7 @@ int wr_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
     {
         unsigned long v = val.i ? 1 : 0;
 
-        if (ioctl(rig->state.rigport.fd, RADIO_SET_ATTN, &v)) { return -RIG_EINVAL; }
+        if (ioctl(rp->fd, RADIO_SET_ATTN, &v)) { return -RIG_EINVAL; }
 
         return RIG_OK;
     }
@@ -242,7 +243,7 @@ int wr_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
     {
         long v = val.i;
 
-        if (ioctl(rig->state.rigport.fd, RADIO_SET_IFS, &v)) { return -RIG_EINVAL; }
+        if (ioctl(rp->fd, RADIO_SET_IFS, &v)) { return -RIG_EINVAL; }
 
         return RIG_OK;
     }
@@ -251,7 +252,7 @@ int wr_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
     {
         long v = val.f * 100; /* iMaxIFGain on wHWVer > RHV_3150 */
 
-        if (ioctl(rig->state.rigport.fd, RADIO_SET_IFG, &v)) { return -RIG_EINVAL; }
+        if (ioctl(rp->fd, RADIO_SET_IFG, &v)) { return -RIG_EINVAL; }
 
         return RIG_OK;
     }
@@ -263,15 +264,17 @@ int wr_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
 
 int wr_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 {
+    hamlib_port_t *rp = RIGPORT(rig);
+
     switch (level)
     {
     case RIG_LEVEL_AF:
     {
         unsigned long v, mv;
 
-        if (ioctl(rig->state.rigport.fd, RADIO_GET_MAXVOL, &mv)) { return -RIG_EINVAL; }
+        if (ioctl(rp->fd, RADIO_GET_MAXVOL, &mv)) { return -RIG_EINVAL; }
 
-        if (ioctl(rig->state.rigport.fd, RADIO_GET_VOL, &v)) { return -RIG_EINVAL; }
+        if (ioctl(rp->fd, RADIO_GET_VOL, &v)) { return -RIG_EINVAL; }
 
         val->f = (float)v / mv;
         return RIG_OK;
@@ -281,9 +284,9 @@ int wr_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
     {
         unsigned long v;
 
-        if (ioctl(rig->state.rigport.fd, RADIO_GET_VOL, &v)) { return -RIG_EINVAL; }
+        if (ioctl(rp->fd, RADIO_GET_VOL, &v)) { return -RIG_EINVAL; }
 
-        val->i = v ? rig->state.attenuator[0] : 0;
+        val->i = v ? STATE(rig)->attenuator[0] : 0;
         return RIG_OK;
     }
 
@@ -291,7 +294,7 @@ int wr_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
     {
         unsigned long v;
 
-        if (ioctl(rig->state.rigport.fd, RADIO_GET_SS, &v)) { return -RIG_EINVAL; }
+        if (ioctl(rp->fd, RADIO_GET_SS, &v)) { return -RIG_EINVAL; }
 
         val->i = v - 60; /* 0..120, Hamlib assumes S9 = 0dB */
         return RIG_OK;
@@ -301,7 +304,7 @@ int wr_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
     {
         long v;
 
-        if (ioctl(rig->state.rigport.fd, RADIO_GET_IFS, &v)) { return -RIG_EINVAL; }
+        if (ioctl(rp->fd, RADIO_GET_IFS, &v)) { return -RIG_EINVAL; }
 
         val->i = v;
         return RIG_OK;
@@ -311,7 +314,7 @@ int wr_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
     {
         long v;
 
-        if (ioctl(rig->state.rigport.fd, RADIO_GET_IFG, &v)) { return -RIG_EINVAL; }
+        if (ioctl(rp->fd, RADIO_GET_IFG, &v)) { return -RIG_EINVAL; }
 
         val->f = (float)v / 100; /* iMaxIFGain on wHWVer > RHV_3150 */
         return RIG_OK;
@@ -329,7 +332,7 @@ const char *wr_get_info(RIG *rig)
 {
     static char buf[100];
 
-    if (ioctl(rig->state.rigport.fd, RADIO_GET_DESCR, buf) < 0) { return "?"; }
+    if (ioctl(RIGPORT(rig)->fd, RADIO_GET_DESCR, buf) < 0) { return "?"; }
 
     return buf;
 }
