@@ -24,8 +24,6 @@
  *
  */
 
-#include <hamlib/config.h>
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>     /* String function definitions */
@@ -295,7 +293,6 @@ static tone_t ft100_dcs_list[] =
 #define FT100_FUNC_ALL (RIG_FUNC_TONE|RIG_FUNC_TSQL)
 
 #define FT100_VFO_ALL (RIG_VFO_A|RIG_VFO_B)
-#define FT100_ANT (RIG_ANT_1)
 
 /* S-meter calibration, ascending order of RAW values */
 #define FT100_STR_CAL { 9, \
@@ -311,12 +308,12 @@ static tone_t ft100_dcs_list[] =
             { 200, -54 }  /*  S0 */ \
             } }
 
-const struct rig_caps ft100_caps =
+struct rig_caps ft100_caps =
 {
     RIG_MODEL(RIG_MODEL_FT100),
     .model_name =     "FT-100",
     .mfg_name =       "Yaesu",
-    .version =        "20211111.0",
+    .version =        "20240910.0",
     .copyright =      "LGPL",
     .status =         RIG_STATUS_STABLE,
     .rig_type =       RIG_TYPE_TRANSCEIVER,
@@ -359,39 +356,39 @@ const struct rig_caps ft100_caps =
     .chan_list =  { RIG_CHAN_END, },  /* FIXME: memory chan .list =  78 */
 
     .rx_range_list1 =  {
-        {kHz(100), MHz(56), FT100_ALL_RX_MODES, -1, -1, FT100_VFO_ALL},
-        {MHz(76), MHz(108), RIG_MODE_WFM,      -1, -1, FT100_VFO_ALL},
-        {MHz(108), MHz(154), FT100_ALL_RX_MODES, -1, -1, FT100_VFO_ALL},
-        {MHz(420), MHz(470), FT100_ALL_RX_MODES, -1, -1, FT100_VFO_ALL},
+        {kHz(100), MHz(56), FT100_ALL_RX_MODES, -1, -1, FT100_VFO_ALL, RIG_ANT_CURR},
+        {MHz(76), MHz(108), RIG_MODE_WFM,      -1, -1, FT100_VFO_ALL, RIG_ANT_CURR},
+        {MHz(108), MHz(154), FT100_ALL_RX_MODES, -1, -1, FT100_VFO_ALL, RIG_ANT_CURR},
+        {MHz(420), MHz(470), FT100_ALL_RX_MODES, -1, -1, FT100_VFO_ALL, RIG_ANT_CURR},
         RIG_FRNG_END,
     },
     .tx_range_list1 =  {
-        FRQ_RNG_HF(1, FT100_OTHER_TX_MODES, W(0.5), W(100), FT100_VFO_ALL, FT100_ANT),
-        FRQ_RNG_HF(1, FT100_AM_TX_MODES,    W(0.5), W(25), FT100_VFO_ALL, FT100_ANT),
-        FRQ_RNG_6m(1, FT100_OTHER_TX_MODES, W(0.5), W(100), FT100_VFO_ALL, FT100_ANT),
-        FRQ_RNG_6m(1, FT100_AM_TX_MODES,    W(0.5), W(25), FT100_VFO_ALL, FT100_ANT),
-        FRQ_RNG_2m(1, FT100_OTHER_TX_MODES, W(0.5), W(50), FT100_VFO_ALL, FT100_ANT),
-        FRQ_RNG_2m(1, FT100_AM_TX_MODES,    W(0.5), W(12.5), FT100_VFO_ALL, FT100_ANT),
-        FRQ_RNG_70cm(1, FT100_OTHER_TX_MODES, W(0.5), W(20), FT100_VFO_ALL, FT100_ANT),
-        FRQ_RNG_70cm(1, FT100_AM_TX_MODES,    W(0.5), W(5),  FT100_VFO_ALL, FT100_ANT),
+        FRQ_RNG_HF(1, FT100_OTHER_TX_MODES, W(0.5), W(100), FT100_VFO_ALL, RIG_ANT_CURR),
+        FRQ_RNG_HF(1, FT100_AM_TX_MODES,    W(0.5), W(25), FT100_VFO_ALL, RIG_ANT_CURR),
+        FRQ_RNG_6m(1, FT100_OTHER_TX_MODES, W(0.5), W(100), FT100_VFO_ALL, RIG_ANT_CURR),
+        FRQ_RNG_6m(1, FT100_AM_TX_MODES,    W(0.5), W(25), FT100_VFO_ALL, RIG_ANT_CURR),
+        FRQ_RNG_2m(1, FT100_OTHER_TX_MODES, W(0.5), W(50), FT100_VFO_ALL, RIG_ANT_CURR),
+        FRQ_RNG_2m(1, FT100_AM_TX_MODES,    W(0.5), W(12.5), FT100_VFO_ALL, RIG_ANT_CURR),
+        FRQ_RNG_70cm(1, FT100_OTHER_TX_MODES, W(0.5), W(20), FT100_VFO_ALL, RIG_ANT_CURR),
+        FRQ_RNG_70cm(1, FT100_AM_TX_MODES,    W(0.5), W(5),  FT100_VFO_ALL, RIG_ANT_CURR),
     },
     .rx_range_list2 =  {
-        {kHz(100), MHz(56), FT100_ALL_RX_MODES, -1, -1, FT100_VFO_ALL},
-        {MHz(76), MHz(108), RIG_MODE_WFM,      -1, -1, FT100_VFO_ALL},
-        {MHz(108), MHz(154), FT100_ALL_RX_MODES, -1, -1, FT100_VFO_ALL},
-        {MHz(420), MHz(470), FT100_ALL_RX_MODES, -1, -1, FT100_VFO_ALL},
+        {kHz(100), MHz(56), FT100_ALL_RX_MODES, -1, -1, FT100_VFO_ALL, RIG_ANT_CURR},
+        {MHz(76), MHz(108), RIG_MODE_WFM,      -1, -1, FT100_VFO_ALL, RIG_ANT_CURR},
+        {MHz(108), MHz(154), FT100_ALL_RX_MODES, -1, -1, FT100_VFO_ALL, RIG_ANT_CURR},
+        {MHz(420), MHz(470), FT100_ALL_RX_MODES, -1, -1, FT100_VFO_ALL, RIG_ANT_CURR},
         RIG_FRNG_END,
     },
 
     .tx_range_list2 =  {
-        FRQ_RNG_HF(2, FT100_OTHER_TX_MODES, W(0.5), W(100), FT100_VFO_ALL, FT100_ANT),
-        FRQ_RNG_HF(2, FT100_AM_TX_MODES,    W(0.5), W(25), FT100_VFO_ALL, FT100_ANT),
-        FRQ_RNG_6m(2, FT100_OTHER_TX_MODES, W(0.5), W(100), FT100_VFO_ALL, FT100_ANT),
-        FRQ_RNG_6m(2, FT100_AM_TX_MODES,    W(0.5), W(25), FT100_VFO_ALL, FT100_ANT),
-        FRQ_RNG_2m(2, FT100_OTHER_TX_MODES, W(0.5), W(50), FT100_VFO_ALL, FT100_ANT),
-        FRQ_RNG_2m(2, FT100_AM_TX_MODES,    W(0.5), W(12.5), FT100_VFO_ALL, FT100_ANT),
-        FRQ_RNG_70cm(2, FT100_OTHER_TX_MODES, W(0.5), W(20), FT100_VFO_ALL, FT100_ANT),
-        FRQ_RNG_70cm(2, FT100_AM_TX_MODES,    W(0.5), W(5),  FT100_VFO_ALL, FT100_ANT),
+        FRQ_RNG_HF(2, FT100_OTHER_TX_MODES, W(0.5), W(100), FT100_VFO_ALL, RIG_ANT_CURR),
+        FRQ_RNG_HF(2, FT100_AM_TX_MODES,    W(0.5), W(25), FT100_VFO_ALL, RIG_ANT_CURR),
+        FRQ_RNG_6m(2, FT100_OTHER_TX_MODES, W(0.5), W(100), FT100_VFO_ALL, RIG_ANT_CURR),
+        FRQ_RNG_6m(2, FT100_AM_TX_MODES,    W(0.5), W(25), FT100_VFO_ALL, RIG_ANT_CURR),
+        FRQ_RNG_2m(2, FT100_OTHER_TX_MODES, W(0.5), W(50), FT100_VFO_ALL, RIG_ANT_CURR),
+        FRQ_RNG_2m(2, FT100_AM_TX_MODES,    W(0.5), W(12.5), FT100_VFO_ALL, RIG_ANT_CURR),
+        FRQ_RNG_70cm(2, FT100_OTHER_TX_MODES, W(0.5), W(20), FT100_VFO_ALL, RIG_ANT_CURR),
+        FRQ_RNG_70cm(2, FT100_AM_TX_MODES,    W(0.5), W(5),  FT100_VFO_ALL, RIG_ANT_CURR),
         RIG_FRNG_END,
     },
 
@@ -473,10 +470,10 @@ int ft100_init(RIG *rig)
 {
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
-    rig->state.priv = (struct ft100_priv_data *) calloc(1,
-                      sizeof(struct ft100_priv_data));
+    STATE(rig)->priv = (struct ft100_priv_data *) calloc(1,
+                       sizeof(struct ft100_priv_data));
 
-    if (!rig->state.priv) { return -RIG_ENOMEM; }
+    if (!STATE(rig)->priv) { return -RIG_ENOMEM; }
 
     return RIG_OK;
 }
@@ -488,12 +485,12 @@ int ft100_cleanup(RIG *rig)
         return -RIG_EINVAL;
     }
 
-    if (rig->state.priv)
+    if (STATE(rig)->priv)
     {
-        free(rig->state.priv);
+        free(STATE(rig)->priv);
     }
 
-    rig->state.priv = NULL;
+    STATE(rig)->priv = NULL;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called\n", __func__);
 
@@ -528,20 +525,21 @@ static int ft100_send_priv_cmd(RIG *rig, unsigned char cmd_index)
 
     if (!rig) { return -RIG_EINVAL; }
 
-    return write_block(&rig->state.rigport, (unsigned char *) &ncmd[cmd_index].nseq,
+    return write_block(RIGPORT(rig), (unsigned char *) &ncmd[cmd_index].nseq,
                        YAESU_CMD_LENGTH);
 }
 
 static int ft100_read_status(RIG *rig)
 {
     struct ft100_priv_data *priv;
+    hamlib_port_t *rp = RIGPORT(rig);
     int ret;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
-    priv = (struct ft100_priv_data *)rig->state.priv;
+    priv = (struct ft100_priv_data *)STATE(rig)->priv;
 
-    rig_flush(&rig->state.rigport);
+    rig_flush(rp);
 
     ret = ft100_send_priv_cmd(rig, FT100_NATIVE_CAT_READ_STATUS);
 
@@ -550,7 +548,7 @@ static int ft100_read_status(RIG *rig)
         return ret;
     }
 
-    ret = read_block(&rig->state.rigport, (unsigned char *) &priv->status,
+    ret = read_block(rp, (unsigned char *) &priv->status,
                      sizeof(FT100_STATUS_INFO));
     rig_debug(RIG_DEBUG_VERBOSE, "%s: read status=%i \n", __func__, ret);
 
@@ -564,12 +562,13 @@ static int ft100_read_status(RIG *rig)
 
 static int ft100_read_flags(RIG *rig)
 {
-    struct ft100_priv_data *priv = (struct ft100_priv_data *)rig->state.priv;
+    struct ft100_priv_data *priv = (struct ft100_priv_data *)STATE(rig)->priv;
     int ret;
+    hamlib_port_t *rp = RIGPORT(rig);
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
-    rig_flush(&rig->state.rigport);
+    rig_flush(rp);
 
     ret = ft100_send_priv_cmd(rig, FT100_NATIVE_CAT_READ_FLAGS);
 
@@ -578,7 +577,7 @@ static int ft100_read_flags(RIG *rig)
         return ret;
     }
 
-    ret = read_block(&rig->state.rigport, (unsigned char *) &priv->flags,
+    ret = read_block(rp, (unsigned char *) &priv->flags,
                      sizeof(FT100_FLAG_INFO));
     rig_debug(RIG_DEBUG_VERBOSE, "%s: read flags=%i \n", __func__, ret);
 
@@ -607,13 +606,13 @@ int ft100_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
     freq = (int) freq / 10;
     to_bcd(p_cmd, freq, 8); /* store bcd format in in p_cmd */
 
-    return write_block(&rig->state.rigport, p_cmd, YAESU_CMD_LENGTH);
+    return write_block(RIGPORT(rig), p_cmd, YAESU_CMD_LENGTH);
 }
 
 int ft100_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
 {
 
-    struct ft100_priv_data *priv = (struct ft100_priv_data *)rig->state.priv;
+    struct ft100_priv_data *priv = (struct ft100_priv_data *)STATE(rig)->priv;
     freq_t d1, d2;
     char freq_str[10];
     int ret;
@@ -733,7 +732,7 @@ int ft100_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
         else if (width <= 2400) { p_cmd[3] = 0x00; }
         else { p_cmd[3] = 0x01; }
 
-        ret = write_block(&rig->state.rigport, p_cmd, YAESU_CMD_LENGTH);
+        ret = write_block(RIGPORT(rig), p_cmd, YAESU_CMD_LENGTH);
 
         if (ret != RIG_OK)
         {
@@ -757,7 +756,7 @@ int ft100_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
 int ft100_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
 {
 
-    struct ft100_priv_data *priv = (struct ft100_priv_data *)rig->state.priv;
+    struct ft100_priv_data *priv = (struct ft100_priv_data *)STATE(rig)->priv;
     int ret;
 
     if (!mode || !width) { return -RIG_EINVAL; }
@@ -883,7 +882,7 @@ int ft100_set_vfo(RIG *rig, vfo_t vfo)
 int ft100_get_vfo(RIG *rig, vfo_t *vfo)
 {
 
-    struct ft100_priv_data *priv = (struct ft100_priv_data *)rig->state.priv;
+    struct ft100_priv_data *priv = (struct ft100_priv_data *)STATE(rig)->priv;
     int ret;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
@@ -914,7 +913,7 @@ int ft100_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt)
 {
 
     unsigned char cmd_index;
-    int split = rig->state.cache.split;
+    int split = CACHE(rig)->split;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
@@ -923,7 +922,8 @@ int ft100_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt)
     case RIG_PTT_ON:
         cmd_index = FT100_NATIVE_CAT_PTT_ON;
 
-        if (split) { rig_set_vfo(rig, RIG_VFO_B); }
+        // This was causing WSJT-X to assume reverse split
+        //if (split) { rig_set_vfo(rig, RIG_VFO_B); }
 
         break;
 
@@ -946,7 +946,7 @@ int ft100_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt)
 int ft100_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt)
 {
 
-    struct ft100_priv_data *priv = (struct ft100_priv_data *)rig->state.priv;
+    struct ft100_priv_data *priv = (struct ft100_priv_data *)STATE(rig)->priv;
     int ret;
 
     if (!ptt) { return -RIG_EINVAL; }
@@ -970,8 +970,8 @@ int ft100_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 {
 
     int ret;
-    int split = rig->state.cache.split;
-    int ptt = rig->state.cache.ptt;
+    int split = CACHE(rig)->split;
+    int ptt = CACHE(rig)->ptt;
 
     FT100_METER_INFO ft100_meter;
 
@@ -993,7 +993,7 @@ int ft100_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
         return ret;
     }
 
-    ret = read_block(&rig->state.rigport, (unsigned char *) &ft100_meter,
+    ret = read_block(RIGPORT(rig), (unsigned char *) &ft100_meter,
                      sizeof(FT100_METER_INFO));
     rig_debug(RIG_DEBUG_VERBOSE, "%s: read meters=%d\n", __func__, ret);
 
@@ -1103,7 +1103,7 @@ int ft100_set_split_vfo(RIG *rig, vfo_t vfo, split_t split, vfo_t tx_vfo)
 int ft100_get_split_vfo(RIG *rig, vfo_t vfo, split_t *split, vfo_t *tx_vfo)
 {
 
-    struct ft100_priv_data *priv = (struct ft100_priv_data *)rig->state.priv;
+    struct ft100_priv_data *priv = (struct ft100_priv_data *)STATE(rig)->priv;
     int ret;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
@@ -1157,7 +1157,7 @@ int ft100_set_rptr_shift(RIG *rig, vfo_t vfo, rptr_shift_t shift)
 int ft100_get_rptr_shift(RIG *rig, vfo_t vfo, rptr_shift_t *shift)
 {
     int ret;
-    struct ft100_priv_data *priv = (struct ft100_priv_data *)rig->state.priv;
+    struct ft100_priv_data *priv = (struct ft100_priv_data *)STATE(rig)->priv;
 
     ret = ft100_read_status(rig);
 
@@ -1210,13 +1210,13 @@ int ft100_set_dcs_code(RIG *rig, vfo_t vfo, tone_t code)
 
     p_cmd[3] = (char)pcode;
 
-    return write_block(&rig->state.rigport, p_cmd, YAESU_CMD_LENGTH);
+    return write_block(RIGPORT(rig), p_cmd, YAESU_CMD_LENGTH);
 }
 
 int ft100_get_dcs_code(RIG *rig, vfo_t vfo, tone_t *code)
 {
     int ret;
-    struct ft100_priv_data *priv = (struct ft100_priv_data *)rig->state.priv;
+    struct ft100_priv_data *priv = (struct ft100_priv_data *)STATE(rig)->priv;
 
     ret = ft100_read_status(rig);
 
@@ -1264,13 +1264,13 @@ int ft100_set_ctcss_tone(RIG *rig, vfo_t vfo, tone_t tone)
 
     p_cmd[3] = (char)ptone;
 
-    return write_block(&rig->state.rigport, p_cmd, YAESU_CMD_LENGTH);
+    return write_block(RIGPORT(rig), p_cmd, YAESU_CMD_LENGTH);
 }
 
 int ft100_get_ctcss_tone(RIG *rig, vfo_t vfo, tone_t *tone)
 {
     int ret;
-    struct ft100_priv_data *priv = (struct ft100_priv_data *)rig->state.priv;
+    struct ft100_priv_data *priv = (struct ft100_priv_data *)STATE(rig)->priv;
 
     ret = ft100_read_status(rig);
 
