@@ -25,14 +25,11 @@
  * Right now, this FT-1000MP implementation is a big mess.
  * This is actually a fast copy past (from ft920.c),
  * just to make get_freq/set_freq and co to work for a friend of mine.
- * I wouln't mind if someone could take over the maintenance
+ * I wouldn't mind if someone could take over the maintenance
  * of this piece of code, and eventually rewrite it.
  * '02, Stephane
  */
 
-
-#include <hamlib/config.h>
-
 #include <stdlib.h>
 #include <string.h>  /* String function definitions */
 #include <math.h>
@@ -41,7 +38,6 @@
 #include "bandplan.h"
 #include "serial.h"
 #include "misc.h"
-#include "cal.h"
 #include "yaesu.h"
 #include "ft1000mp.h"
 
@@ -312,12 +308,12 @@ struct ft1000mp_priv_data
  *
  */
 
-const struct rig_caps ft1000mp_caps =
+struct rig_caps ft1000mp_caps =
 {
     RIG_MODEL(RIG_MODEL_FT1000MP),
     .model_name =         "FT-1000MP",
     .mfg_name =           "Yaesu",
-    .version =            "20230104.0",
+    .version =            "20241105.0",
     .copyright =          "LGPL",
     .status =             RIG_STATUS_STABLE,
     .rig_type =           RIG_TYPE_TRANSCEIVER,
@@ -455,12 +451,12 @@ const struct rig_caps ft1000mp_caps =
     .hamlib_check_rig_caps = HAMLIB_CHECK_RIG_CAPS
 };
 
-const struct rig_caps ft1000mpmkv_caps =
+struct rig_caps ft1000mpmkv_caps =
 {
     RIG_MODEL(RIG_MODEL_FT1000MPMKV),
     .model_name =         "MARK-V FT-1000MP",
     .mfg_name =           "Yaesu",
-    .version =            "20230104.0",
+    .version =            "20241105.0",
     .copyright =          "LGPL",
     .status =             RIG_STATUS_STABLE,
     .rig_type =           RIG_TYPE_TRANSCEIVER,
@@ -598,12 +594,12 @@ const struct rig_caps ft1000mpmkv_caps =
     /* TODO: the remaining ... */
 };
 
-const struct rig_caps ft1000mpmkvfld_caps =
+struct rig_caps ft1000mpmkvfld_caps =
 {
     RIG_MODEL(RIG_MODEL_FT1000MPMKVFLD),
     .model_name =         "MARK-V Field FT-1000MP",
     .mfg_name =           "Yaesu",
-    .version =            "20230104.0",
+    .version =            "20241105.0",
     .copyright =          "LGPL",
     .status =             RIG_STATUS_STABLE,
     .rig_type =           RIG_TYPE_TRANSCEIVER,
@@ -753,15 +749,15 @@ static int ft1000mp_init(RIG *rig)
 
     ENTERFUNC;
 
-    rig->state.priv = (struct ft1000mp_priv_data *) calloc(1,
-                      sizeof(struct ft1000mp_priv_data));
+    STATE(rig)->priv = (struct ft1000mp_priv_data *) calloc(1,
+                       sizeof(struct ft1000mp_priv_data));
 
-    if (!rig->state.priv)                       /* whoops! memory shortage! */
+    if (!STATE(rig)->priv)                       /* whoops! memory shortage! */
     {
         RETURNFUNC(-RIG_ENOMEM);
     }
 
-    priv = rig->state.priv;
+    priv = STATE(rig)->priv;
 
     /* TODO: read pacing from preferences */
     priv->pacing =
@@ -781,12 +777,12 @@ static int ft1000mp_cleanup(RIG *rig)
 {
     ENTERFUNC;
 
-    if (rig->state.priv)
+    if (STATE(rig)->priv)
     {
-        free(rig->state.priv);
+        free(STATE(rig)->priv);
     }
 
-    rig->state.priv = NULL;
+    STATE(rig)->priv = NULL;
 
     RETURNFUNC(RIG_OK);
 }
@@ -800,19 +796,20 @@ static int ft1000mp_cleanup(RIG *rig)
 static int ft1000mp_open(RIG *rig)
 {
     struct rig_state *rig_s;
+    hamlib_port_t *rp = RIGPORT(rig);
     struct ft1000mp_priv_data *p;
     unsigned char *cmd;           /* points to sequence to send */
 
     ENTERFUNC;
 
-    rig_s = &rig->state;
+    rig_s = STATE(rig);
     p = (struct ft1000mp_priv_data *)rig_s->priv;
 
     rig_debug(RIG_DEBUG_TRACE, "%s: rig_open: write_delay = %i msec \n", __func__,
-              rig_s->rigport.write_delay);
+              rp->write_delay);
     rig_debug(RIG_DEBUG_TRACE, "%s: rig_open: post_write_delay = %i msec \n",
               __func__,
-              rig_s->rigport.post_write_delay);
+              rp->post_write_delay);
 
     /*
      * Copy native cmd PACING  to private cmd storage area
@@ -823,9 +820,9 @@ static int ft1000mp_open(RIG *rig)
 
     /* send PACING cmd to rig  */
     cmd = p->p_cmd;
-    write_block(&rig->state.rigport, cmd, YAESU_CMD_LENGTH);
+    write_block(rp, cmd, YAESU_CMD_LENGTH);
 
-    ft1000mp_get_vfo(rig, &rig->state.current_vfo);
+    ft1000mp_get_vfo(rig, &rig_s->current_vfo);
     /* TODO */
 
     RETURNFUNC(RIG_OK);
@@ -841,7 +838,7 @@ static int ft1000mp_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 
     ENTERFUNC;
 
-    p = (struct ft1000mp_priv_data *)rig->state.priv;
+    p = (struct ft1000mp_priv_data *)STATE(rig)->priv;
 
     rig_debug(RIG_DEBUG_TRACE, "%s: requested freq on %s = %"PRIfreq" Hz \n",
               __func__,
@@ -849,22 +846,28 @@ static int ft1000mp_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 
     if (vfo == RIG_VFO_CURR)
     {
-        vfo = rig->state.current_vfo;
+        vfo = STATE(rig)->current_vfo;
     }
 
+    // round freq to 10Hz intervals due to rig restriction
+    freq = round(freq / 10.0) * 10.0;
+
     switch (vfo)
     {
     case RIG_VFO_A:
         cmd_index = FT1000MP_NATIVE_FREQA_SET;
+        CACHE(rig)->freqMainA = freq;
         break;
 
     case RIG_VFO_B:
         cmd_index = FT1000MP_NATIVE_FREQB_SET;
+        CACHE(rig)->freqMainB = freq;
         break;
 
     case RIG_VFO_MEM:
-        /* TODO, hint: store current memory number */
-        RETURNFUNC(-RIG_ENIMPL);
+        // we can set VFOA when VFO MEM is selected
+        cmd_index = FT1000MP_NATIVE_FREQA_SET;
+        break;
 
     default:
         rig_debug(RIG_DEBUG_WARN, "%s: unknown VFO %0x\n", __func__, vfo);
@@ -876,16 +879,14 @@ static int ft1000mp_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
      */
     memcpy(&p->p_cmd, &ncmd[cmd_index].nseq, YAESU_CMD_LENGTH);
 
-    // round freq to 10Hz intervals due to rig restriction
-    freq = round(freq / 10.0) * 10.0;
-
     to_bcd(p->p_cmd, freq / 10, 8); /* store bcd format in in p_cmd */
 
     rig_debug(RIG_DEBUG_TRACE, "%s: freq = %"PRIfreq" Hz\n", __func__,
               (freq_t)from_bcd(p->p_cmd, 8) * 10);
 
     cmd = p->p_cmd;               /* get native sequence */
-    write_block(&rig->state.rigport, cmd, YAESU_CMD_LENGTH);
+    write_block(RIGPORT(rig), cmd, YAESU_CMD_LENGTH);
+
 
     RETURNFUNC(RIG_OK);
 }
@@ -932,8 +933,8 @@ static int ft1000mp_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
     if (vfo == RIG_VFO_CURR)
     {
         rig_debug(RIG_DEBUG_TRACE, "%s: current_vfo=%s\n", __func__,
-                  rig_strvfo(rig->state.current_vfo));
-        vfo = rig->state.current_vfo;
+                  rig_strvfo(STATE(rig)->current_vfo));
+        vfo = STATE(rig)->current_vfo;
     }
 
     retval = ft1000mp_get_vfo_data(rig, vfo);
@@ -944,7 +945,7 @@ static int ft1000mp_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
         RETURNFUNC(retval);
     }
 
-    priv = (struct ft1000mp_priv_data *)rig->state.priv;
+    priv = (struct ft1000mp_priv_data *)STATE(rig)->priv;
 
     if (vfo == RIG_VFO_B)
     {
@@ -962,7 +963,7 @@ static int ft1000mp_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
               f,
               vfo);
 
-    *freq = f;                    /* return displayed frequency */
+    *freq = f;                    // return displayed frequency
 
     RETURNFUNC(RIG_OK);
 }
@@ -988,8 +989,8 @@ static int ft1000mp_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
     if (vfo == RIG_VFO_CURR)
     {
         rig_debug(RIG_DEBUG_TRACE, "%s: current_vfo=%s\n", __func__,
-                  rig_strvfo(rig->state.current_vfo));
-        vfo = rig->state.current_vfo;
+                  rig_strvfo(STATE(rig)->current_vfo));
+        vfo = STATE(rig)->current_vfo;
     }
 
     /*
@@ -1103,14 +1104,15 @@ static int ft1000mp_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode,
     unsigned char mymode;         /* ft1000mp mode */
     unsigned char mymode_ext; /* ft1000mp extra mode bit mode */
     int retval;
+    struct rig_state *rs = STATE(rig);
 
     ENTERFUNC;
 
     if (vfo == RIG_VFO_CURR)
     {
         rig_debug(RIG_DEBUG_TRACE, "%s: current_vfo=%s\n", __func__,
-                  rig_strvfo(rig->state.current_vfo));
-        vfo = rig->state.current_vfo;
+                  rig_strvfo(rs->current_vfo));
+        vfo = rs->current_vfo;
     }
 
     retval = ft1000mp_get_vfo_data(rig, vfo);
@@ -1120,7 +1122,7 @@ static int ft1000mp_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode,
         RETURNFUNC(retval);
     }
 
-    priv = (struct ft1000mp_priv_data *)rig->state.priv;
+    priv = (struct ft1000mp_priv_data *)rs->priv;
 
     if (vfo == RIG_VFO_B)
     {
@@ -1210,7 +1212,7 @@ static int ft1000mp_set_vfo(RIG *rig, vfo_t vfo)
 
     if (vfo == RIG_VFO_VFO)
     {
-        vfo = rig->state.current_vfo;
+        vfo = STATE(rig)->current_vfo;
     }
 
 #if 0 // seems switching VFOs like this changes the frequencies in the response
@@ -1219,13 +1221,13 @@ static int ft1000mp_set_vfo(RIG *rig, vfo_t vfo)
     {
     case RIG_VFO_A:
         cmd_index = FT1000MP_NATIVE_VFO_A;
-        rig->state.current_vfo = vfo;       /* update active VFO */
+        STATE(rig)->current_vfo = vfo;       /* update active VFO */
         rig_debug(RIG_DEBUG_TRACE, "%s: vfo == RIG_VFO_A\n", __func__);
         break;
 
     case RIG_VFO_B:
         cmd_index = FT1000MP_NATIVE_VFO_B;
-        rig->state.current_vfo = vfo;       /* update active VFO */
+        STATE(rig)->current_vfo = vfo;       /* update active VFO */
         rig_debug(RIG_DEBUG_TRACE, "%s: vfo == RIG_VFO_B\n", __func__);
         break;
 
@@ -1245,7 +1247,7 @@ static int ft1000mp_set_vfo(RIG *rig, vfo_t vfo)
 #endif
 
     // we just store the requested vfo in our internal state
-    rig->state.current_vfo = vfo;
+    STATE(rig)->current_vfo = vfo;
 
     RETURNFUNC(RIG_OK);
 
@@ -1265,7 +1267,7 @@ static int ft1000mp_get_vfo(RIG *rig, vfo_t *vfo)
 
     ENTERFUNC;
 
-    p = (struct ft1000mp_priv_data *)rig->state.priv;
+    p = (struct ft1000mp_priv_data *)STATE(rig)->priv;
 
     /* Get flags for VFO status */
     retval = ft1000mp_get_update_data(rig, FT1000MP_NATIVE_UPDATE,
@@ -1282,7 +1284,7 @@ static int ft1000mp_get_vfo(RIG *rig, vfo_t *vfo)
     }
     else // we are emulating vfo status
     {
-        *vfo = rig->state.current_vfo;
+        *vfo = STATE(rig)->current_vfo;
 
         if (*vfo == RIG_VFO_CURR)
         {
@@ -1294,11 +1296,11 @@ static int ft1000mp_get_vfo(RIG *rig, vfo_t *vfo)
 #if 0
     else if (p->update_data[FT1000MP_SUMO_DISPLAYED_STATUS] & SF_VFOAB)
     {
-        *vfo = rig->state.current_vfo = RIG_VFO_B;
+        *vfo = STATE(rig)->current_vfo = RIG_VFO_B;
     }
     else
     {
-        *vfo = rig->state.current_vfo = RIG_VFO_A;
+        *vfo = STATE(rig)->current_vfo = RIG_VFO_A;
     }
 
 #endif
@@ -1312,12 +1314,11 @@ static int ft1000mp_get_vfo(RIG *rig, vfo_t *vfo)
 static int ft1000mp_set_func(RIG *rig, vfo_t vfo, setting_t func, int status)
 {
     struct ft1000mp_priv_data *priv;
-    struct rig_state *rs;
+    hamlib_port_t *rp = RIGPORT(rig);
     unsigned char *cmd;
 
     ENTERFUNC;
-    rs = &rig->state;
-    priv = (struct ft1000mp_priv_data *)rig->state.priv;
+    priv = (struct ft1000mp_priv_data *)STATE(rig)->priv;
 
     switch (func)
     {
@@ -1333,7 +1334,7 @@ static int ft1000mp_set_func(RIG *rig, vfo_t vfo, setting_t func, int status)
 
         cmd = priv->p_cmd;
 
-        write_block(&rs->rigport, cmd, YAESU_CMD_LENGTH);
+        write_block(rp, cmd, YAESU_CMD_LENGTH);
         RETURNFUNC(RIG_OK);
 
     case RIG_FUNC_XIT:
@@ -1348,7 +1349,7 @@ static int ft1000mp_set_func(RIG *rig, vfo_t vfo, setting_t func, int status)
 
         cmd = priv->p_cmd;
 
-        write_block(&rs->rigport, cmd, YAESU_CMD_LENGTH);
+        write_block(rp, cmd, YAESU_CMD_LENGTH);
         RETURNFUNC(RIG_OK);
 
     default:
@@ -1366,7 +1367,7 @@ static int ft1000mp_get_func(RIG *rig, vfo_t vfo, setting_t func, int *status)
     unsigned char *p;
 
     ENTERFUNC;
-    priv = (struct ft1000mp_priv_data *)rig->state.priv;
+    priv = (struct ft1000mp_priv_data *)STATE(rig)->priv;
 
     if (!status)
     {
@@ -1461,7 +1462,7 @@ static int ft1000mp_set_rxit(RIG *rig, vfo_t vfo, shortfreq_t rit)
 
     ENTERFUNC;
 
-    rs = &rig->state;
+    rs = STATE(rig);
     priv = (struct ft1000mp_priv_data *)rs->priv;
 
     rig_debug(RIG_DEBUG_TRACE, "%s: requested freq = %d Hz\n", __func__, (int)rit);
@@ -1490,7 +1491,7 @@ static int ft1000mp_set_rxit(RIG *rig, vfo_t vfo, shortfreq_t rit)
     priv->p_cmd[2] = direction;
 
     cmd = priv->p_cmd;               /* get native sequence */
-    write_block(&rs->rigport, cmd, YAESU_CMD_LENGTH);
+    write_block(RIGPORT(rig), cmd, YAESU_CMD_LENGTH);
 
     RETURNFUNC(RIG_OK);
 }
@@ -1510,7 +1511,7 @@ static int ft1000mp_get_rxit(RIG *rig, vfo_t vfo, shortfreq_t *rit)
 
     ENTERFUNC;
 
-    priv = (struct ft1000mp_priv_data *)rig->state.priv;
+    priv = (struct ft1000mp_priv_data *)STATE(rig)->priv;
 
     retval = ft1000mp_get_vfo_data(rig, vfo);
 
@@ -1541,7 +1542,7 @@ static int ft1000mp_get_rxit(RIG *rig, vfo_t vfo, shortfreq_t *rit)
     rig_debug(RIG_DEBUG_TRACE, "%s: freq = %d Hz for VFO [%s]\n", __func__, (int)f,
               rig_strvfo(vfo));
 
-    *rit = f;     /* return displayed frequency */
+    *rit = f;     // return displayed frequency
 
     RETURNFUNC(RIG_OK);
 }
@@ -1552,13 +1553,14 @@ static int ft1000mp_get_level(RIG *rig, vfo_t vfo, setting_t level,
 {
     struct ft1000mp_priv_data *priv;
     struct rig_state *rs;
+    hamlib_port_t *rp = RIGPORT(rig);
     unsigned char lvl_data[YAESU_CMD_LENGTH];
     int m;
     int retval;
-    int retry = rig->state.rigport.retry;
+    int retry = rp->retry;
 
     ENTERFUNC;
-    rs = &rig->state;
+    rs = STATE(rig);
     priv = (struct ft1000mp_priv_data *)rs->priv;
 
 
@@ -1570,7 +1572,7 @@ static int ft1000mp_get_level(RIG *rig, vfo_t vfo, setting_t level,
     case RIG_LEVEL_RAWSTR:
         if (vfo == RIG_VFO_CURR)
         {
-            vfo = rig->state.current_vfo;
+            vfo = rs->current_vfo;
         }
 
         m = vfo == RIG_VFO_B ? 0x01 : 0x00;
@@ -1615,9 +1617,9 @@ static int ft1000mp_get_level(RIG *rig, vfo_t vfo, setting_t level,
 
     do
     {
-        write_block(&rs->rigport, priv->p_cmd, YAESU_CMD_LENGTH);
+        write_block(rp, priv->p_cmd, YAESU_CMD_LENGTH);
 
-        retval = read_block(&rs->rigport, lvl_data, YAESU_CMD_LENGTH);
+        retval = read_block(rp, lvl_data, YAESU_CMD_LENGTH);
     }
     while (retry-- && retval == -RIG_ETIMEOUT);
 
@@ -1685,14 +1687,14 @@ static int ft1000mp_get_update_data(RIG *rig, unsigned char ci,
 
     ENTERFUNC;
 
-    p = (struct ft1000mp_priv_data *)rig->state.priv;
+    p = (struct ft1000mp_priv_data *)STATE(rig)->priv;
 
     // timeout retries are done in read_block now
     // based on rig backed retry value
     /* send UPDATE command to fetch data*/
     ft1000mp_send_priv_cmd(rig, ci);
 
-    n = read_block(&rig->state.rigport, p->update_data, rl);
+    n = read_block(RIGPORT(rig), p->update_data, rl);
 
     if (n == -RIG_ETIMEOUT)
     {
@@ -1721,7 +1723,7 @@ static int ft1000mp_send_priv_cmd(RIG *rig, unsigned char ci)
         RETURNFUNC(-RIG_EINVAL);
     }
 
-    write_block(&rig->state.rigport, ncmd[ci].nseq, YAESU_CMD_LENGTH);
+    write_block(RIGPORT(rig), ncmd[ci].nseq, YAESU_CMD_LENGTH);
 
     RETURNFUNC(RIG_OK);
 
@@ -1731,6 +1733,7 @@ static int ft1000mp_set_split_vfo(RIG *rig, vfo_t vfo, split_t split,
                                   vfo_t tx_vfo)
 {
     unsigned char cmd_index = 0;      /* index of sequence to send */
+    struct rig_state *rs = STATE(rig);
 
     ENTERFUNC;
     rig_debug(RIG_DEBUG_TRACE, "%s called rx_vfo=%s, tx_vfo=%s\n", __func__,
@@ -1752,9 +1755,9 @@ static int ft1000mp_set_split_vfo(RIG *rig, vfo_t vfo, split_t split,
     }
 
     // manual says VFO_A=Tx and VFO_B=Rx but testing shows otherwise
-    rig->state.current_vfo = RIG_VFO_A;
-    rig->state.rx_vfo = RIG_VFO_B;
-    rig->state.tx_vfo = RIG_VFO_B;
+    rs->current_vfo = RIG_VFO_A;
+    rs->rx_vfo = RIG_VFO_B;
+    rs->tx_vfo = RIG_VFO_B;
     ft1000mp_send_priv_cmd(rig, cmd_index);
 
     RETURNFUNC(RIG_OK);
@@ -1773,7 +1776,7 @@ static int ft1000mp_get_split_vfo(RIG *rig, vfo_t vfo, split_t *split,
 
     ENTERFUNC;
 
-    p = (struct ft1000mp_priv_data *)rig->state.priv;
+    p = (struct ft1000mp_priv_data *)STATE(rig)->priv;
 
     /* Get flags for split status */
     retval = ft1000mp_get_update_data(rig, FT1000MP_NATIVE_UPDATE,
@@ -1812,6 +1815,7 @@ static int ft1000mp_set_split_mode(RIG *rig, vfo_t vfo, rmode_t tx_mode,
                                    pbwidth_t tx_width)
 {
     int retval;
+    ENTERFUNC;
     retval = rig_set_mode(rig, RIG_VFO_B, tx_mode, tx_width);
     RETURNFUNC(retval);
 }
@@ -1820,6 +1824,7 @@ static int ft1000mp_get_split_mode(RIG *rig, vfo_t vfo, rmode_t *tx_mode,
                                    pbwidth_t *tx_width)
 {
     int retval;
+    ENTERFUNC;
     retval = rig_get_mode(rig, RIG_VFO_B, tx_mode, tx_width);
     RETURNFUNC(retval);
 }
@@ -1828,6 +1833,7 @@ static int ft1000mp_set_split_freq_mode(RIG *rig, vfo_t vfo, freq_t freq,
                                         rmode_t mode, pbwidth_t width)
 {
     int retval;
+    ENTERFUNC;
     retval = rig_set_mode(rig, RIG_VFO_B, mode, width);
 
     if (retval != RIG_OK)
@@ -1841,8 +1847,8 @@ static int ft1000mp_set_split_freq_mode(RIG *rig, vfo_t vfo, freq_t freq,
 
     if (retval == RIG_OK)
     {
-        rig->state.cache.freqMainB = freq;
-        rig->state.cache.modeMainB = mode;
+        CACHE(rig)->freqMainB = freq;
+        CACHE(rig)->modeMainB = mode;
     }
 
     RETURNFUNC(retval);
@@ -1852,6 +1858,7 @@ static int ft1000mp_get_split_freq_mode(RIG *rig, vfo_t vfo, freq_t *freq,
                                         rmode_t *mode, pbwidth_t *width)
 {
     int retval;
+    ENTERFUNC;
     retval = rig_get_mode(rig, RIG_VFO_B, mode, width);
 
     if (retval != RIG_OK)
@@ -1865,8 +1872,8 @@ static int ft1000mp_get_split_freq_mode(RIG *rig, vfo_t vfo, freq_t *freq,
 
     if (retval == RIG_OK)
     {
-        rig->state.cache.freqMainB = *freq;
-        rig->state.cache.modeMainB = *mode;
+        CACHE(rig)->freqMainB = *freq;
+        CACHE(rig)->modeMainB = *mode;
     }
 
     RETURNFUNC(retval);
