@@ -25,9 +25,6 @@
  *
  */
 
-
-#include <hamlib/config.h>
-
 #include "hamlib/rig.h"
 #include "bandplan.h"
 #include "newcat.h"
@@ -37,12 +34,12 @@
 /*
  * FT-450 rig capabilities
  */
-const struct rig_caps ft450_caps =
+struct rig_caps ft450_caps =
 {
     RIG_MODEL(RIG_MODEL_FT450),
     .model_name =         "FT-450",
     .mfg_name =           "Yaesu",
-    .version =            NEWCAT_VER ".2",
+    .version =            NEWCAT_VER ".4",
     .copyright =          "LGPL",
     .status =             RIG_STATUS_STABLE,
     .rig_type =           RIG_TYPE_TRANSCEIVER,
@@ -63,17 +60,28 @@ const struct rig_caps ft450_caps =
     .has_set_func =       FT450_FUNCS,
     .has_get_level =      FT450_LEVELS,
     .has_set_level =      RIG_LEVEL_SET(FT450_LEVELS),
-    .has_get_parm =       RIG_PARM_NONE,
-    .has_set_parm =       RIG_PARM_NONE,
+    .has_get_parm =       RIG_PARM_BANDSELECT,
+    .has_set_parm =       RIG_PARM_BANDSELECT,
     .level_gran =
     {
+#define NO_LVL_CWPITCH
+#define NO_LVL_NOTCHF
+#define NO_LVL_VOXGAIN
+#define NO_LVL_NR
 #include "level_gran_yaesu.h"
-        // cppcheck-suppress *
-        [LVL_RAWSTR] = { .min = { .i = 0 }, .max = { .i = 255 } },
+#undef NO_LVL_CWPITCH
+#undef NO_LVL_NOTCHF
+#undef NO_LVL_VOXGAIN
+#undef NO_LVL_NR
         [LVL_CWPITCH] = { .min = { .i = 400 }, .max = { .i = 800 }, .step = { .i = 100 } },
-        [LVL_KEYSPD] = { .min = { .i = 4 }, .max = { .i = 60 }, .step = { .i = 1 } },
         [LVL_NOTCHF] = { .min = { .i = 1 }, .max = { .i = 4000 }, .step = { .i = 10 } },
+        [LVL_VOXGAIN] = { .min = { .f = 0 }, .max = { .f = 1.0 }, .step = { .f = 1.0f / 255.0f } },
+        [LVL_NR] = { .min = { .f = 0 }, .max = { .f = 1.0 }, .step = { .f = 1.0f / 11.0f } },
     },
+    .parm_gran =  {
+        [PARM_BANDSELECT] = {.min = {.f = 0.0f}, .max = {.f = 1.0f}, .step = {.s = "BAND160M,BAND80M,BANDUNUSED,BAND40M,BAND30M,BAND20M,BAND17M,BAND15M,BAND12M,BAND10M,BAND6M,BANDGEN"}}
+    },
+
     .ctcss_list =         common_ctcss_list,
     .dcs_list =           NULL,
     .preamp =             { 10, RIG_DBLST_END, }, /* TBC: Not specified in manual */
@@ -94,6 +102,7 @@ const struct rig_caps ft450_caps =
     .chan_list =          {
         {   1, 500, RIG_MTYPE_MEM,  NEWCAT_MEM_CAP },
         { 501, 504, RIG_MTYPE_EDGE, NEWCAT_MEM_CAP },    /* two by two */
+        {   1,   1, RIG_MTYPE_MORSE },
         RIG_CHAN_END,
     },
 
@@ -207,6 +216,7 @@ const struct rig_caps ft450_caps =
     .send_morse =         newcat_send_morse,
     .wait_morse =         rig_wait_morse,
     .scan =               newcat_scan,
+    .morse_qsize =        40,
     .hamlib_check_rig_caps = HAMLIB_CHECK_RIG_CAPS
 };
 
