@@ -25,8 +25,6 @@
  *
  */
 
-#include <hamlib/config.h>
-
 #include <stdlib.h>
 #include <string.h>  /* String function definitions */
 
@@ -241,7 +239,7 @@ struct ft840_priv_data
  *
  */
 
-const struct rig_caps ft840_caps =
+struct rig_caps ft840_caps =
 {
     RIG_MODEL(RIG_MODEL_FT840),
     .model_name =         "FT-840",
@@ -389,15 +387,15 @@ static int ft840_init(RIG *rig)
         return -RIG_EINVAL;
     }
 
-    rig->state.priv = (struct ft840_priv_data *) calloc(1,
-                      sizeof(struct ft840_priv_data));
+    STATE(rig)->priv = (struct ft840_priv_data *) calloc(1,
+                       sizeof(struct ft840_priv_data));
 
-    if (!rig->state.priv)                       /* whoops! memory shortage! */
+    if (!STATE(rig)->priv)                       /* whoops! memory shortage! */
     {
         return -RIG_ENOMEM;
     }
 
-    priv = rig->state.priv;
+    priv = STATE(rig)->priv;
 
     /* TODO: read pacing from preferences */
     priv->pacing = FT840_PACING_DEFAULT_VALUE; /* set pacing to minimum for now */
@@ -424,12 +422,12 @@ static int ft840_cleanup(RIG *rig)
         return -RIG_EINVAL;
     }
 
-    if (rig->state.priv)
+    if (STATE(rig)->priv)
     {
-        free(rig->state.priv);
+        free(STATE(rig)->priv);
     }
 
-    rig->state.priv = NULL;
+    STATE(rig)->priv = NULL;
 
     return RIG_OK;
 }
@@ -442,7 +440,6 @@ static int ft840_cleanup(RIG *rig)
 
 static int ft840_open(RIG *rig)
 {
-    struct rig_state *rig_s;
     struct ft840_priv_data *priv;
     int err;
 
@@ -453,13 +450,12 @@ static int ft840_open(RIG *rig)
         return -RIG_EINVAL;
     }
 
-    priv = (struct ft840_priv_data *)rig->state.priv;
-    rig_s = &rig->state;
+    priv = (struct ft840_priv_data *)STATE(rig)->priv;
 
     rig_debug(RIG_DEBUG_TRACE, "%s: write_delay = %i msec\n",
-              __func__, rig_s->rigport.write_delay);
+              __func__, RIGPORT(rig)->write_delay);
     rig_debug(RIG_DEBUG_TRACE, "%s: post_write_delay = %i msec\n",
-              __func__, rig_s->rigport.post_write_delay);
+              __func__, RIGPORT(rig)->post_write_delay);
     rig_debug(RIG_DEBUG_TRACE,
               "%s: read pacing = %i\n", __func__, priv->pacing);
 
@@ -517,7 +513,7 @@ static int ft840_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
         return -RIG_EINVAL;
     }
 
-    priv = (struct ft840_priv_data *)rig->state.priv;
+    priv = (struct ft840_priv_data *)STATE(rig)->priv;
 
     rig_debug(RIG_DEBUG_TRACE, "%s: passed vfo = 0x%02x\n", __func__, vfo);
     rig_debug(RIG_DEBUG_TRACE, "%s: passed freq = %"PRIfreq" Hz\n", __func__, freq);
@@ -573,7 +569,7 @@ static int ft840_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
         return -RIG_EINVAL;
     }
 
-    priv = (struct ft840_priv_data *)rig->state.priv;
+    priv = (struct ft840_priv_data *)STATE(rig)->priv;
 
     if (vfo == RIG_VFO_CURR)
     {
@@ -664,7 +660,7 @@ static int ft840_set_mode(RIG *rig, vfo_t vfo, rmode_t mode,
               rig_strrmode(mode));
     rig_debug(RIG_DEBUG_TRACE, "%s: passed width = %d Hz\n", __func__, (int)width);
 
-    priv = (struct ft840_priv_data *)rig->state.priv;
+    priv = (struct ft840_priv_data *)STATE(rig)->priv;
 
     if (vfo == RIG_VFO_CURR)
     {
@@ -801,7 +797,7 @@ static int ft840_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
 
     rig_debug(RIG_DEBUG_TRACE, "%s: passed vfo = 0x%02x\n", __func__, vfo);
 
-    priv = (struct ft840_priv_data *)rig->state.priv;
+    priv = (struct ft840_priv_data *)STATE(rig)->priv;
 
     if (vfo == RIG_VFO_CURR)
     {
@@ -945,7 +941,7 @@ static int ft840_set_vfo(RIG *rig, vfo_t vfo)
 
     rig_debug(RIG_DEBUG_TRACE, "%s: passed vfo = 0x%02x\n", __func__, vfo);
 
-    priv = (struct ft840_priv_data *)rig->state.priv;
+    priv = (struct ft840_priv_data *)STATE(rig)->priv;
 
     if (vfo == RIG_VFO_CURR)
     {
@@ -1025,7 +1021,7 @@ static int ft840_get_vfo(RIG *rig, vfo_t *vfo)
         return -RIG_EINVAL;
     }
 
-    priv = (struct ft840_priv_data *)rig->state.priv;
+    priv = (struct ft840_priv_data *)STATE(rig)->priv;
 
     /* Get flags for VFO status */
     err = ft840_get_update_data(rig, FT840_NATIVE_READ_FLAGS,
@@ -1131,7 +1127,7 @@ static int ft840_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt)
         return -RIG_EINVAL;
     }
 
-    priv = (struct ft840_priv_data *)rig->state.priv;
+    priv = (struct ft840_priv_data *)STATE(rig)->priv;
 
     rig_debug(RIG_DEBUG_TRACE, "%s: passed vfo = 0x%02x\n", __func__, vfo);
     rig_debug(RIG_DEBUG_TRACE, "%s: passed ptt = 0x%02x\n", __func__, ptt);
@@ -1194,7 +1190,7 @@ static int ft840_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt)
         return -RIG_EINVAL;
     }
 
-    priv = (struct ft840_priv_data *)rig->state.priv;
+    priv = (struct ft840_priv_data *)STATE(rig)->priv;
 
     /* Get flags for VFO status */
     err = ft840_get_update_data(rig, FT840_NATIVE_READ_FLAGS,
@@ -1307,7 +1303,7 @@ static int ft840_get_split_vfo(RIG *rig, vfo_t vfo, split_t *split,
 
     rig_debug(RIG_DEBUG_TRACE, "%s: passed vfo = 0x%02x\n", __func__, vfo);
 
-    priv = (struct ft840_priv_data *)rig->state.priv;
+    priv = (struct ft840_priv_data *)STATE(rig)->priv;
 
     /* Get flags for VFO split status */
     err = ft840_get_update_data(rig, FT840_NATIVE_READ_FLAGS,
@@ -1374,7 +1370,7 @@ static int ft840_set_rit(RIG *rig, vfo_t vfo, shortfreq_t rit)
     rig_debug(RIG_DEBUG_TRACE, "%s: passed vfo = 0x%02x\n", __func__, vfo);
     rig_debug(RIG_DEBUG_TRACE, "%s: passed rit = %li\n", __func__, rit);
 
-    priv = (struct ft840_priv_data *)rig->state.priv;
+    priv = (struct ft840_priv_data *)STATE(rig)->priv;
 
     /*
      * The assumption here is that the user hasn't changed
@@ -1454,7 +1450,7 @@ static int ft840_get_rit(RIG *rig, vfo_t vfo, shortfreq_t *rit)
 
     rig_debug(RIG_DEBUG_TRACE, "%s: passed vfo = 0x%02x\n", __func__, vfo);
 
-    priv = (struct ft840_priv_data *)rig->state.priv;
+    priv = (struct ft840_priv_data *)STATE(rig)->priv;
 
     if (vfo == RIG_VFO_CURR)
     {
@@ -1606,7 +1602,7 @@ static int ft840_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
     rig_debug(RIG_DEBUG_TRACE, "%s: passed level = %s\n", __func__,
               rig_strlevel(level));
 
-    priv = (struct ft840_priv_data *)rig->state.priv;
+    priv = (struct ft840_priv_data *)STATE(rig)->priv;
 
     switch (level)
     {
@@ -1724,7 +1720,7 @@ static int ft840_vfo_op(RIG *rig, vfo_t vfo, vfo_op_t op)
  *              rl      expected length of returned data in octets
  *
  * Returns:     RIG_OK if all called functions are successful,
- *              otherwise returns error from called functiion
+ *              otherwise returns error from called function
  */
 
 static int ft840_get_update_data(RIG *rig, unsigned char ci, unsigned char rl)
@@ -1739,7 +1735,7 @@ static int ft840_get_update_data(RIG *rig, unsigned char ci, unsigned char rl)
         return -RIG_EINVAL;
     }
 
-    priv = (struct ft840_priv_data *)rig->state.priv;
+    priv = (struct ft840_priv_data *)STATE(rig)->priv;
 
     err = ft840_send_static_cmd(rig, ci);
 
@@ -1748,7 +1744,7 @@ static int ft840_get_update_data(RIG *rig, unsigned char ci, unsigned char rl)
         return err;
     }
 
-    n = read_block(&rig->state.rigport, priv->update_data, rl);
+    n = read_block(RIGPORT(rig), priv->update_data, rl);
 
     if (n < 0)
     {
@@ -1770,7 +1766,7 @@ static int ft840_get_update_data(RIG *rig, unsigned char ci, unsigned char rl)
  *              ci      Command index of the ncmd table
  *
  * Returns:     RIG_OK if all called functions are successful,
- *              otherwise returns error from called functiion
+ *              otherwise returns error from called function
  */
 
 static int ft840_send_static_cmd(RIG *rig, unsigned char ci)
@@ -1791,7 +1787,7 @@ static int ft840_send_static_cmd(RIG *rig, unsigned char ci)
         return -RIG_EINVAL;
     }
 
-    err = write_block(&rig->state.rigport, ncmd[ci].nseq,
+    err = write_block(RIGPORT(rig), ncmd[ci].nseq,
                       YAESU_CMD_LENGTH);
 
     if (err != RIG_OK)
@@ -1814,7 +1810,7 @@ static int ft840_send_static_cmd(RIG *rig, unsigned char ci)
  *              p1-p4   Command parameters
  *
  * Returns:     RIG_OK if all called functions are successful,
- *              otherwise returns error from called functiion
+ *              otherwise returns error from called function
  */
 
 static int ft840_send_dynamic_cmd(RIG *rig, unsigned char ci,
@@ -1836,7 +1832,7 @@ static int ft840_send_dynamic_cmd(RIG *rig, unsigned char ci,
               "%s: passed p1 = 0x%02x, p2 = 0x%02x, p3 = 0x%02x, p4 = 0x%02x,\n",
               __func__, p1, p2, p3, p4);
 
-    priv = (struct ft840_priv_data *)rig->state.priv;
+    priv = (struct ft840_priv_data *)STATE(rig)->priv;
 
     if (ncmd[ci].ncomp)
     {
@@ -1852,7 +1848,7 @@ static int ft840_send_dynamic_cmd(RIG *rig, unsigned char ci,
     priv->p_cmd[P3] = p3;
     priv->p_cmd[P4] = p4;
 
-    err = write_block(&rig->state.rigport, (unsigned char *) &priv->p_cmd,
+    err = write_block(RIGPORT(rig), (unsigned char *) &priv->p_cmd,
                       YAESU_CMD_LENGTH);
 
     if (err != RIG_OK)
@@ -1875,7 +1871,7 @@ static int ft840_send_dynamic_cmd(RIG *rig, unsigned char ci,
  *              freq    freq_t frequency value
  *
  * Returns:     RIG_OK if all called functions are successful,
- *              otherwise returns error from called functiion
+ *              otherwise returns error from called function
  */
 
 static int ft840_send_dial_freq(RIG *rig, unsigned char ci, freq_t freq)
@@ -1895,7 +1891,7 @@ static int ft840_send_dial_freq(RIG *rig, unsigned char ci, freq_t freq)
     rig_debug(RIG_DEBUG_TRACE, "%s: passed ci = %i\n", __func__, ci);
     rig_debug(RIG_DEBUG_TRACE, "%s: passed freq = %"PRIfreq" Hz\n", __func__, freq);
 
-    priv = (struct ft840_priv_data *)rig->state.priv;
+    priv = (struct ft840_priv_data *)STATE(rig)->priv;
 
     if (ncmd[ci].ncomp)
     {
@@ -1913,7 +1909,7 @@ static int ft840_send_dial_freq(RIG *rig, unsigned char ci, freq_t freq)
     rig_debug(RIG_DEBUG_TRACE, fmt, __func__, (int64_t)from_bcd(priv->p_cmd,
               FT840_BCD_DIAL) * 10);
 
-    err = write_block(&rig->state.rigport, (unsigned char *) &priv->p_cmd,
+    err = write_block(RIGPORT(rig), (unsigned char *) &priv->p_cmd,
                       YAESU_CMD_LENGTH);
 
     if (err != RIG_OK)
@@ -1938,7 +1934,7 @@ static int ft840_send_dial_freq(RIG *rig, unsigned char ci, freq_t freq)
  *              p2      P2 value -- CLAR_OFFSET_PLUS || CLAR_OFFSET_MINUS
  *
  * Returns:     RIG_OK if all called functions are successful,
- *              otherwise returns error from called functiion
+ *              otherwise returns error from called function
  *
  * Assumes:     rit doesn't exceed tuning limits of rig
  */
@@ -1961,7 +1957,7 @@ static int ft840_send_rit_freq(RIG *rig, unsigned char ci, shortfreq_t rit)
     rig_debug(RIG_DEBUG_TRACE, "%s: passed ci = %i\n", __func__, ci);
     rig_debug(RIG_DEBUG_TRACE, "%s: passed rit = %li Hz\n", __func__, rit);
 
-    priv = (struct ft840_priv_data *)rig->state.priv;
+    priv = (struct ft840_priv_data *)STATE(rig)->priv;
 
     if (ncmd[ci].ncomp)
     {
@@ -1995,7 +1991,7 @@ static int ft840_send_rit_freq(RIG *rig, unsigned char ci, shortfreq_t rit)
     priv->p_cmd[P1] = p1;         /* ick */
     priv->p_cmd[P2] = p2;
 
-    err = write_block(&rig->state.rigport, (char *) &priv->p_cmd,
+    err = write_block(RIGPORT(rig), (char *) &priv->p_cmd,
                       YAESU_CMD_LENGTH);
 
     if (err != RIG_OK)
