@@ -44,8 +44,6 @@
  *
  */
 
-#include <hamlib/config.h>
-
 #include <stdlib.h>
 #include <string.h>  /* String function definitions */
 
@@ -381,12 +379,12 @@ static tone_t ft650_ctcss_list[] =
  * Notice that some rigs share the same functions.
  */
 
-const struct rig_caps ft847_caps =
+struct rig_caps ft847_caps =
 {
     RIG_MODEL(RIG_MODEL_FT847),
     .model_name = "FT-847",
     .mfg_name =  "Yaesu",
-    .version =  "20220525.0",
+    .version =  "20230512.0",
     .copyright =  "LGPL",
     .status =  RIG_STATUS_STABLE,
     .rig_type =  RIG_TYPE_TRANSCEIVER,
@@ -539,12 +537,12 @@ const struct rig_caps ft847_caps =
  * Notice that some rigs share the same functions.
  */
 
-const struct rig_caps ft650_caps =
+struct rig_caps ft650_caps =
 {
     RIG_MODEL(RIG_MODEL_FT650),
     .model_name = "FT-650",
     .mfg_name =  "Yaesu",
-    .version =  "20220525.0",
+    .version =  "20230512.0",
     .copyright =  "LGPL",
     .status =  RIG_STATUS_STABLE,
     .rig_type =  RIG_TYPE_TRANSCEIVER,
@@ -677,12 +675,12 @@ const struct rig_caps ft650_caps =
     .hamlib_check_rig_caps = HAMLIB_CHECK_RIG_CAPS
 };
 
-const struct rig_caps mchfqrp_caps =
+struct rig_caps mchfqrp_caps =
 {
     RIG_MODEL(RIG_MODEL_MCHFQRP),
     .model_name = "mcHF QRP",
     .mfg_name =  "M0NKA",
-    .version =  "20220525.0",
+    .version =  "20230512.0",
     .copyright =  "LGPL",
     .status =  RIG_STATUS_STABLE,
     .rig_type =  RIG_TYPE_TRANSCEIVER,
@@ -850,12 +848,12 @@ improvements. This version was made in May 1998. Later serial numbers (e.g.,
 8L09nnnn) all seem to have incorporated the earlier improvements plus new
 ones...."
  */
-const struct rig_caps ft847uni_caps =
+struct rig_caps ft847uni_caps =
 {
     RIG_MODEL(RIG_MODEL_FT847UNI),
     .model_name = "FT-847UNI",
     .mfg_name =  "Yaesu",
-    .version =  "20210221.0",
+    .version =  "20230511.0",
     .copyright =  "LGPL",
     .status =  RIG_STATUS_STABLE,
     .rig_type =  RIG_TYPE_TRANSCEIVER,
@@ -1007,7 +1005,7 @@ const struct rig_caps ft847uni_caps =
 
 /*
  * setup *priv
- * serial port is already open (rig->state->fd)
+ * serial port is already open (STATE(rig)->fd)
  */
 
 static int ft847_init(RIG *rig)
@@ -1021,16 +1019,16 @@ static int ft847_init(RIG *rig)
         return -RIG_EINVAL;
     }
 
-    rig->state.priv = (struct ft847_priv_data *) calloc(1,
-                      sizeof(struct ft847_priv_data));
+    STATE(rig)->priv = (struct ft847_priv_data *) calloc(1,
+                       sizeof(struct ft847_priv_data));
 
-    if (!rig->state.priv)
+    if (!STATE(rig)->priv)
     {
         /* whoops! memory shortage! */
         return -RIG_ENOMEM;
     }
 
-    priv = rig->state.priv;
+    priv = STATE(rig)->priv;
 
 
     priv->sat_mode = RIG_SPLIT_OFF;
@@ -1059,12 +1057,12 @@ static int ft847_cleanup(RIG *rig)
         return -RIG_EINVAL;
     }
 
-    if (rig->state.priv)
+    if (STATE(rig)->priv)
     {
-        free(rig->state.priv);
+        free(STATE(rig)->priv);
     }
 
-    rig->state.priv = NULL;
+    STATE(rig)->priv = NULL;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called \n", __func__);
 
@@ -1121,7 +1119,7 @@ static int ft847_send_priv_cmd(RIG *rig, int cmd_index)
         return -RIG_EINVAL;
     }
 
-    return write_block(&rig->state.rigport, ncmd[cmd_index].nseq,
+    return write_block(RIGPORT(rig), ncmd[cmd_index].nseq,
                        YAESU_CMD_LENGTH);
 }
 
@@ -1132,14 +1130,14 @@ static int ft847_send_priv_cmd(RIG *rig, int cmd_index)
  */
 static int opcode_vfo(RIG *rig, unsigned char *cmd, int cmd_index, vfo_t vfo)
 {
-    struct ft847_priv_data *p = (struct ft847_priv_data *)rig->state.priv;
+    struct ft847_priv_data *p = (struct ft847_priv_data *)STATE(rig)->priv;
 
     memcpy(cmd, &ncmd[cmd_index].nseq, YAESU_CMD_LENGTH);
 
     /* If the sat_mode is not enabled,
      * then leave the OpCode untouched (MAIN VFO) */
 
-    if (p->sat_mode == RIG_SPLIT_ON)
+    if (p->sat_mode == RIG_SPLIT_ON || vfo == RIG_VFO_SUB)
     {
         switch (vfo)
         {
@@ -1201,7 +1199,7 @@ static int ft847_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 
     if (UNIDIRECTIONAL)
     {
-        struct ft847_priv_data *priv = (struct ft847_priv_data *)rig->state.priv;
+        struct ft847_priv_data *priv = (struct ft847_priv_data *)STATE(rig)->priv;
 
         if (vfo == RIG_VFO_MAIN)
         {
@@ -1215,7 +1213,7 @@ static int ft847_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
         }
     }
 
-    return write_block(&rig->state.rigport, p_cmd, YAESU_CMD_LENGTH);
+    return write_block(RIGPORT(rig), p_cmd, YAESU_CMD_LENGTH);
 }
 
 #define MD_LSB  0x00
@@ -1232,12 +1230,12 @@ static int ft847_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 static int get_freq_and_mode(RIG *rig, vfo_t vfo, freq_t *freq, rmode_t *mode,
                              pbwidth_t *width)
 {
-    struct rig_state *rs = &rig->state;
+    hamlib_port_t *rp = RIGPORT(rig);
     unsigned char p_cmd[YAESU_CMD_LENGTH]; /* sequence to send */
     unsigned char cmd_index;  /* index of sequence to send */
     unsigned char data[8];
     int n;
-    struct ft847_priv_data *priv = (struct ft847_priv_data *)rig->state.priv;
+    struct ft847_priv_data *priv = (struct ft847_priv_data *)STATE(rig)->priv;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: vfo =%s \n",
               __func__, rig_strvfo(vfo));
@@ -1272,14 +1270,14 @@ static int get_freq_and_mode(RIG *rig, vfo_t vfo, freq_t *freq, rmode_t *mode,
         return n;
     }
 
-    n = write_block(&rs->rigport, p_cmd, YAESU_CMD_LENGTH);
+    n = write_block(rp, p_cmd, YAESU_CMD_LENGTH);
 
     if (n < 0)
     {
         return n;
     }
 
-    n = read_block(&rs->rigport, data, YAESU_CMD_LENGTH);
+    n = read_block(rp, data, YAESU_CMD_LENGTH);
 
     if (n != YAESU_CMD_LENGTH)
     {
@@ -1360,7 +1358,6 @@ static int ft847_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
 static int ft847_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
 {
     unsigned char cmd_index;  /* index of sequence to send */
-    struct rig_state *rs = &rig->state;
     unsigned char p_cmd[YAESU_CMD_LENGTH]; /* sequence to send */
     int ret;
 
@@ -1373,7 +1370,7 @@ static int ft847_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
 
     if (UNIDIRECTIONAL)
     {
-        struct ft847_priv_data *priv = (struct ft847_priv_data *)rig->state.priv;
+        struct ft847_priv_data *priv = (struct ft847_priv_data *)STATE(rig)->priv;
         priv->mode = mode;
         priv->width = width;
     }
@@ -1469,7 +1466,7 @@ static int ft847_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
         return ret;
     }
 
-    return write_block(&rs->rigport, p_cmd, YAESU_CMD_LENGTH);
+    return write_block(RIGPORT(rig), p_cmd, YAESU_CMD_LENGTH);
 }
 
 static int ft847_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
@@ -1485,7 +1482,7 @@ static int ft847_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
  */
 static int ft847_set_split_vfo(RIG *rig, vfo_t vfo, split_t split, vfo_t tx_vfo)
 {
-    struct ft847_priv_data *priv = (struct ft847_priv_data *)rig->state.priv;
+    struct ft847_priv_data *priv = (struct ft847_priv_data *)STATE(rig)->priv;
     unsigned char cmd_index;  /* index of sequence to send */
     int ret;
 
@@ -1518,7 +1515,7 @@ static int ft847_set_split_vfo(RIG *rig, vfo_t vfo, split_t split, vfo_t tx_vfo)
 static int ft847_get_split_vfo(RIG *rig, vfo_t vfo, split_t *split,
                                vfo_t *tx_vfo)
 {
-    struct ft847_priv_data *priv = (struct ft847_priv_data *)rig->state.priv;
+    struct ft847_priv_data *priv = (struct ft847_priv_data *)STATE(rig)->priv;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
@@ -1568,7 +1565,7 @@ static int ft847_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt)
 
     if (UNIDIRECTIONAL)
     {
-        struct ft847_priv_data *priv = (struct ft847_priv_data *)rig->state.priv;
+        struct ft847_priv_data *priv = (struct ft847_priv_data *)STATE(rig)->priv;
         priv->ptt = ptt;
     }
 
@@ -1596,7 +1593,8 @@ static int ft847_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt)
 
 static int ft847_get_status(RIG *rig, int status_ci)
 {
-    struct ft847_priv_data *p = (struct ft847_priv_data *) rig->state.priv;
+    struct ft847_priv_data *p = (struct ft847_priv_data *) STATE(rig)->priv;
+    hamlib_port_t *rp = RIGPORT(rig);
     unsigned char *data;
     int len;
     int n;
@@ -1623,17 +1621,16 @@ static int ft847_get_status(RIG *rig, int status_ci)
         return -RIG_EINTERNAL;
     }
 
-    rig_flush(&rig->state.rigport);
+    rig_flush(rp);
 
-    n = write_block(&rig->state.rigport, ncmd[status_ci].nseq,
-                    YAESU_CMD_LENGTH);
+    n = write_block(rp, ncmd[status_ci].nseq, YAESU_CMD_LENGTH);
 
     if (n < 0)
     {
         return n;
     }
 
-    n = read_block(&rig->state.rigport, data, len);
+    n = read_block(rp, data, len);
 
     if (n < 0)
     {
@@ -1651,12 +1648,12 @@ static int ft847_get_status(RIG *rig, int status_ci)
 static int ft847_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt)
 {
 
-    struct ft847_priv_data *p = (struct ft847_priv_data *) rig->state.priv;
+    struct ft847_priv_data *p = (struct ft847_priv_data *) STATE(rig)->priv;
     int n;
 
     if (UNIDIRECTIONAL)
     {
-        struct ft847_priv_data *priv = (struct ft847_priv_data *)rig->state.priv;
+        struct ft847_priv_data *priv = (struct ft847_priv_data *)STATE(rig)->priv;
         *ptt = priv->ptt;
         return RIG_OK;
     }
@@ -1676,7 +1673,7 @@ static int ft847_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt)
        socket DTR or RTS PTT on the rear PACKET PTT pin is likely. So we
        override if we know PTT was asserted via rig_set_ptt for any type
        of PTT */
-    if (RIG_PTT_OFF == *ptt && rig->state.transmit) { *ptt = RIG_PTT_ON; }
+    if (RIG_PTT_OFF == *ptt && STATE(rig)->transmit) { *ptt = RIG_PTT_ON; }
 
     return RIG_OK;
 }
@@ -1685,7 +1682,7 @@ static int ft847_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt)
 static int ft847_get_dcd(RIG *rig, vfo_t vfo, dcd_t *dcd)
 {
 
-    struct ft847_priv_data *p = (struct ft847_priv_data *) rig->state.priv;
+    struct ft847_priv_data *p = (struct ft847_priv_data *) STATE(rig)->priv;
     int n;
 
     if (UNIDIRECTIONAL)
@@ -1714,7 +1711,7 @@ static int ft847_get_dcd(RIG *rig, vfo_t vfo, dcd_t *dcd)
  */
 static int ft847_get_rawstr_level(RIG *rig, value_t *val)
 {
-    struct ft847_priv_data *p = (struct ft847_priv_data *) rig->state.priv;
+    struct ft847_priv_data *p = (struct ft847_priv_data *) STATE(rig)->priv;
     int n;
 
     if (UNIDIRECTIONAL)
@@ -1786,7 +1783,7 @@ static int ft847_get_smeter_level(RIG *rig, value_t *val)
  */
 static int ft847_get_alc_level(RIG *rig, value_t *val)
 {
-    struct ft847_priv_data *p = (struct ft847_priv_data *) rig->state.priv;
+    struct ft847_priv_data *p = (struct ft847_priv_data *) STATE(rig)->priv;
     int n;
 
     if (UNIDIRECTIONAL)
@@ -1875,7 +1872,7 @@ static int ft847_set_func(RIG *rig, vfo_t vfo, setting_t func, int status)
         return ret;
     }
 
-    return write_block(&rig->state.rigport, p_cmd, YAESU_CMD_LENGTH);
+    return write_block(RIGPORT(rig), p_cmd, YAESU_CMD_LENGTH);
 }
 
 
@@ -1920,7 +1917,7 @@ static int ft847_set_ctcss_tone(RIG *rig, vfo_t vfo, tone_t tone)
     /* get associated CAT code */
     p_cmd[0] = ft847_ctcss_cat[i];
 
-    return write_block(&rig->state.rigport, p_cmd, YAESU_CMD_LENGTH);
+    return write_block(RIGPORT(rig), p_cmd, YAESU_CMD_LENGTH);
 }
 
 static int ft847_set_ctcss_sql(RIG *rig, vfo_t vfo, tone_t tone)
@@ -1946,7 +1943,7 @@ static int ft847_set_dcs_sql(RIG *rig, vfo_t vfo, tone_t code)
     /* DCS Code # (i.e. 07, 54=DCS Code 754) */
     to_bcd_be(p_cmd, code, 4); /* store bcd format in in p_cmd */
 
-    return write_block(&rig->state.rigport, p_cmd, YAESU_CMD_LENGTH);
+    return write_block(RIGPORT(rig), p_cmd, YAESU_CMD_LENGTH);
 
 }
 
@@ -1989,6 +1986,6 @@ static int ft847_set_rptr_offs(RIG *rig, vfo_t vfo, shortfreq_t rptr_offs)
 
     to_bcd_be(p_cmd, rptr_offs / 10, 8); /* store bcd format in in p_cmd */
 
-    return write_block(&rig->state.rigport, p_cmd, YAESU_CMD_LENGTH);
+    return write_block(RIGPORT(rig), p_cmd, YAESU_CMD_LENGTH);
 }
 
