@@ -928,11 +928,11 @@ int ft857_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
         rig_get_cache(rig, vfo, &freq, &freq_ms, &mode, &mode_ms, &width,
                       &width_ms);
 
-        if (144000000.0f >= freq && 148000000.0f <= freq)
+        if (144000000.0f <= freq && 148000000.0f > freq)
         {
             return ft857_get_pometer_level(rig, val, &rig->caps->rfpower_meter_cal, 2.0);
         }
-        else if (420000000.0f >= freq && 450000000.0f <= freq)
+        else if (420000000.0f <= freq && 450000000.0f > freq)
         {
             return ft857_get_pometer_level(rig, val, &rig->caps->rfpower_meter_cal, 5.0);
         }
@@ -1350,7 +1350,7 @@ int ft857_set_rptr_shift(RIG *rig, vfo_t vfo, rptr_shift_t shift)
 {
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called \n", __func__);
 
-    rig_debug(RIG_DEBUG_VERBOSE, "ft857: set repeter shift = %i\n", shift);
+    rig_debug(RIG_DEBUG_VERBOSE, "ft857: set repeater shift = %i\n", shift);
 
     switch (shift)
     {
@@ -1373,7 +1373,7 @@ int ft857_set_rptr_offs(RIG *rig, vfo_t vfo, shortfreq_t offs)
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called \n", __func__);
 
-    rig_debug(RIG_DEBUG_VERBOSE, "ft857: set repeter offs = %li\n", offs);
+    rig_debug(RIG_DEBUG_VERBOSE, "ft857: set repeater offs = %li\n", offs);
 
     /* fill in the offset freq */
     to_bcd_be(data, offs / 10, 8);
