@@ -31,9 +31,6 @@
 *  G0OAN
 */
 
-
-#include <hamlib/config.h>
-
 #include <stdlib.h>
 #include <string.h>  /* String function definitions */
 
@@ -233,7 +230,7 @@ struct ft990_priv_data
                 .flags = 1,      \
 }
 
-const struct rig_caps ft990_caps =
+struct rig_caps ft990_caps =
 {
     RIG_MODEL(RIG_MODEL_FT990),
     .model_name =         "FT-990",
@@ -266,6 +263,10 @@ const struct rig_caps ft990_caps =
     {
 #include "level_gran_yaesu.h"
     },
+    .parm_gran =  {
+        [PARM_BACKLIGHT] = {.min = {.f = 0.0f}, .max = {.f = 1.0f}, .step = {.f = 1.0f / 255.0f}},
+    },
+
     .ctcss_list =         NULL,
     .dcs_list =           NULL,
     .preamp =             { RIG_DBLST_END, },
@@ -396,15 +397,15 @@ int ft990_init(RIG *rig)
         return -RIG_EINVAL;
     }
 
-    rig->state.priv = (struct ft990_priv_data *) calloc(1,
-                      sizeof(struct ft990_priv_data));
+    STATE(rig)->priv = (struct ft990_priv_data *) calloc(1,
+                       sizeof(struct ft990_priv_data));
 
-    if (!rig->state.priv)
+    if (!STATE(rig)->priv)
     {
         return -RIG_ENOMEM;
     }
 
-    priv = rig->state.priv;
+    priv = STATE(rig)->priv;
 
     // Set default pacing value
     priv->pacing = FT990_PACING_DEFAULT_VALUE;
@@ -429,12 +430,12 @@ int ft990_cleanup(RIG *rig)
         return -RIG_EINVAL;
     }
 
-    if (rig->state.priv)
+    if (STATE(rig)->priv)
     {
-        free(rig->state.priv);
+        free(STATE(rig)->priv);
     }
 
-    rig->state.priv = NULL;
+    STATE(rig)->priv = NULL;
 
     return RIG_OK;
 }
@@ -445,7 +446,6 @@ int ft990_cleanup(RIG *rig)
  */
 int  ft990_open(RIG *rig)
 {
-    struct rig_state *rig_s;
     struct ft990_priv_data *priv;
     int err;
 
@@ -456,13 +456,12 @@ int  ft990_open(RIG *rig)
         return -RIG_EINVAL;
     }
 
-    priv = (struct ft990_priv_data *)rig->state.priv;
-    rig_s = &rig->state;
+    priv = (struct ft990_priv_data *)STATE(rig)->priv;
 
     rig_debug(RIG_DEBUG_TRACE, "%s: write_delay = %i msec\n",
-              __func__, rig_s->rigport.write_delay);
+              __func__, RIGPORT(rig)->write_delay);
     rig_debug(RIG_DEBUG_TRACE, "%s: post_write_delay = %i msec\n",
-              __func__, rig_s->rigport.post_write_delay);
+              __func__, RIGPORT(rig)->post_write_delay);
     rig_debug(RIG_DEBUG_TRACE,
               "%s: read pacing = %i\n", __func__, priv->pacing);
 
@@ -539,7 +538,7 @@ int ft990_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
         return -RIG_EINVAL;
     }
 
-    priv = (struct ft990_priv_data *)rig->state.priv;
+    priv = (struct ft990_priv_data *)STATE(rig)->priv;
     vfo_save = priv->current_vfo;
 
     // Set to selected VFO
@@ -616,7 +615,7 @@ int ft990_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
         return -RIG_EINVAL;
     }
 
-    priv = (struct ft990_priv_data *)rig->state.priv;
+    priv = (struct ft990_priv_data *)STATE(rig)->priv;
 
     if (vfo == RIG_VFO_CURR)
     {
@@ -709,7 +708,7 @@ int ft990_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt)
     rig_debug(RIG_DEBUG_TRACE, "%s: passed vfo = 0x%02x\n", __func__, vfo);
     rig_debug(RIG_DEBUG_TRACE, "%s: passed ptt = 0x%02x\n", __func__, ptt);
 
-    priv = (struct ft990_priv_data *) rig->state.priv;
+    priv = (struct ft990_priv_data *) STATE(rig)->priv;
 
     // Set to selected VFO
     if (vfo == RIG_VFO_CURR)
@@ -785,7 +784,7 @@ int ft990_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt)
 
     rig_debug(RIG_DEBUG_TRACE, "%s: passed vfo = 0x%02x\n", __func__, vfo);
 
-    priv = (struct ft990_priv_data *) rig->state.priv;
+    priv = (struct ft990_priv_data *) STATE(rig)->priv;
 
     err = ft990_get_update_data(rig, FT990_NATIVE_READ_FLAGS, 0);
 
@@ -840,7 +839,7 @@ int ft990_set_rptr_shift(RIG *rig, vfo_t vfo, rptr_shift_t rptr_shift)
     rig_debug(RIG_DEBUG_TRACE, "%s: passed rptr_shift = 0x%02x\n", __func__,
               rptr_shift);
 
-    priv = (struct ft990_priv_data *) rig->state.priv;
+    priv = (struct ft990_priv_data *) STATE(rig)->priv;
 
     // Set to selected VFO
     if (vfo == RIG_VFO_CURR)
@@ -967,7 +966,7 @@ int ft990_get_rptr_shift(RIG *rig, vfo_t vfo, rptr_shift_t *rptr_shift)
 
     rig_debug(RIG_DEBUG_TRACE, "%s: passed vfo = 0x%02x\n", __func__, vfo);
 
-    priv = (struct ft990_priv_data *) rig->state.priv;
+    priv = (struct ft990_priv_data *) STATE(rig)->priv;
 
     if (vfo == RIG_VFO_CURR)
     {
@@ -1118,7 +1117,7 @@ int ft990_set_split_vfo(RIG *rig, vfo_t vfo, split_t split, vfo_t tx_vfo)
     rig_debug(RIG_DEBUG_TRACE, "%s: passed split = 0x%02x\n", __func__, split);
     rig_debug(RIG_DEBUG_TRACE, "%s: passed tx_vfo = 0x%02x\n", __func__, tx_vfo);
 
-    priv = (struct ft990_priv_data *) rig->state.priv;
+    priv = (struct ft990_priv_data *) STATE(rig)->priv;
 
     if (vfo == RIG_VFO_CURR)
     {
@@ -1214,7 +1213,7 @@ int ft990_get_split_vfo(RIG *rig, vfo_t vfo, split_t *split, vfo_t *tx_vfo)
 
     rig_debug(RIG_DEBUG_TRACE, "%s: passed vfo = 0x%02x\n", __func__, vfo);
 
-    priv = (struct ft990_priv_data *) rig->state.priv;
+    priv = (struct ft990_priv_data *) STATE(rig)->priv;
 
     // Read status flags
     err = ft990_get_update_data(rig, FT990_NATIVE_READ_FLAGS, 0);
@@ -1307,7 +1306,7 @@ int ft990_set_rit(RIG *rig, vfo_t vfo, shortfreq_t rit)
         return -RIG_EINVAL;
     }
 
-    priv = (struct ft990_priv_data *) rig->state.priv;
+    priv = (struct ft990_priv_data *) STATE(rig)->priv;
 
     // Set to selected VFO
     if (vfo == RIG_VFO_CURR)
@@ -1414,7 +1413,7 @@ int ft990_get_rit(RIG *rig, vfo_t vfo, shortfreq_t *rit)
 
     rig_debug(RIG_DEBUG_TRACE, "%s: passed vfo = 0x%02x\n", __func__, vfo);
 
-    priv = (struct ft990_priv_data *) rig->state.priv;
+    priv = (struct ft990_priv_data *) STATE(rig)->priv;
 
     if (vfo == RIG_VFO_CURR)
     {
@@ -1513,7 +1512,7 @@ int ft990_set_xit(RIG *rig, vfo_t vfo, shortfreq_t xit)
         return -RIG_EINVAL;
     }
 
-    priv = (struct ft990_priv_data *) rig->state.priv;
+    priv = (struct ft990_priv_data *) STATE(rig)->priv;
 
     // Set to selected VFO
     if (vfo == RIG_VFO_CURR)
@@ -1619,7 +1618,7 @@ int ft990_get_xit(RIG *rig, vfo_t vfo, shortfreq_t *xit)
 
     rig_debug(RIG_DEBUG_TRACE, "%s: passed vfo = 0x%02x\n", __func__, vfo);
 
-    priv = (struct ft990_priv_data *) rig->state.priv;
+    priv = (struct ft990_priv_data *) STATE(rig)->priv;
 
     if (vfo == RIG_VFO_CURR)
     {
@@ -1779,7 +1778,7 @@ int ft990_get_func(RIG *rig, vfo_t vfo, setting_t func, int *status)
     rig_debug(RIG_DEBUG_TRACE, "%s: passed func = %s\n", __func__,
               rig_strfunc(func));
 
-    priv = (struct ft990_priv_data *)rig->state.priv;
+    priv = (struct ft990_priv_data *)STATE(rig)->priv;
 
     err = ft990_get_update_data(rig, FT990_NATIVE_READ_FLAGS, 0);
 
@@ -1904,7 +1903,7 @@ int ft990_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
               rig_strrmode(mode));
     rig_debug(RIG_DEBUG_TRACE, "%s: passed width = %d Hz\n", __func__, (int)width);
 
-    priv = (struct ft990_priv_data *)rig->state.priv;
+    priv = (struct ft990_priv_data *)STATE(rig)->priv;
 
     // Set to selected VFO
     if (vfo == RIG_VFO_CURR)
@@ -2056,7 +2055,7 @@ int ft990_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
 
     rig_debug(RIG_DEBUG_TRACE, "%s: passed vfo = 0x%02x\n", __func__, vfo);
 
-    priv = (struct ft990_priv_data *)rig->state.priv;
+    priv = (struct ft990_priv_data *)STATE(rig)->priv;
 
     if (vfo == RIG_VFO_CURR)
     {
@@ -2232,7 +2231,7 @@ int ft990_set_vfo(RIG *rig, vfo_t vfo)
 
     rig_debug(RIG_DEBUG_TRACE, "%s: passed vfo = 0x%02x\n", __func__, vfo);
 
-    priv = (struct ft990_priv_data *)rig->state.priv;
+    priv = (struct ft990_priv_data *)STATE(rig)->priv;
 
     if (vfo == RIG_VFO_CURR)
     {
@@ -2315,7 +2314,7 @@ int ft990_get_vfo(RIG *rig, vfo_t *vfo)
         return -RIG_EINVAL;
     }
 
-    priv = (struct ft990_priv_data *)rig->state.priv;
+    priv = (struct ft990_priv_data *)STATE(rig)->priv;
 
     /* Get flags for VFO status */
     err = ft990_get_update_data(rig, FT990_NATIVE_READ_FLAGS, 0);
@@ -2401,7 +2400,7 @@ int ft990_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *value)
     rig_debug(RIG_DEBUG_TRACE, "%s: passed level %s\n", __func__,
               rig_strlevel(level));
 
-    priv = (struct ft990_priv_data *) rig->state.priv;
+    priv = (struct ft990_priv_data *) STATE(rig)->priv;
 
     if (vfo == RIG_VFO_CURR)
     {
@@ -2429,7 +2428,7 @@ int ft990_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *value)
         return err;
     }
 
-    err = read_block(&rig->state.rigport, mdata, FT990_READ_METER_LENGTH);
+    err = read_block(RIGPORT(rig), mdata, FT990_READ_METER_LENGTH);
 
     if (err < 0)
     {
@@ -2500,7 +2499,7 @@ int ft990_vfo_op(RIG *rig, vfo_t vfo, vfo_op_t op)
     rig_debug(RIG_DEBUG_TRACE, "%s: passed vfo %s\n", __func__, rig_strvfo(vfo));
     rig_debug(RIG_DEBUG_TRACE, "%s: passed op %s\n", __func__, rig_strvfop(op));
 
-    priv = (struct ft990_priv_data *) rig->state.priv;
+    priv = (struct ft990_priv_data *) STATE(rig)->priv;
 
     if (vfo == RIG_VFO_CURR)
     {
@@ -2621,7 +2620,7 @@ int ft990_set_mem(RIG *rig, vfo_t vfo, int ch)
 
     rig_debug(RIG_DEBUG_TRACE, "%s: passed ch = %i\n", __func__, ch);
 
-    priv = (struct ft990_priv_data *) rig->state.priv;
+    priv = (struct ft990_priv_data *) STATE(rig)->priv;
 
     // Check for valid channel number
     if (ch < 1 || ch > 90)
@@ -2673,7 +2672,7 @@ int ft990_get_mem(RIG *rig, vfo_t vfo, int *ch)
 
     rig_debug(RIG_DEBUG_TRACE, "%s: passed vfo = 0x%02x\n", __func__, vfo);
 
-    priv = (struct ft990_priv_data *) rig->state.priv;
+    priv = (struct ft990_priv_data *) STATE(rig)->priv;
 
     if (vfo == RIG_VFO_CURR)
     {
@@ -2767,7 +2766,7 @@ int ft990_get_channel(RIG *rig, vfo_t vfo, channel_t *chan, int read_only)
     rig_debug(RIG_DEBUG_TRACE, "%s: passed chan->channel_num = %i\n",
               __func__, chan->channel_num);
 
-    priv = (struct ft990_priv_data *) rig->state.priv;
+    priv = (struct ft990_priv_data *) STATE(rig)->priv;
 
     if (chan->channel_num < 0 || chan->channel_num > 90)
     {
@@ -3224,7 +3223,7 @@ int ft990_get_channel(RIG *rig, vfo_t vfo, channel_t *chan, int read_only)
  *              rl      expected length of returned data in octets
  *
  * Returns:     RIG_OK if all called functions are successful,
- *              otherwise returns error from called functiion
+ *              otherwise returns error from called function
  */
 int ft990_get_update_data(RIG *rig, unsigned char ci, unsigned short ch)
 {
@@ -3244,7 +3243,7 @@ int ft990_get_update_data(RIG *rig, unsigned char ci, unsigned short ch)
         return -RIG_EINVAL;
     }
 
-    priv = (struct ft990_priv_data *)rig->state.priv;
+    priv = (struct ft990_priv_data *)STATE(rig)->priv;
 
     if (ci == FT990_NATIVE_UPDATE_MEM_CHNL_DATA)
         // P4 = 0x01 to 0x5a for channel 1 - 90
@@ -3296,7 +3295,7 @@ int ft990_get_update_data(RIG *rig, unsigned char ci, unsigned short ch)
         return -RIG_EINVAL;
     }
 
-    n = read_block(&rig->state.rigport, p, rl);
+    n = read_block(RIGPORT(rig), p, rl);
 
     if (n < 0)
     {
@@ -3322,7 +3321,7 @@ int ft990_get_update_data(RIG *rig, unsigned char ci, unsigned short ch)
  *              ci      Command index of the ncmd table
  *
  * Returns:     RIG_OK if all called functions are successful,
- *              otherwise returns error from called functiion
+ *              otherwise returns error from called function
  */
 int ft990_send_static_cmd(RIG *rig, unsigned char ci)
 {
@@ -3342,7 +3341,7 @@ int ft990_send_static_cmd(RIG *rig, unsigned char ci)
         return -RIG_EINVAL;
     }
 
-    err = write_block(&rig->state.rigport, ncmd[ci].nseq, YAESU_CMD_LENGTH);
+    err = write_block(RIGPORT(rig), ncmd[ci].nseq, YAESU_CMD_LENGTH);
 
     if (err != RIG_OK)
     {
@@ -3363,7 +3362,7 @@ int ft990_send_static_cmd(RIG *rig, unsigned char ci)
  *              p1-p4   Command parameters
  *
  * Returns:     RIG_OK if all called functions are successful,
- *              otherwise returns error from called functiion
+ *              otherwise returns error from called function
  */
 int ft990_send_dynamic_cmd(RIG *rig, unsigned char ci,
                            unsigned char p1, unsigned char p2,
@@ -3384,7 +3383,7 @@ int ft990_send_dynamic_cmd(RIG *rig, unsigned char ci,
               "%s: passed p1 = 0x%02x, p2 = 0x%02x, p3 = 0x%02x, p4 = 0x%02x,\n",
               __func__, p1, p2, p3, p4);
 
-    priv = (struct ft990_priv_data *)rig->state.priv;
+    priv = (struct ft990_priv_data *)STATE(rig)->priv;
 
     if (ncmd[ci].ncomp)
     {
@@ -3400,7 +3399,7 @@ int ft990_send_dynamic_cmd(RIG *rig, unsigned char ci,
     priv->p_cmd[1] = p3;
     priv->p_cmd[0] = p4;
 
-    err = write_block(&rig->state.rigport, (unsigned char *) &priv->p_cmd,
+    err = write_block(RIGPORT(rig), (unsigned char *) &priv->p_cmd,
                       YAESU_CMD_LENGTH);
 
     if (err != RIG_OK)
@@ -3422,7 +3421,7 @@ int ft990_send_dynamic_cmd(RIG *rig, unsigned char ci,
  *              freq    freq_t frequency value
  *
  * Returns:     RIG_OK if all called functions are successful,
- *              otherwise returns error from called functiion
+ *              otherwise returns error from called function
  */
 int ft990_send_dial_freq(RIG *rig, unsigned char ci, freq_t freq)
 {
@@ -3441,7 +3440,7 @@ int ft990_send_dial_freq(RIG *rig, unsigned char ci, freq_t freq)
     rig_debug(RIG_DEBUG_TRACE, "%s: passed ci = 0x%02x\n", __func__, ci);
     rig_debug(RIG_DEBUG_TRACE, "%s: passed freq = %"PRIfreq" Hz\n", __func__, freq);
 
-    priv = (struct ft990_priv_data *)rig->state.priv;
+    priv = (struct ft990_priv_data *)STATE(rig)->priv;
 
     if (ncmd[ci].ncomp)
     {
@@ -3459,7 +3458,7 @@ int ft990_send_dial_freq(RIG *rig, unsigned char ci, freq_t freq)
     rig_debug(RIG_DEBUG_TRACE, fmt, __func__, (int64_t)from_bcd(priv->p_cmd,
               FT990_BCD_DIAL) * 10);
 
-    err = write_block(&rig->state.rigport, (unsigned char *) &priv->p_cmd,
+    err = write_block(RIGPORT(rig), (unsigned char *) &priv->p_cmd,
                       YAESU_CMD_LENGTH);
 
     if (err != RIG_OK)
@@ -3479,7 +3478,7 @@ int ft990_send_dial_freq(RIG *rig, unsigned char ci, freq_t freq)
  *              rit    shortfreq_t frequency value
  *
  * Returns:     RIG_OK if all called functions are successful,
- *              otherwise returns error from called functiion
+ *              otherwise returns error from called function
  */
 int ft990_send_rit_freq(RIG *rig, unsigned char ci, shortfreq_t rit)
 {
@@ -3496,7 +3495,7 @@ int ft990_send_rit_freq(RIG *rig, unsigned char ci, shortfreq_t rit)
     rig_debug(RIG_DEBUG_TRACE, "%s: passed ci = 0x%02x\n", __func__, ci);
     rig_debug(RIG_DEBUG_TRACE, "%s: passed rit = %li Hz\n", __func__, rit);
 
-    priv = (struct ft990_priv_data *) rig->state.priv;
+    priv = (struct ft990_priv_data *) STATE(rig)->priv;
 
     if (ncmd[ci].ncomp)
     {
@@ -3524,7 +3523,7 @@ int ft990_send_rit_freq(RIG *rig, unsigned char ci, shortfreq_t rit)
     // Store bcd format into privat command storage area
     to_bcd(priv->p_cmd, labs(rit) / 10, FT990_BCD_RIT);
 
-    err = write_block(&rig->state.rigport, (unsigned char *) &priv->p_cmd,
+    err = write_block(RIGPORT(rig), (unsigned char *) &priv->p_cmd,
                       YAESU_CMD_LENGTH);
 
     if (err != RIG_OK)
