@@ -29,9 +29,6 @@
  *
  */
 
-
-#include <hamlib/config.h>
-
 #include <stdlib.h>
 #include <string.h>
 #include "hamlib/rig.h"
@@ -123,6 +120,42 @@ const struct confparams ft991_ext_levels[] =
         RIG_CONF_NUMERIC,
         { .n = { .min = 1, .max = 11, .step = 1 } },
     },
+    {
+        TOK_MAXPOWER_HF,
+        "MAXPOWER_HF",
+        "Maxpower HF",
+        "Maxpower HF",
+        NULL,
+        RIG_CONF_INT,
+        { .n = { .min = 5, .max = 100, .step = 1 } },
+    },
+    {
+        TOK_MAXPOWER_6M,
+        "MAXPOWER_6M",
+        "Maxpower 6m",
+        "Maxpower 6m",
+        NULL,
+        RIG_CONF_INT,
+        { .n = { .min = 5, .max = 100, .step = 1 } },
+    },
+    {
+        TOK_MAXPOWER_VHF,
+        "MAXPOWER_VHF",
+        "Maxpower VHF",
+        "Maxpower VHF",
+        NULL,
+        RIG_CONF_INT,
+        { .n = { .min = 5, .max = 50, .step = 1 } },
+    },
+    {
+        TOK_MAXPOWER_UHF,
+        "MAXPOWER_UHF",
+        "Maxpower UHF",
+        "Maxpower UHF",
+        NULL,
+        RIG_CONF_NUMERIC,
+        { .n = { .min = 5, .max = 50, .step = 1 } },
+    },
     { RIG_CONF_END, NULL, }
 };
 
@@ -130,18 +163,19 @@ int ft991_ext_tokens[] =
 {
     TOK_KEYER, TOK_APF_FREQ, TOK_APF_WIDTH,
     TOK_CONTOUR, TOK_CONTOUR_FREQ, TOK_CONTOUR_LEVEL, TOK_CONTOUR_WIDTH,
+    TOK_MAXPOWER_HF, TOK_MAXPOWER_6M, TOK_MAXPOWER_UHF, TOK_MAXPOWER_VHF,
     TOK_BACKEND_NONE
 };
 
 /*
  * FT-991 rig capabilities
  */
-const struct rig_caps ft991_caps =
+struct rig_caps ft991_caps =
 {
     RIG_MODEL(RIG_MODEL_FT991),
     .model_name =         "FT-991",
     .mfg_name =           "Yaesu",
-    .version =            NEWCAT_VER ".15",
+    .version =            NEWCAT_VER ".18",
     .copyright =          "LGPL",
     .status =             RIG_STATUS_STABLE,
     .rig_type =           RIG_TYPE_TRANSCEIVER,
@@ -162,12 +196,27 @@ const struct rig_caps ft991_caps =
     .has_set_func =       FT991_FUNCS,
     .has_get_level =      FT991_LEVELS,
     .has_set_level =      RIG_LEVEL_SET(FT991_LEVELS),
-    .has_get_parm =       RIG_PARM_NONE,
-    .has_set_parm =       RIG_PARM_NONE,
+    .has_get_parm =       RIG_PARM_BANDSELECT,
+    .has_set_parm =       RIG_PARM_BANDSELECT,
     .level_gran = {
+#define NO_LVL_MICGAIN
+#define NO_LVL_SQL
+#define NO_LVL_MONITOR_GAIN
+#define NO_LVL_RFPOWER
 #include "level_gran_yaesu.h"
-        [LVL_NR] = { .min = { .f = 0 }, .max = { .f = 1 }, .step = { .f = 1.0f / 15.0f } },
+#undef NO_LVL_MICGAIN
+#undef NO_LVL_SQL
+#undef NO_LVL_MONITOR_GAIN
+#undef NO_LVL_RFPOWER
+        [LVL_MICGAIN] = { .min = { .f = 0 }, .max = { .f = 1.0 }, .step = { .f = 1.0f / 100.0f } },
+        [LVL_SQL] = { .min = { .f = 0 }, .max = { .f = 1.0 }, .step = { .f = 1.0f / 100.0f } },
+        [LVL_MONITOR_GAIN] = { .min = { .f = 0 }, .max = { .f = 1.0 }, .step = { .f = 1.0f / 100.0f } },
+        [LVL_RFPOWER] = { .min = { .f = .05 }, .max = { .f = 1.0 }, .step = { .f = 1.0f / 100.0f } },
     },
+    .parm_gran =  {
+        [PARM_BANDSELECT] = {.step = {.s = "BAND160M,BAND80M,BANDUNUSED,BAND40M,BAND30M,BAND20M,BAND17M,BAND15M,BAND12M,BAND10M,BAND6M,BANDGEN,BANDMW,BANDUNUSED,BANDAIR,BAND70CM,BAND33CM"}}
+    },
+
     .ctcss_list =         common_ctcss_list,
     .dcs_list =           common_dcs_list,
     .preamp =             { 10, 20, RIG_DBLST_END, },
@@ -190,7 +239,10 @@ const struct rig_caps ft991_caps =
     .comp_meter_cal =     FT991_COMP_CAL,
     .chan_list =          {
         {   1,  99, RIG_MTYPE_MEM,  NEWCAT_MEM_CAP },
-        { 100, 117, RIG_MTYPE_EDGE, NEWCAT_MEM_CAP },    /* two by two */
+        {   100,  117, RIG_MTYPE_MEM,  NEWCAT_MEM_CAP }, // P1L-P9U PMS channels
+        {   118,  127, RIG_MTYPE_MEM,  NEWCAT_MEM_CAP }, // 5xx 5MHz band
+        {   1,      5, RIG_MTYPE_VOICE },
+        {   1,      5, RIG_MTYPE_MORSE },
         RIG_CHAN_END,
     },
 
@@ -320,6 +372,8 @@ const struct rig_caps ft991_caps =
     .get_xit =            newcat_get_xit,
     .get_func =           newcat_get_func,
     .set_func =           newcat_set_func,
+    .get_parm =           newcat_get_parm,
+    .set_parm =           newcat_set_parm,
     .get_level =          newcat_get_level,
     .set_level =          newcat_set_level,
     .get_mem =            newcat_get_mem,
@@ -356,7 +410,7 @@ const struct rig_caps ft991_caps =
     .send_voice_mem =     newcat_send_voice_mem,
     .set_clock =          newcat_set_clock,
     .get_clock =          newcat_get_clock,
-    .scan =               newcat_scan,
+    .morse_qsize =        50,
     .hamlib_check_rig_caps = HAMLIB_CHECK_RIG_CAPS
 };
 
@@ -412,7 +466,7 @@ ft991_set_split_freq(RIG *rig, vfo_t vfo, freq_t tx_freq)
         return (rval);
     }
 
-    if (rig->state.cache.freqMainB == tx_freq)
+    if (CACHE(rig)->freqMainB == tx_freq)
     {
         rig_debug(RIG_DEBUG_TRACE, "%s: freq %.0f already set on VFOB\n", __func__,
                   tx_freq);
@@ -501,7 +555,7 @@ static int ft991_get_split_mode(RIG *rig, vfo_t vfo, rmode_t *tx_mode,
         return -RIG_EINVAL;
     }
 
-    priv = (struct newcat_priv_data *)rig->state.priv;
+    priv = (struct newcat_priv_data *)STATE(rig)->priv;
     rdata = (ft991info *)priv->ret_data;
 
     SNPRINTF(priv->cmd_str, sizeof(priv->cmd_str), "OI;");
@@ -589,7 +643,7 @@ static int ft991_set_split_mode(RIG *rig, vfo_t vfo, rmode_t tx_mode,
         return -RIG_EINVAL;
     }
 
-    if (rig->state.cache.modeMainB == tx_mode)
+    if (CACHE(rig)->modeMainB == tx_mode)
     {
         rig_debug(RIG_DEBUG_TRACE, "%s: mode %s already set on VFOB\n", __func__,
                   rig_strrmode(tx_mode));
@@ -614,7 +668,7 @@ static int ft991_set_split_mode(RIG *rig, vfo_t vfo, rmode_t tx_mode,
     }
 
 
-    state = &rig->state;
+    state = STATE(rig);
 
     rig_debug(RIG_DEBUG_TRACE, "%s: passed vfo = %s\n", __func__,
               rig_strvfo(vfo));
@@ -647,8 +701,9 @@ static int ft991_set_split_mode(RIG *rig, vfo_t vfo, rmode_t tx_mode,
         return err;
     }
 
-    strncat(restore_commands, priv->ret_data,
-            NEWCAT_DATA_LEN - strlen(restore_commands));
+    size_t len = strlen(restore_commands);
+    SNPRINTF(restore_commands + len, sizeof(restore_commands) - len, "%.*s",
+         (int)(sizeof(restore_commands) - len - 1), priv->ret_data);
 
     /* Change mode on VFOA */
     if (RIG_OK != (err = newcat_set_mode(rig, RIG_VFO_A, tx_mode,
@@ -673,14 +728,14 @@ static int ft991_init(RIG *rig)
 
     if (ret != RIG_OK) { return ret; }
 
-    rig->state.current_vfo = RIG_VFO_A;
+    STATE(rig)->current_vfo = RIG_VFO_A;
     return RIG_OK;
 }
 
 static int ft991_find_current_vfo(RIG *rig, vfo_t *vfo, tone_t *enc_dec_mode,
                                   rmode_t *mode)
 {
-    struct newcat_priv_data *priv = (struct newcat_priv_data *)rig->state.priv;
+    struct newcat_priv_data *priv = (struct newcat_priv_data *)STATE(rig)->priv;
     ft991info *info = (ft991info *)priv->ret_data;
     int err;
 
@@ -730,7 +785,7 @@ static int ft991_find_current_vfo(RIG *rig, vfo_t *vfo, tone_t *enc_dec_mode,
 
 static int ft991_get_enabled_ctcss_dcs_mode(RIG *rig)
 {
-    struct newcat_priv_data *priv = (struct newcat_priv_data *)rig->state.priv;
+    struct newcat_priv_data *priv = (struct newcat_priv_data *)STATE(rig)->priv;
     int err;
 
     rig_debug(RIG_DEBUG_TRACE, "%s called\n", __func__);
@@ -748,7 +803,7 @@ static int ft991_get_enabled_ctcss_dcs_mode(RIG *rig)
 
 static int ft991_set_ctcss_tone(RIG *rig, vfo_t vfo, tone_t tone)
 {
-    struct newcat_priv_data *priv = (struct newcat_priv_data *)rig->state.priv;
+    struct newcat_priv_data *priv = (struct newcat_priv_data *)STATE(rig)->priv;
     int i;
     ncboolean tone_match;
 
@@ -785,7 +840,7 @@ static int ft991_set_ctcss_tone(RIG *rig, vfo_t vfo, tone_t tone)
 
 static int ft991_get_ctcss_tone(RIG *rig, vfo_t vfo, tone_t *tone)
 {
-    struct newcat_priv_data *priv = (struct newcat_priv_data *)rig->state.priv;
+    struct newcat_priv_data *priv = (struct newcat_priv_data *)STATE(rig)->priv;
     int ret;
     int t;
     int ret_data_len;
@@ -851,7 +906,7 @@ static int ft991_get_ctcss_tone(RIG *rig, vfo_t vfo, tone_t *tone)
 
 static int ft991_set_ctcss_sql(RIG *rig, vfo_t vfo, tone_t tone)
 {
-    struct newcat_priv_data *priv = (struct newcat_priv_data *)rig->state.priv;
+    struct newcat_priv_data *priv = (struct newcat_priv_data *)STATE(rig)->priv;
     int err;
     rmode_t rmode;
 
@@ -900,7 +955,7 @@ static int ft991_set_ctcss_sql(RIG *rig, vfo_t vfo, tone_t tone)
 
 static int ft991_get_ctcss_sql(RIG *rig, vfo_t vfo, tone_t *tone)
 {
-    struct newcat_priv_data *priv = (struct newcat_priv_data *)rig->state.priv;
+    struct newcat_priv_data *priv = (struct newcat_priv_data *)STATE(rig)->priv;
     int ret;
     int t;
     int ret_data_len;
@@ -953,7 +1008,7 @@ static int ft991_get_ctcss_sql(RIG *rig, vfo_t vfo, tone_t *tone)
 
 static int ft991_get_dcs_code(RIG *rig, vfo_t vfo, tone_t *code)
 {
-    struct newcat_priv_data *priv = (struct newcat_priv_data *)rig->state.priv;
+    struct newcat_priv_data *priv = (struct newcat_priv_data *)STATE(rig)->priv;
     int err;
     int t;
     tone_t enc_dec_mode;
@@ -1018,7 +1073,7 @@ static int ft991_get_dcs_code(RIG *rig, vfo_t vfo, tone_t *code)
 
 static int ft991_set_dcs_code(RIG *rig, vfo_t vfo, tone_t code)
 {
-    struct newcat_priv_data *priv = (struct newcat_priv_data *)rig->state.priv;
+    struct newcat_priv_data *priv = (struct newcat_priv_data *)STATE(rig)->priv;
     int i;
     ncboolean code_match;
 
@@ -1055,7 +1110,7 @@ static int ft991_set_dcs_code(RIG *rig, vfo_t vfo, tone_t code)
 
 static int ft991_set_dcs_sql(RIG *rig, vfo_t vfo, tone_t code)
 {
-    struct newcat_priv_data *priv = (struct newcat_priv_data *)rig->state.priv;
+    struct newcat_priv_data *priv = (struct newcat_priv_data *)STATE(rig)->priv;
     int i;
     ncboolean code_match;
 
@@ -1092,7 +1147,7 @@ static int ft991_set_dcs_sql(RIG *rig, vfo_t vfo, tone_t code)
 
 static int ft991_get_dcs_sql(RIG *rig, vfo_t vfo, tone_t *code)
 {
-    struct newcat_priv_data *priv = (struct newcat_priv_data *)rig->state.priv;
+    struct newcat_priv_data *priv = (struct newcat_priv_data *)STATE(rig)->priv;
     int codeindex;
     int ret;
     int ret_data_len;
@@ -1146,12 +1201,12 @@ static int ft991_get_dcs_sql(RIG *rig, vfo_t vfo, tone_t *code)
 // VFO functions so rigctld can be used without --vfo argument
 static int ft991_set_vfo(RIG *rig, vfo_t vfo)
 {
-    rig->state.current_vfo = vfo;
+    STATE(rig)->current_vfo = vfo;
     RETURNFUNC2(RIG_OK);
 }
 
 static int ft991_get_vfo(RIG *rig, vfo_t *vfo)
 {
-    *vfo = rig->state.current_vfo;
+    *vfo = STATE(rig)->current_vfo;
     RETURNFUNC2(RIG_OK);
 }
