@@ -19,7 +19,6 @@
  *
  */
 
-#include <hamlib/config.h>
 
 #include <stdlib.h>
 
@@ -28,7 +27,6 @@
 #endif
 
 #include "hamlib/rotator.h"
-#include "misc.h"
 #include "register.h"
 
 char axcmd[512];
