@@ -29,8 +29,7 @@
  *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
-
-#include <config.h>
+/* SPDX-License-Identifier: LGPL-2.1-or-later */
 
 #include <stdio.h>
 #include <stdlib.h>          /* Standard library definitions */
@@ -39,9 +38,9 @@
 
 #include "hamlib/rotator.h"
 #include "serial.h"
-#include "misc.h"
 #include "register.h"
 #include "iofunc.h"
+#include "misc.h"
 
 #include "rotorez.h"
 
@@ -58,6 +57,7 @@ static int rotorez_rot_set_position(ROT *rot, azimuth_t azimuth,
                                     elevation_t elevation);
 static int rotorez_rot_get_position(ROT *rot, azimuth_t *azimuth,
                                     elevation_t *elevation);
+static int rotorez_park(ROT *rot);
 static int erc_rot_get_position(ROT *rot, azimuth_t *azimuth,
                                 elevation_t *elevation);
 static int rt21_rot_get_position(ROT *rot, azimuth_t *azimuth,
@@ -69,7 +69,8 @@ static int rotorez_rot_reset(ROT *rot, rot_reset_t reset);
 static int rotorez_rot_stop(ROT *rot);
 static int dcu1_rot_stop(ROT *rot);
 
-static int rotorez_rot_set_conf(ROT *rot, token_t token, const char *val);
+static int rotorez_rot_set_conf(ROT *rot, hamlib_token_t token,
+                                const char *val);
 
 static const char *rotorez_rot_get_info(ROT *rot);
 
@@ -132,7 +133,7 @@ const struct rot_caps rotorez_rot_caps =
     ROT_MODEL(ROT_MODEL_ROTOREZ),
     .model_name =       "Rotor-EZ",
     .mfg_name =         "Idiom Press",
-    .version =          "20220109.0",
+    .version =          "20230328.0",
     .copyright =        "LGPL",
     .status =           RIG_STATUS_STABLE,
     .rot_type =         ROT_TYPE_OTHER,
@@ -160,6 +161,7 @@ const struct rot_caps rotorez_rot_caps =
     .rot_cleanup =      rotorez_rot_cleanup,
     .set_position =     rotorez_rot_set_position,
     .get_position =     rotorez_rot_get_position,
+    .park =             rotorez_park,
     .stop =             rotorez_rot_stop,
     .set_conf =         rotorez_rot_set_conf,
     .get_info =         rotorez_rot_get_info,
@@ -177,9 +179,9 @@ const struct rot_caps rotorcard_rot_caps =
     ROT_MODEL(ROT_MODEL_ROTORCARD),
     .model_name =       "RotorCard",
     .mfg_name =         "Idiom Press",
-    .version =          "20100214.0",
+    .version =          "20230328.0",
     .copyright =        "LGPL",
-    .status =           RIG_STATUS_BETA,
+    .status =           RIG_STATUS_STABLE,
     .rot_type =         ROT_TYPE_OTHER,
     .port_type =        RIG_PORT_SERIAL,
     .serial_rate_min =  4800,
@@ -205,6 +207,7 @@ const struct rot_caps rotorcard_rot_caps =
     .rot_cleanup =      rotorez_rot_cleanup,
     .set_position =     rotorez_rot_set_position,
     .get_position =     rotorez_rot_get_position,
+    .park =             rotorez_park,
     .stop =             rotorez_rot_stop,
     .set_conf =         rotorez_rot_set_conf,
     .get_info =         rotorez_rot_get_info,
@@ -221,7 +224,7 @@ const struct rot_caps dcu_rot_caps =
     ROT_MODEL(ROT_MODEL_DCU),
     .model_name =       "DCU-1/DCU-1X",
     .mfg_name =         "Hy-Gain",
-    .version =          "20100823.0",
+    .version =          "20230328.0",
     .copyright =        "LGPL",
     .status =           RIG_STATUS_STABLE,
     .rot_type =         ROT_TYPE_OTHER,
@@ -265,7 +268,7 @@ const struct rot_caps erc_rot_caps =
     ROT_MODEL(ROT_MODEL_ERC),
     .model_name =       "ERC",
     .mfg_name =         "DF9GR",
-    .version =          "20100823.2",      /* second revision on 23 Aug 2010 */
+    .version =          "20230328.2",      /* second revision on 23 Aug 2010 */
     .copyright =        "LGPL",
     .status =           RIG_STATUS_STABLE,
     .rot_type =         ROT_TYPE_OTHER,
@@ -293,6 +296,7 @@ const struct rot_caps erc_rot_caps =
     .rot_cleanup =      rotorez_rot_cleanup,
     .set_position =     rotorez_rot_set_position,
     .get_position =     erc_rot_get_position,
+    .park =             rotorez_park,
     .stop =             dcu1_rot_stop,
     .reset =            rotorez_rot_reset,
 //  .stop =             rotorez_rot_stop,
@@ -312,7 +316,7 @@ const struct rot_caps yrc1_rot_caps =
     ROT_MODEL(ROT_MODEL_YRC1),
     .model_name =       "DCU2/DCU3/YRC-1",
     .mfg_name =         "Hy-Gain",
-    .version =          "20100823.2",
+    .version =          "20230328.2",
     .copyright =        "LGPL",
     .status =           RIG_STATUS_STABLE,
     .rot_type =         ROT_TYPE_OTHER,
@@ -340,6 +344,7 @@ const struct rot_caps yrc1_rot_caps =
     .rot_cleanup =      rotorez_rot_cleanup,
     .set_position =     rotorez_rot_set_position,
     .get_position =     erc_rot_get_position,
+    .park =             rotorez_park,
     .stop =             dcu1_rot_stop,
     .reset =            rotorez_rot_reset,
 //  .stop =             rotorez_rot_stop,
@@ -354,7 +359,7 @@ const struct rot_caps rt21_rot_caps =
     ROT_MODEL(ROT_MODEL_RT21),
     .model_name =       "RT-21",
     .mfg_name =     "Green Heron",
-    .version =      "20220104.0",
+    .version =      "20230507.0",
     .copyright =        "LGPL",
     .status =       RIG_STATUS_STABLE,
     .rot_type =     ROT_TYPE_OTHER,
@@ -382,6 +387,7 @@ const struct rot_caps rt21_rot_caps =
     .rot_cleanup =      rotorez_rot_cleanup,
     .set_position =     rt21_rot_set_position,
     .get_position =     rt21_rot_get_position,
+    .park =             rotorez_park,
     .stop =             rotorez_rot_stop,
 //  .set_conf =         rotorez_rot_set_conf,
 //  .get_info =         rotorez_rot_get_info,
@@ -410,17 +416,17 @@ static int rotorez_rot_init(ROT *rot)
         return -RIG_EINVAL;
     }
 
-    rot->state.priv = (struct rotorez_rot_priv_data *)
-                      calloc(1, sizeof(struct rotorez_rot_priv_data));
+    ROTSTATE(rot)->priv = (struct rotorez_rot_priv_data *)
+                          calloc(1, sizeof(struct rotorez_rot_priv_data));
 
-    if (!rot->state.priv)
+    if (!ROTSTATE(rot)->priv)
     {
         return -RIG_ENOMEM;
     }
 
-    rot->state.rotport.type.rig = RIG_PORT_SERIAL;
+    ROTPORT(rot)->type.rig = RIG_PORT_SERIAL;
 
-    ((struct rotorez_rot_priv_data *)rot->state.priv)->az = 0;
+    ((struct rotorez_rot_priv_data *)ROTSTATE(rot)->priv)->az = 0;
 
     return RIG_OK;
 }
@@ -439,12 +445,12 @@ static int rotorez_rot_cleanup(ROT *rot)
         return -RIG_EINVAL;
     }
 
-    if (rot->state.priv)
+    if (ROTSTATE(rot)->priv)
     {
-        free(rot->state.priv);
+        free(ROTSTATE(rot)->priv);
     }
 
-    rot->state.priv = NULL;
+    ROTSTATE(rot)->priv = NULL;
 
     return RIG_OK;
 }
@@ -460,7 +466,7 @@ static int rotorez_rot_set_position(ROT *rot, azimuth_t azimuth,
                                     elevation_t elevation)
 {
     char cmdstr[8];
-    char execstr[5] = "AM1;";
+    const char execstr[5] = "AM1;";
     int err;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
@@ -535,7 +541,7 @@ static int rt21_rot_set_position(ROT *rot, azimuth_t azimuth,
         return err;
     }
 
-    if (rot->state.rotport2.pathname[0] != 0)
+    if (ROTPORT2(rot)->pathname[0] != 0)
     {
         SNPRINTF(cmdstr, sizeof(cmdstr), "AP1%05.1f\r;",
                  elevation);    /* Total field width of 5 chars */
@@ -562,8 +568,9 @@ static int rt21_rot_set_position(ROT *rot, azimuth_t azimuth,
 static int rotorez_rot_get_position(ROT *rot, azimuth_t *azimuth,
                                     elevation_t *elevation)
 {
-    struct rot_state *rs;
-    char cmdstr[5] = "AI1;";
+    hamlib_port_t *rotp;
+    hamlib_port_t *rotp2;
+    const char cmdstr[5] = "AI1;";
     char az[5];         /* read azimuth string */
     char *p;
     azimuth_t tmp = 0;
@@ -576,6 +583,9 @@ static int rotorez_rot_get_position(ROT *rot, azimuth_t *azimuth,
         return -RIG_EINVAL;
     }
 
+    rotp = ROTPORT(rot);
+    rotp2 = ROTPORT2(rot);
+
     do
     {
         err = rotorez_send_priv_cmd(rot, cmdstr);
@@ -585,9 +595,7 @@ static int rotorez_rot_get_position(ROT *rot, azimuth_t *azimuth,
             return err;
         }
 
-        rs = &rot->state;
-
-        err = read_block(&rs->rotport, (unsigned char *) az, AZ_READ_LEN);
+        err = read_block(rotp, (unsigned char *) az, AZ_READ_LEN);
 
         if (err != AZ_READ_LEN)
         {
@@ -649,7 +657,68 @@ static int rotorez_rot_get_position(ROT *rot, azimuth_t *azimuth,
     }
 
     *azimuth = tmp;
-    *elevation = 0;             /* RotorEZ does not support elevation */
+
+    if (strlen(rotp2->pathname) > 0)
+    {
+        do
+        {
+            err = rotorez_send_priv_cmd2(rot, cmdstr);
+
+            if (err != RIG_OK)
+            {
+                return err;
+            }
+
+            //TODO: Should this be rotp or rotp2????
+            //err = read_block(&rs->rotport, (unsigned char *) az, AZ_READ_LEN);
+            err = read_block(rotp2, (unsigned char *) az, AZ_READ_LEN);
+
+            if (err != AZ_READ_LEN)
+            {
+                return -RIG_ETRUNC;
+            }
+
+            /* The elevation string should be ';xxx' beginning at offset 0.  If the
+             * ';' is not there, it's likely the RotorEZ has received an invalid
+             * command and the buffer needs to be flushed.  See
+             * rotorez_flush_buffer() definition below for a complete description.
+             */
+            if (az[0] != ';')
+            {
+                err = rotorez_flush_buffer(rot);
+
+                if (err == -RIG_EIO)
+                {
+                    return err;
+                }
+                else
+                {
+                    err = -RIG_EINVAL;
+                }
+            }
+            else if (err == AZ_READ_LEN)
+            {
+                /* Check if remaining chars are digits if az[0] == ';' */
+                for (p = az + 1; p < az + 4; p++)
+                    if (isdigit((int)*p))
+                    {
+                        continue;
+                    }
+                    else
+                    {
+                        err = -RIG_EINVAL;
+                    }
+            }
+        }
+        while (err == -RIG_EINVAL);
+
+        sscanf(az, ";%f", elevation);
+    }
+    else
+    {
+        *elevation = 0;             /* RotorEZ does not support elevation */
+    }
+
     rig_debug(RIG_DEBUG_TRACE,
               "%s: azimuth = %.1f deg; elevation = %.1f deg\n",
               __func__, *azimuth, *elevation);
@@ -668,8 +737,7 @@ static int rotorez_rot_get_position(ROT *rot, azimuth_t *azimuth,
 static int erc_rot_get_position(ROT *rot, azimuth_t *azimuth,
                                 elevation_t *elevation)
 {
-    struct rot_state *rs;
-    char cmdstr[5] = "AI1;";
+    const char cmdstr[5] = "AI1;";
     char az[5];         /* read azimuth string */
     char *p;
     azimuth_t tmp = 0;
@@ -691,9 +759,7 @@ static int erc_rot_get_position(ROT *rot, azimuth_t *azimuth,
             return err;
         }
 
-        rs = &rot->state;
-
-        err = read_block(&rs->rotport, (unsigned char *) az, AZ_READ_LEN);
+        err = read_block(ROTPORT(rot), (unsigned char *) az, AZ_READ_LEN);
 
         if (err != AZ_READ_LEN)
         {
@@ -786,7 +852,8 @@ static int erc_rot_get_position(ROT *rot, azimuth_t *azimuth,
 static int rt21_rot_get_position(ROT *rot, azimuth_t *azimuth,
                                  elevation_t *elevation)
 {
-    struct rot_state *rs;
+    hamlib_port_t *rotp;
+    hamlib_port_t *rotp2;
     char az[8];     /* read azimuth string */
     int err;
 
@@ -797,6 +864,9 @@ static int rt21_rot_get_position(ROT *rot, azimuth_t *azimuth,
         return -RIG_EINVAL;
     }
 
+    rotp = ROTPORT(rot);
+    rotp2 = ROTPORT2(rot);
+
     /* 'BI1' is an RT-21 specific command that queries for a floating
      * point position (to the tenth of a degree).
      */
@@ -807,9 +877,7 @@ static int rt21_rot_get_position(ROT *rot, azimuth_t *azimuth,
         return err;
     }
 
-    rs = &rot->state;
-
-    err = read_string(&rs->rotport, (unsigned char *) az, RT21_AZ_LEN + 1, ";",
+    err = read_string(rotp, (unsigned char *) az, RT21_AZ_LEN + 1, ";",
                       strlen(";"), 0, 1);
 
     if (err < 0)    /* read_string returns negative on error. */
@@ -841,7 +909,32 @@ static int rt21_rot_get_position(ROT *rot, azimuth_t *azimuth,
         }
 
         *azimuth = tmp;
-        *elevation = 0.0;   /* RT-21 backend does not support el at this time. */
+
+        if (rotp2 && strlen(rotp2->pathname) > 0)
+        {
+            err = rotorez_send_priv_cmd2(rot, "BI1;");
+
+            if (err != RIG_OK)
+            {
+                return err;
+            }
+
+            err = read_string(rotp2, (unsigned char *) az, RT21_AZ_LEN + 1, ";",
+                              strlen(";"), 0, 1);
+
+            if (err < 0)    /* read_string returns negative on error. */
+            {
+                return err;
+            }
+
+            sscanf(az, "%f", elevation);
+
+        }
+        else
+        {
+            *elevation = 0.0;   /* RT-21 backend does not support el at this time. */
+        }
+
         rig_debug(RIG_DEBUG_TRACE,
                   "%s: azimuth = %.1f deg; elevation = %.1f deg\n",
                   __func__, *azimuth, *elevation);
@@ -863,7 +956,7 @@ static int rt21_rot_get_position(ROT *rot, azimuth_t *azimuth,
 
 static int rotorez_rot_stop(ROT *rot)
 {
-    char cmdstr[2] = ";";
+    const char cmdstr[2] = ";";
     int err;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
@@ -896,7 +989,7 @@ static int rotorez_rot_reset(ROT *rot, rot_reset_t reset)
 
 static int dcu1_rot_stop(ROT *rot)
 {
-    char cmdstr[5] = "AS1;";
+    const char cmdstr[5] = "AS1;";
     int err;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
@@ -925,7 +1018,7 @@ static int dcu1_rot_stop(ROT *rot)
  * define in rotorez.h and *val of '1' or '0' (enable/disable).
  */
 
-static int rotorez_rot_set_conf(ROT *rot, token_t token, const char *val)
+static int rotorez_rot_set_conf(ROT *rot, hamlib_token_t token, const char *val)
 {
     char cmdstr[2];
     char c;
@@ -999,12 +1092,22 @@ static int rotorez_rot_set_conf(ROT *rot, token_t token, const char *val)
         return -RIG_EINVAL;
     }
 
-    rig_debug(RIG_DEBUG_TRACE, "%s: c = %c, *val = %c\n", __func__, c, *val);
     SNPRINTF(cmdstr, sizeof(cmdstr), "%c", c);
 
     rig_debug(RIG_DEBUG_TRACE, "%s: cmdstr = %s, *val = %c\n",
               __func__, cmdstr, *val);
 
+    /*
+     * We cannot send anything to the rotator if it isn't open yet.
+     * Queue any set_conf commands and let rot_open reprocess them
+     *  after it has done it's job.
+     */
+    if (!ROTSTATE(rot)->comm_state)
+    {
+        err = queue_deferred_config(&ROTSTATE(rot)->config_queue, token, val);
+        return err;
+    }
+
     err = rotorez_send_priv_cmd(rot, cmdstr);
 
     if (err != RIG_OK)
@@ -1043,7 +1146,6 @@ static const char *rotorez_rot_get_info(ROT *rot)
 
 static int rotorez_send_priv_cmd(ROT *rot, const char *cmdstr)
 {
-    struct rot_state *rs;
     int err;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
@@ -1053,8 +1155,7 @@ static int rotorez_send_priv_cmd(ROT *rot, const char *cmdstr)
         return -RIG_EINVAL;
     }
 
-    rs = &rot->state;
-    err = write_block(&rs->rotport, (unsigned char *) cmdstr, strlen(cmdstr));
+    err = write_block(ROTPORT(rot), (unsigned char *) cmdstr, strlen(cmdstr));
 
     if (err != RIG_OK)
     {
@@ -1067,7 +1168,6 @@ static int rotorez_send_priv_cmd(ROT *rot, const char *cmdstr)
 // send command to 2nd rotator port
 static int rotorez_send_priv_cmd2(ROT *rot, const char *cmdstr)
 {
-    struct rot_state *rs;
     int err;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
@@ -1077,8 +1177,7 @@ static int rotorez_send_priv_cmd2(ROT *rot, const char *cmdstr)
         return -RIG_EINVAL;
     }
 
-    rs = &rot->state;
-    err = write_block(&rs->rotport2, (unsigned char *) cmdstr, strlen(cmdstr));
+    err = write_block(ROTPORT2(rot), (unsigned char *) cmdstr, strlen(cmdstr));
 
     if (err != RIG_OK)
     {
@@ -1102,7 +1201,6 @@ static int rotorez_send_priv_cmd2(ROT *rot, const char *cmdstr)
 
 static int rotorez_flush_buffer(ROT *rot)
 {
-    struct rot_state *rs;
     char garbage[32];         /* read buffer */
     int err = 0;
     size_t MAX = 31;
@@ -1114,11 +1212,9 @@ static int rotorez_flush_buffer(ROT *rot)
         return -RIG_EINVAL;
     }
 
-    rs = &rot->state;
-
     do
     {
-        err = read_block(&rs->rotport, (unsigned char *) garbage, MAX);
+        err = read_block(ROTPORT(rot), (unsigned char *) garbage, MAX);
 
         /* Oops!  An IO error was encountered.  Bail out! */
         if (err == -RIG_EIO)
@@ -1131,6 +1227,20 @@ static int rotorez_flush_buffer(ROT *rot)
     return RIG_OK;
 }
 
+/*
+ * Moves to Home Position
+ */
+static int rotorez_park(ROT *rot)
+{
+    rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
+
+    /* Assume home is 0,0 */
+    rotorez_rot_set_position(rot, 0, 0);
+
+    return RIG_OK;
+}
+
+
 
 /*
  * Initialize backend
