@@ -14,14 +14,17 @@
 BUILD_DIR=~/builds
 
 # Set this to LibUSB archive extracted in $BUILD_DIR
-LIBUSB_VER=libusb-1.0.22
+LIBUSB_VER=libusb-1.0.24
 
-# Set to the correct HOST_ARCH= line for your minGW installation
+# Set to the correct HOST_ARCH= line for your MinGW installation
 HOST_ARCH=i686-w64-mingw32
 
-# Set to the strip name for your version of minGW
+# Set to the strip name for your version of MinGW
 HOST_ARCH_STRIP=i686-w64-mingw32-strip
 
+# Set to the dlltool name for your version of MinGW
+HOST_ARCH_DLLTOOL=i686-w64-mingw32-dlltool
+
 # Error return codes.  See /usr/include/sysexits.h
 EX_USAGE=64
 EX_NOINPUT=66
@@ -111,7 +114,7 @@ following:
    a semi-colon ';' after the last path before adding the Hamlib path (NB. The
    entire path is highlighted and will be erased upon typing a character so
    click in the box to unselect the text first.  The PATH is important!!)
-   Append the Hamlib path, e.g. C:\Program Files\hamlib-w32-4.0~git\bin
+   Append the Hamlib path, e.g. C:\Program Files\hamlib-w32-$RELEASE\bin
 
  * Click OK for all three dialog boxes to save your changes.
 
@@ -121,8 +124,9 @@ Testing with the Hamlib Utilities
 
 To continue, be sure you have read the README.betatester file, especially the
 "Testing Hamlib" section.  The primary means of testing is by way of the
-rigctl utility for radios and rotctl utility for rotators.  Each is a command
-line program that is interactive or can act on a single command and exit.
+rigctl utility for radios, the rotctl utility for rotators and the ampctl
+utility for amplifiers.  Each is a command line program that is interactive
+or can act on a single command and exit.
 
 Documentation for each utility can be found as an HTML file in the doc
 directory.
@@ -176,6 +180,10 @@ program is not considered a "derivative work" when using the published Hamlib
 API and normal linking to the front-end library, and may be of a license of
 your choosing.
 
+As of 08 Sep 2022 a .lib file is generated using the MinGW dlltool utility.
+If this file does not work for your project, follow the steps in the following
+section:
+
 For linking the library with MS Visual C++ 2003, from the directory you
 installed Hamlib run the following commands to generate the libhamlib-4.lib
 file needed for linking with your MSVC project:
@@ -186,15 +194,12 @@ c:\Program Files\Microsoft Visual C++ Toolkit 2003\bin\link.exe /lib /machine:i3
 To do the same for Visual Studio 2017:
 
 cd lib\msvc
-"c:\Program Files (x86)\Microsoft Visual Studio\2017\BuildTools\Tools\MSVC\14.16.27023\bin\Hostx64\x86\bin\link.exe" /lib /machine:i386 /def:libhamlib-4.def
+c:\Program Files (x86)\Microsoft Visual Studio\2017\BuildTools\Tools\MSVC\14.16.27023\bin\Hostx64\x86\bin\link.exe /lib /machine:i386 /def:libhamlib-4.def
 
-and for VS 2019:
+For VS 2019:
 
 cd lib\msvc
-"c:\Program Files (x86)\Microsoft Visual Studio\2019\Community\VC\Tools\MSVC\14.25.28610\bin\Hostx64\x86\bin\link.exe" /lib /machine:i386 /def:libhamlib-4.def
-
-cd lib/msvc
-"c:\Program Files\Microsoft Visual Studio\2022\Community\VC\Tools\MSVC\14.32.31326\bin\Hostx64\x86\link.exe" /lib /machine:i386 /def:libhamlib-4.def
+c:\Program Files (x86)\Microsoft Visual Studio\2019\Community\VC\Tools\MSVC\14.25.28610\bin\Hostx64\x86\bin\link.exe /lib /machine:i386 /def:libhamlib-4.def
 
 NOTE: feedback is requested on the previous two command examples!
 
@@ -212,6 +217,7 @@ Please report problems or success to hamlib-developer@lists.sourceforge.net
 
 Cheers,
 Stephane Fillod - F8CFE
+Mike Black - W9MDB
 Nate Bargmann - N0NB
 http://www.hamlib.org
 
@@ -287,4 +293,21 @@ then
     cp -a ${FILE} ${ZIP_DIR}/bin/.
 fi
 
+# Required for MinGW with GCC 10 (Debian 11)
+FILE="/usr/lib/gcc/i686-w64-mingw32/10-posix/libgcc_s_dw2-1.dll"
+if test -f "$FILE"
+then
+    cp -a ${FILE} ${ZIP_DIR}/bin/.
+fi
+
+# Required for MinGW with GCC 12 (Debian 12)
+FILE="/usr/lib/gcc/i686-w64-mingw32/12-posix/libgcc_s_dw2-1.dll"
+if test -f "$FILE"
+then
+    cp -a ${FILE} ${ZIP_DIR}/bin/.
+fi
+
+# Generate .lib file for MSVC
+${HOST_ARCH_DLLTOOL} --input-def ${ZIP_DIR}/lib/msvc/libhamlib-4.def --output-lib ${ZIP_DIR}/lib/msvc/libhamlib-4.lib
+
 /usr/bin/zip -r ${HL_FILENAME}.zip $(basename ${ZIP_DIR})
