@@ -1,9 +1,6 @@
 // simicom will show the pts port to use for rigctl on Unix
 // using virtual serial ports on Windows is to be developed yet
 // Needs a lot of improvement to work on all Icoms
-// gcc -g -Wall -o simicom simicom.c -lhamlib
-// On mingw in the hamlib src directory
-// gcc -static -I../include -g -Wall -o simicom simicom.c -L../../build/src/.libs -lhamlib -lwsock32 -lws2_32
 #define _XOPEN_SOURCE 700
 // since we are POSIX here we need this
 #if 0
@@ -718,7 +715,7 @@ char *name = ptsname(fd);
 
 if (name == NULL)
 {
-    perror("pstname");
+    perror("ptsname");
     return -1;
 }
 
