@@ -1,6 +1,5 @@
 //#define TRACE /* Full traffic trace if enabled */
 // can run this using rigctl/rigctld and socat pty devices
-// gcc -o simts890 -l hamlib simts890.c
 #define _XOPEN_SOURCE 700
 // since we are POSIX here we need this
 #if  0
@@ -209,7 +208,7 @@ int openPort(char *comport) // doesn't matter for using pts devices
 
     if (name == NULL)
     {
-        perror("pstname");
+        perror("ptsname");
         return -1;
     }
 
@@ -1420,7 +1419,7 @@ int main(int argc, char *argv[])
             switch (buf[2])
             {
             case '0': // Frequency Marker Function
-            case '1': // Frequency Marker List Regiatration
+            case '1': // Frequency Marker List Registration
             case '2': // Total Number Registered of Frequency Marker List
             case '3': // Frequency Marker List Readout
             case '4': // Frequency Marker List Delete
