@@ -65,6 +65,7 @@
 DEFINE_INITAMP_BACKEND(dummy);
 DEFINE_INITAMP_BACKEND(kpa1500);
 DEFINE_INITAMP_BACKEND(gemini);
+DEFINE_INITAMP_BACKEND(expert);
 //! @endcond
 
 /**
@@ -88,6 +89,7 @@ static struct
     { AMP_DUMMY, AMP_BACKEND_DUMMY, AMP_FUNCNAMA(dummy) },
     { AMP_ELECRAFT, AMP_BACKEND_ELECRAFT, AMP_FUNCNAMA(kpa1500) },
     { AMP_GEMINI, AMP_BACKEND_GEMINI, AMP_FUNCNAMA(gemini) },
+    { AMP_EXPERT, AMP_BACKEND_EXPERT, AMP_FUNCNAMA(expert) },
     { 0, NULL }, /* end */
 };
 
