@@ -1,2 +1,2 @@
 /* This date time is from the last non-merge commit to Hamlib. */
-#define HAMLIBDATETIME "2025-07-18T18:23:23Z SHA=59e3d1"
+#define HAMLIBDATETIME "2025-09-05T19:49:48Z SHA=8a6bd5"
