@@ -139,6 +139,8 @@
 #define LVL_SWR           setting2idx_builtin(RIG_LEVEL_SWR)
 #define LVL_ALC           setting2idx_builtin(RIG_LEVEL_ALC)
 #define LVL_STRENGTH      setting2idx_builtin(RIG_LEVEL_STRENGTH)
+#define LVL_USB_AF        setting2idx_builtin(RIG_LEVEL_USB_AF)
+#define LVL_USB_AF_INPUT  setting2idx_builtin(RIG_LEVEL_USB_AF_INPUT)
 /*#define LVL_BWC          setting2idx_builtin(RIG_LEVEL_BWC)*/
 
 #define LVL_RFPOWER_METER setting2idx_builtin(RIG_LEVEL_RFPOWER_METER)
@@ -187,6 +189,9 @@
 #define PARM_TIME      setting2idx_builtin(RIG_PARM_TIME)
 #define PARM_BAT       setting2idx_builtin(RIG_PARM_BAT)
 #define PARM_KEYLIGHT  setting2idx_builtin(RIG_PARM_KEYLIGHT)
+#define PARM_BANDSELECT setting2idx_builtin(RIG_PARM_BANDSELECT)
+#define PARM_SCREENSAVER setting2idx_builtin(RIG_PARM_SCREENSAVER)
+#define PARM_KEYERTYPE setting2idx_builtin(RIG_PARM_KEYERTYPE)
 
 /* Rotator levels */
 
