@@ -76,11 +76,8 @@
  */
 
 
-#ifdef HAVE_CONFIG_H
-#  include "config.h"
-#endif
+#include <hamlib/config.h>
 
-#include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
@@ -377,7 +374,7 @@ int HAMLIB_API dec2dms(double dec,
  * notation common on many GPS units.
  *
  * When passed a value < -180 or > 180, the value will be normalized
- * within these limits and the sign set apropriately.
+ * within these limits and the sign set appropriately.
  *
  * Upon return dec2dmmm guarantees 0 >= \a degrees <= 180,
  * 0.0 >= \a minutes < 60.0.
