@@ -28,7 +28,6 @@
 
 #include <hamlib/config.h>
 
-#include <errno.h>
 #include <stdlib.h>
 #include <string.h>
 #include <stdio.h>
@@ -44,7 +43,7 @@
 #  define PATH_MAX       1024
 #endif
 
-#define RIG_BACKEND_MAX 32
+#define RIG_BACKEND_MAX 50
 
 #define DEFINE_INITRIG_BACKEND(backend) \
     int MAKE_VERSIONED_FN(PREFIX_INITRIG, ABI_VERSION, backend(void *be_handle)); \
@@ -89,6 +88,10 @@ DEFINE_INITRIG_BACKEND(barrett);
 DEFINE_INITRIG_BACKEND(elad);
 DEFINE_INITRIG_BACKEND(codan);
 DEFINE_INITRIG_BACKEND(gomspace);
+DEFINE_INITRIG_BACKEND(mds);
+DEFINE_INITRIG_BACKEND(anytone);
+DEFINE_INITRIG_BACKEND(motorola);
+DEFINE_INITRIG_BACKEND(commradio);
 //! @endcond
 
 #ifdef HAVE_WINRADIO
@@ -147,6 +150,10 @@ static struct
     { RIG_ELAD, RIG_BACKEND_ELAD, RIG_FUNCNAMA(elad) },
     { RIG_CODAN, RIG_BACKEND_CODAN, RIG_FUNCNAMA(codan) },
     { RIG_GOMSPACE, RIG_BACKEND_GOMSPACE, RIG_FUNCNAM(gomspace) },
+    { RIG_MDS, RIG_BACKEND_MDS, RIG_FUNCNAMA(mds) },
+    { RIG_ANYTONE, RIG_BACKEND_ANYTONE, RIG_FUNCNAMA(anytone) },
+    { RIG_MOTOROLA, RIG_BACKEND_MOTOROLA, RIG_FUNCNAMA(motorola) },
+    { RIG_COMMRADIO, RIG_BACKEND_COMMRADIO, RIG_FUNCNAM(commradio) },
     { 0, NULL }, /* end */
 };
 
@@ -158,7 +165,7 @@ static struct
 //! @cond Doxygen_Suppress
 struct rig_list
 {
-    const struct rig_caps *caps;
+    struct rig_caps *caps;
     struct rig_list *next;
 };
 //! @endcond
@@ -186,7 +193,7 @@ static int rig_lookup_backend(rig_model_t rig_model);
  * Basically, this is a hash insert function that doesn't check for dup!
  */
 //! @cond Doxygen_Suppress
-int HAMLIB_API rig_register(const struct rig_caps *caps)
+int HAMLIB_API rig_register(struct rig_caps *caps)
 {
     int hval;
     struct rig_list *p;
@@ -199,7 +206,7 @@ int HAMLIB_API rig_register(const struct rig_caps *caps)
     }
 
 #if 0
-    rig_debug(RIG_DEBUG_VERBOSE,
+    rig_debug(RIG_DEBUG_ERR,
               "%s: rig_register (%u)\n",
               __func__,
               caps->rig_model);
@@ -225,7 +232,6 @@ int HAMLIB_API rig_register(const struct rig_caps *caps)
     p->next = rig_hash_table[hval];
     rig_hash_table[hval] = p;
 
-    //RETURNFUNC(RIG_OK);
     return RIG_OK;
 }
 //! @endcond
@@ -236,7 +242,7 @@ int HAMLIB_API rig_register(const struct rig_caps *caps)
  */
 
 //! @cond Doxygen_Suppress
-const struct rig_caps *HAMLIB_API rig_get_caps(rig_model_t rig_model)
+struct rig_caps *HAMLIB_API rig_get_caps(rig_model_t rig_model)
 {
     struct rig_list *p;
 
@@ -288,7 +294,7 @@ int HAMLIB_API rig_check_backend(rig_model_t rig_model)
     const struct rig_caps *caps;
     int be_idx;
     int retval;
-    int i, n;
+//    int i;
 
     /* already loaded ? */
     caps = rig_get_caps(rig_model);
@@ -298,13 +304,14 @@ int HAMLIB_API rig_check_backend(rig_model_t rig_model)
         return RIG_OK;
     }
 
+#if 0 // this stopped a 2nd rig_init call with a valid model to fail -- reversing
+
     // hmmm...no caps so did we already load the rigs?
     for (n = 0, i = 0; i < RIGLSTHASHSZ; i++)
     {
         if (rig_hash_table[i]) { ++n; }
     }
 
-#if 0 // this stopped a 2nd rig_init call with a valid model to fail -- reversing
 
     if (n > 1)
     {
