@@ -24,8 +24,8 @@
 
 #include <hamlib/rotator.h>
 
-int frontrot_set_conf(ROT *rot, token_t token, const char *val);
-int frontrot_get_conf(ROT *rot, token_t token, char *val, int val_len);
+int frontrot_set_conf(ROT *rot, hamlib_token_t token, const char *val);
+int frontrot_get_conf(ROT *rot, hamlib_token_t token, char *val, int val_len);
 
 
 #endif /* _ROT_CONF_H */
