@@ -90,6 +90,11 @@ DEFINE_INITROT_BACKEND(indi);
 DEFINE_INITROT_BACKEND(androidsensor);
 #endif
 DEFINE_INITROT_BACKEND(grbltrk);
+DEFINE_INITROT_BACKEND(flir);
+DEFINE_INITROT_BACKEND(apex);
+DEFINE_INITROT_BACKEND(saebrtrack);
+DEFINE_INITROT_BACKEND(skywatcher);
+
 //! @endcond
 
 /**
@@ -138,6 +143,10 @@ static struct
     { ROT_ANDROIDSENSOR, ROT_BACKEND_ANDROIDSENSOR, ROT_FUNCNAMA(androidsensor) },
 #endif
     { ROT_GRBLTRK, ROT_BACKEND_GRBLTRK, ROT_FUNCNAMA(grbltrk) },
+    { ROT_FLIR, ROT_BACKEND_FLIR, ROT_FUNCNAMA(flir) },
+    { ROT_APEX, ROT_BACKEND_APEX, ROT_FUNCNAMA(apex) },
+    { ROT_SAEBRTRACK, ROT_BACKEND_SAEBRTRACK, ROT_FUNCNAMA(saebrtrack)},
+    { ROT_SKYWATCHER, ROT_BACKEND_SKYWATCHER, ROT_FUNCNAMA(skywatcher)},
     { 0, NULL }, /* end */
 };
 
