@@ -71,7 +71,7 @@
 #define TOK_STOP_BITS   TOKEN_FRONTEND(22)
 /** \brief  Serial parity (format?) */
 #define TOK_PARITY      TOKEN_FRONTEND(23)
-/** \brief Serial Handshake (format?)  */
+/** \brief Serial Handshake (format?) */
 #define TOK_HANDSHAKE   TOKEN_FRONTEND(24)
 /** \brief Serial Req. To Send status */
 #define TOK_RTS_STATE   TOKEN_FRONTEND(25)
@@ -89,17 +89,23 @@
 #define TOK_PTT_BITNUM        TOKEN_FRONTEND(34)
 /** \brief  PTT share with other applications */
 #define TOK_PTT_SHARE        TOKEN_FRONTEND(35)
-/** \brief  PTT share with other applications */
+/** \brief  Flush with read instead of TCFLUSH */
 #define TOK_FLUSHX        TOKEN_FRONTEND(36)
 /** \brief  Asynchronous data transfer support */
 #define TOK_ASYNC        TOKEN_FRONTEND(37)
+/** \brief  Tuner external control pathname */
+#define TOK_TUNER_CONTROL_PATHNAME TOKEN_FRONTEND(38)
+/** \brief Number of retries permitted in case of read timeouts */
+#define TOK_TIMEOUT_RETRY       TOKEN_FRONTEND(39)
+#define TOK_POST_PTT_DELAY       TOKEN_FRONTEND(40)
+#define TOK_DEVICE_ID            TOKEN_FRONTEND(41)
 
 /*
  * rig specific tokens
  */
 /* rx_range_list/tx_range_list, filters, announces, has(func,lvl,..) */
 
-/** \brief rig: ?? */
+/** \brief rig: VFO compensation in ppm */
 #define TOK_VFO_COMP    TOKEN_FRONTEND(110)
 /** \brief rig: Rig state poll interval in milliseconds */
 #define TOK_POLL_INTERVAL   TOKEN_FRONTEND(111)
@@ -119,10 +125,27 @@
 #define TOK_AUTO_DISABLE_SCREENSAVER  TOKEN_FRONTEND(126)
 /** \brief rig: Disable Yaesu band select logic */
 #define TOK_DISABLE_YAESU_BANDSELECT  TOKEN_FRONTEND(127)
-/** \brief rig: Supporess get_freq on VFOB for satellite RIT tuning */
+/** \brief rig: Suppress get_freq on VFOB for satellite RIT tuning */
 #define TOK_TWIDDLE_TIMEOUT  TOKEN_FRONTEND(128)
-/** \brief rig: Supporess get_freq on VFOB for satellite RIT tuning */
+/** \brief rig: Suppress get_freq on VFOB for satellite RIT tuning */
 #define TOK_TWIDDLE_RIT  TOKEN_FRONTEND(129)
+/** \brief rig: Add Hz to VFOA/Main frequency set */
+#define TOK_OFFSET_VFOA  TOKEN_FRONTEND(130)
+/** \brief rig: Add Hz to VFOB/Sub frequency set */
+#define TOK_OFFSET_VFOB  TOKEN_FRONTEND(131)
+/** \brief rig: Multicast data UDP address for publishing rig data and state, default 224.0.0.1, value of 0.0.0.0 disables multicast data publishing */
+#define TOK_MULTICAST_DATA_ADDR  TOKEN_FRONTEND(132)
+/** \brief rig: Multicast data UDP port, default 4532 */
+#define TOK_MULTICAST_DATA_PORT  TOKEN_FRONTEND(133)
+/** \brief rig: Multicast command server UDP address for sending commands to rig, default 224.0.0.2, value of 0.0.0.0 disables multicast command server */
+#define TOK_MULTICAST_CMD_ADDR  TOKEN_FRONTEND(134)
+/** \brief rig: Multicast command server UDP port, default 4532 */
+#define TOK_MULTICAST_CMD_PORT  TOKEN_FRONTEND(135)
+/** \brief rig: Skip setting freq on opposite VFO when in split mode */
+#define TOK_FREQ_SKIP  TOKEN_FRONTEND(136)
+/** \brief rig: Client ID of WSJTX or GPREDICT */
+#define TOK_CLIENT  TOKEN_FRONTEND(137)
+
 /*
  * rotator specific tokens
  * (strictly, should be documented as rotator_internal)
