@@ -19,17 +19,16 @@
  *
  */
 
-#include <hamlib/config.h>
-
 #include <stdio.h>
 #include <string.h>
 
 #include <hamlib/rig.h>
 #include "misc.h"
-
+#include "riglist.h"
 #include "sprintflst.h"
 #include "rigctl_parse.h"
 #include "../rigs/icom/icom.h"
+#include "dumpcaps.h"
 
 void range_print(FILE *fout, const struct freq_range_list range_list[], int rx);
 int range_sanity_check(const struct freq_range_list range_list[], int rx);
@@ -72,12 +71,13 @@ static int print_ext(RIG *rig, const struct confparams *cfp, rig_ptr_t ptr)
 int dumpcaps(RIG *rig, FILE *fout)
 {
     const struct rig_caps *caps;
+    struct rig_state *rs;
     int status, i;
     int can_esplit, can_echannel;
     char freqbuf[20];
     int backend_warnings = 0;
     char warnbuf[4096];
-    char prntbuf[1024];  /* a malloc would be better.. */
+    char prntbuf[8192];  /* a malloc would be better.. */
     char *label1, *label2, *label3, *label4, *label5;
     char *labelrx1; // , *labelrx2, *labelrx3, *labelrx4, *labelrx5;
 
@@ -90,10 +90,12 @@ int dumpcaps(RIG *rig, FILE *fout)
     }
 
     caps = rig->caps;
+    rs = STATE(rig);
 
     fprintf(fout, "Caps dump for model: %u\n", caps->rig_model);
     fprintf(fout, "Model name:\t%s\n", caps->model_name);
     fprintf(fout, "Mfg name:\t%s\n", caps->mfg_name);
+    fprintf(fout, "Hamlib version:\t%s\n", hamlib_version2);
     fprintf(fout, "Backend version:\t%s\n", caps->version);
     fprintf(fout, "Backend copyright:\t%s\n", caps->copyright);
     fprintf(fout, "Backend status:\t%s\n", rig_strstatus(caps->status));
@@ -193,7 +195,7 @@ int dumpcaps(RIG *rig, FILE *fout)
     case RIG_PORT_SERIAL:
         fprintf(fout, "RS-232\n");
         fprintf(fout,
-                "Serial speed: %d..%d bauds, %d%c%d %s\n",
+                "Serial speed: %d..%d baud, %d%c%d, ctrl=%s\n",
                 caps->serial_rate_min,
                 caps->serial_rate_max,
                 caps->serial_data_bits,
@@ -202,7 +204,7 @@ int dumpcaps(RIG *rig, FILE *fout)
                 caps->serial_parity == RIG_PARITY_EVEN ? 'E' :
                 caps->serial_parity == RIG_PARITY_MARK ? 'M' : 'S',
                 caps->serial_stop_bits,
-                caps->serial_handshake == RIG_HANDSHAKE_NONE ? "" :
+                caps->serial_handshake == RIG_HANDSHAKE_NONE ? "NONE" :
                 (caps->serial_handshake == RIG_HANDSHAKE_XONXOFF ? "XONXOFF" : "CTS/RTS")
                );
         break;
@@ -238,16 +240,48 @@ int dumpcaps(RIG *rig, FILE *fout)
     }
 
     fprintf(fout,
-            "Write delay: %dmS, timeout %dmS, %d retry\n",
+            "Write delay: %dms, timeout %dms, %d retry\n",
             caps->write_delay, caps->timeout, caps->retry);
     fprintf(fout,
-            "Post Write delay: %dmS\n",
+            "Post write delay: %dms\n",
             caps->post_write_delay);
 
     fprintf(fout,
             "Has targetable VFO: %s\n",
             caps->targetable_vfo ? "Y" : "N");
 
+    fprintf(fout, "Targetable features:");
+
+    if (caps->targetable_vfo & RIG_TARGETABLE_FREQ) { fprintf(fout, " FREQ"); }
+
+    if (caps->targetable_vfo & RIG_TARGETABLE_MODE) { fprintf(fout, " MODE"); }
+
+    if (caps->targetable_vfo & RIG_TARGETABLE_TONE) { fprintf(fout, " TONE"); }
+
+    if (caps->targetable_vfo & RIG_TARGETABLE_FUNC) { fprintf(fout, " FUNC"); }
+
+    if (caps->targetable_vfo & RIG_TARGETABLE_LEVEL) { fprintf(fout, " LEVEL"); }
+
+    if (caps->targetable_vfo & RIG_TARGETABLE_RITXIT) { fprintf(fout, " RITXIT"); }
+
+    if (caps->targetable_vfo & RIG_TARGETABLE_PTT) { fprintf(fout, " PTT"); }
+
+    if (caps->targetable_vfo & RIG_TARGETABLE_MEM) { fprintf(fout, " MEM"); }
+
+    if (caps->targetable_vfo & RIG_TARGETABLE_BANK) { fprintf(fout, " BANK"); }
+
+    if (caps->targetable_vfo & RIG_TARGETABLE_ANT) { fprintf(fout, " ANT"); }
+
+    if (caps->targetable_vfo & RIG_TARGETABLE_ROOFING) { fprintf(fout, " ROOFING"); }
+
+    if (caps->targetable_vfo & RIG_TARGETABLE_SPECTRUM) { fprintf(fout, " SPECTRUM"); }
+
+    if (caps->targetable_vfo & RIG_TARGETABLE_BAND) { fprintf(fout, " BAND"); }
+
+    if (caps->targetable_vfo == 0) { fprintf(fout, " None"); }
+
+    fprintf(fout, "\n");
+
     fprintf(fout,
             "Has async data support: %s\n",
             caps->async_data_supported ? "Y" : "N");
@@ -303,8 +337,8 @@ int dumpcaps(RIG *rig, FILE *fout)
     if (priv_caps && RIG_BACKEND_NUM(rig->caps->rig_model) == RIG_ICOM
             && priv_caps->agc_levels_present)
     {
-        for (i = 0; i <= RIG_AGC_LAST && priv_caps->agc_levels[i].level != RIG_AGC_LAST
-                && priv_caps->agc_levels[i].icom_level >= 0; i++)
+        for (i = 0; i < HAMLIB_MAX_AGC_LEVELS
+                && priv_caps->agc_levels[i].level != RIG_AGC_LAST ; i++)
         {
             fprintf(fout, " %d=%s", priv_caps->agc_levels[i].level,
                     rig_stragclevel(priv_caps->agc_levels[i].level));
@@ -312,31 +346,16 @@ int dumpcaps(RIG *rig, FILE *fout)
     }
     else
     {
-
         for (i = 0; i < HAMLIB_MAX_AGC_LEVELS && i < caps->agc_level_count; i++)
         {
             fprintf(fout, " %d=%s", caps->agc_levels[i],
                     rig_stragclevel(caps->agc_levels[i]));
         }
-
-        if (i == 0)
-        {
-            fprintf(fout, " %d=%s", RIG_AGC_NONE, rig_stragclevel(RIG_AGC_NONE));
-        }
     }
 
-    fprintf(fout, "\n");
-
     if (i == 0)
     {
-        rig_debug(RIG_DEBUG_WARN,
-                  "%s: defaulting to all levels since rig does not have any\n", __func__);
-
-        // Fall back to printing out all levels for backwards-compatibility
-        for (i = RIG_AGC_OFF; i <= RIG_AGC_LAST; i++)
-        {
-            fprintf(fout, " %d=%s", i, rig_stragclevel(i));
-        }
+        fprintf(fout, " %d=%s", RIG_AGC_NONE, rig_stragclevel(RIG_AGC_NONE));
     }
 
     fprintf(fout, "\n");
@@ -437,10 +456,9 @@ int dumpcaps(RIG *rig, FILE *fout)
     fprintf(fout, "Extra parameters:\n");
     rig_ext_parm_foreach(rig, print_ext, fout);
 
-
-    if (rig->state.mode_list != 0)
+    if (rs->mode_list != 0)
     {
-        rig_sprintf_mode(prntbuf, sizeof(prntbuf), rig->state.mode_list);
+        rig_sprintf_mode(prntbuf, sizeof(prntbuf), rs->mode_list);
     }
     else
     {
@@ -451,9 +469,9 @@ int dumpcaps(RIG *rig, FILE *fout)
 
     fprintf(fout, "Mode list: %s\n", prntbuf);
 
-    if (rig->state.vfo_list != 0)
+    if (rs->vfo_list != 0)
     {
-        rig_sprintf_vfo(prntbuf, sizeof(prntbuf), rig->state.vfo_list);
+        rig_sprintf_vfo(prntbuf, sizeof(prntbuf), rs->vfo_list);
     }
     else
     {
@@ -905,6 +923,8 @@ int dumpcaps(RIG *rig, FILE *fout)
     fprintf(fout, "Can send DTMF:\t%c\n", caps->send_dtmf != NULL ? 'Y' : 'N');
     fprintf(fout, "Can recv DTMF:\t%c\n", caps->recv_dtmf != NULL ? 'Y' : 'N');
     fprintf(fout, "Can send Morse:\t%c\n", caps->send_morse != NULL ? 'Y' : 'N');
+    fprintf(fout, "Can stop Morse:\t%c\n", caps->stop_morse != NULL ? 'Y' : 'N');
+    fprintf(fout, "Can wait Morse:\t%c\n", caps->wait_morse != NULL ? 'Y' : 'N');
     fprintf(fout, "Can send Voice:\t%c\n",
             caps->send_voice_mem != NULL ? 'Y' : 'N');
 
@@ -918,7 +938,7 @@ int dumpcaps(RIG *rig, FILE *fout)
 
     can_echannel = caps->set_mem
                    && ((caps->set_vfo
-                        && ((rig->state.vfo_list & RIG_VFO_MEM) == RIG_VFO_MEM))
+                        && ((rs->vfo_list & RIG_VFO_MEM) == RIG_VFO_MEM))
                        || (caps->vfo_op
                            && rig_has_vfo_op(rig, RIG_OP_TO_VFO | RIG_OP_FROM_VFO)));
 
@@ -1149,6 +1169,11 @@ static void dump_chan_caps(const channel_cap_t *chan, FILE *fout)
         fprintf(fout, "WIDTH ");
     }
 
+    if (chan->split)
+    {
+        fprintf(fout, "SPLIT ");
+    }
+
     if (chan->tx_freq)
     {
         fprintf(fout, "TXFREQ ");
@@ -1253,3 +1278,15 @@ int dumpconf(RIG *rig, FILE *fout)
 
     return 0;
 }
+
+int dumpconf_list(RIG *rig, FILE *fout)
+{
+    rig_token_foreach(rig, print_conf_list2, (rig_ptr_t)rig);
+    return 0;
+}
+
+int dumpconf_list_rot(ROT *rot, FILE *fout)
+{
+    rot_token_foreach(rot, print_conf_list2, rot);
+    return 0;
+}
