@@ -29,7 +29,7 @@
 
 int print_caps_sum(const struct rig_caps *caps, void *data)
 {
-    char *fmt1 = "%-13s";
+    const char *fmt1 = "%-13s";
     printf("%6u \t%-22s \t%-23s\t%-8s   \t",
            caps->rig_model,
            caps->mfg_name,
