@@ -21,19 +21,12 @@
  *
  */
 
-#include <hamlib/config.h>
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <ctype.h>
-#include <errno.h>
-
-#include <getopt.h>
 
 #include <hamlib/rig.h>
 #include "misc.h"
-#include "sprintflst.h"
 
 
 /*
@@ -68,7 +61,7 @@ static int  tokenize_line(char *line,
                           size_t siz,
                           char delim);
 
-static int find_on_list(char **list, char *what);
+static int find_on_list(char **list, const char *what);
 
 int csv_save(RIG *rig, const char *outfilename);
 int csv_load(RIG *rig, const char *infilename);
@@ -279,6 +272,7 @@ static char *mystrtok(char *s, char delim)
     }
     else
     {
+        return NULL;
     }
 
     if (str && str[ pos + 1 ] == '\0')
@@ -349,7 +343,7 @@ int csv_parm_save(RIG *rig, const char *outfilename)
 {
     int i, ret;
     FILE *f;
-    setting_t get_parm = all ? 0x7fffffff : rig->state.has_get_parm;
+    setting_t get_parm = all ? 0x7fffffff : STATE(rig)->has_get_parm;
 
     f = fopen(outfilename, "w");
 
@@ -547,6 +541,11 @@ void dump_csv_name(const channel_cap_t *mem_caps, FILE *f)
         fprintf(f, "flags%c", csv_sep);
     }
 
+    if (mem_caps->tag)
+    {
+        fprintf(f, "tag%c", csv_sep);
+    }
+
     fprintf(f, "\n");
 }
 
@@ -700,7 +699,19 @@ int dump_csv_chan(RIG *rig,
 
     if (mem_caps->flags)
     {
-        fprintf(f, "%x%c", chan.flags, csv_sep);
+        if (chan.tag[0] != 0)  // then we need the separator
+        {
+            fprintf(f, "%x%c", chan.flags, csv_sep);
+        }
+        else
+        {
+            fprintf(f, "%x", chan.flags);
+        }
+    }
+
+    if (chan.tag[0] != 0)
+    {
+        fprintf(f, "%s", chan.tag);
     }
 
     fprintf(f, "\n");
@@ -731,6 +742,7 @@ int set_channel_data(RIG *rig,
 
     int i, j, n;
     const channel_cap_t *mem_caps;
+    struct rig_state *rs = STATE(rig);
 
     memset(chan, 0, sizeof(channel_t));
     chan->vfo = RIG_VFO_CURR;
@@ -748,7 +760,7 @@ int set_channel_data(RIG *rig,
     /* find channel caps of appropriate memory group? */
     for (j = 0; j < HAMLIB_CHANLSTSIZ; j++)
     {
-        if (rig->state.chan_list[j].startc <= n && rig->state.chan_list[j].endc >= n)
+        if (rs->chan_list[j].startc <= n && rs->chan_list[j].endc >= n)
         {
             break;
         }
@@ -761,7 +773,7 @@ int set_channel_data(RIG *rig,
 
     printf("Requested channel number %d, list number %d\n", n, j);
 
-    mem_caps = &rig->state.chan_list[j].mem_caps;
+    mem_caps = &rs->chan_list[j].mem_caps;
 
     if (mem_caps->bank_num)
     {
@@ -1021,7 +1033,7 @@ int set_channel_data(RIG *rig,
     \return string position on the list on success,
            -1 if string not found or if string is empty
 */
-int find_on_list(char **list, char *what)
+int find_on_list(char **list, const char *what)
 {
     int i = 0;
 
