@@ -28,12 +28,17 @@
 #include <stdio.h>
 #include <hamlib/rig.h>
 
+#define RIGCTL_PARSE_END 1
+#define RIGCTL_PARSE_ERROR 2
+
 /*
  * external prototype
  */
 
 int dumpcaps(RIG *, FILE *);
+int dumpstate(RIG *, FILE *);
 int dumpconf(RIG *, FILE *);
+int dumpconf_list(RIG *, FILE *);
 
 /*
  * Prototypes
@@ -43,11 +48,12 @@ void version();
 void list_models();
 int dump_chan(FILE *, RIG *, channel_t *);
 int print_conf_list(const struct confparams *cfp, rig_ptr_t data);
+int print_conf_list2(const struct confparams *cfp, rig_ptr_t data);
 int set_conf(RIG *my_rig, char *conf_parms);
 
 typedef void (*sync_cb_t)(int);
 int rigctl_parse(RIG *my_rig, FILE *fin, FILE *fout, char *argv[], int argc, sync_cb_t sync_cb,
                  int interactive, int prompt, int * vfo_mode, char send_cmd_term,
-                 int * ext_resp_ptr, char * resp_sep_ptr);
+                 int * ext_resp_ptr, char * resp_sep_ptr, int use_password);
 
 #endif  /* RIGCTL_PARSE_H */
