@@ -11,10 +11,10 @@
 
 #include <hamlib/config.h>
 
-#define SERIAL_PORT "/dev/pts/4"
+#define SERIAL_PORT "/dev/pts/2"
 
 
-int main(int argc, char *argv[])
+int main(int argc, const char *argv[])
 {
     RIG *my_rig;        /* handle to rig (nstance) */
     freq_t freq;        /* frequency  */
@@ -38,9 +38,10 @@ int main(int argc, char *argv[])
      * allocate memory, setup & open port
      */
 
+    hamlib_port_t myport;
+
     if (argc < 2)
     {
-        hamlib_port_t myport;
         /* may be overridden by backend probe */
         myport.type.rig = RIG_PORT_SERIAL;
         myport.parm.serial.rate = 9600;
@@ -48,7 +49,6 @@ int main(int argc, char *argv[])
         myport.parm.serial.stop_bits = 1;
         myport.parm.serial.parity = RIG_PARITY_NONE;
         myport.parm.serial.handshake = RIG_HANDSHAKE_NONE;
-        strncpy(myport.pathname, SERIAL_PORT, HAMLIB_FILPATHLEN - 1);
 
         rig_load_all_backends();
         myrig_model = rig_probe(&myport);
@@ -59,15 +59,16 @@ int main(int argc, char *argv[])
     }
 
     my_rig = rig_init(myrig_model);
+    rig_set_conf(my_rig, rig_token_lookup(my_rig, "rig_pathname"), SERIAL_PORT);
 
     if (!my_rig)
     {
-        fprintf(stderr, "Unknown rig num: %d\n", myrig_model);
+        fprintf(stderr, "Unknown rig num: %u\n", myrig_model);
         fprintf(stderr, "Please check riglist.h\n");
         exit(1); /* whoops! something went wrong (mem alloc?) */
     }
 
-    //strncpy(my_rig->state.rigport.pathname, SERIAL_PORT, HAMLIB_FILPATHLEN - 1);
+    //strncpy(RIGPORT(my_rig)->pathname, SERIAL_PORT, HAMLIB_FILPATHLEN - 1);
 
     retcode = rig_open(my_rig);
 
@@ -77,8 +78,22 @@ int main(int argc, char *argv[])
         exit(2);
     }
 
+    uint64_t levels = rig_get_caps_int(my_rig->caps->rig_model,
+                                       RIG_CAPS_HAS_GET_LEVEL);
+    printf("HAS_GET_LEVEL=0x%8llx, SWR=%8llx,true=%d\n", (unsigned long long)levels,
+           (unsigned long long)(levels & RIG_LEVEL_SWR),
+           (levels & RIG_LEVEL_SWR) == RIG_LEVEL_SWR);
+
     char val[256];
-    retcode = rig_get_conf2(my_rig, rig_token_lookup(my_rig, "write_delay"), val, sizeof(val));
+    retcode = rig_get_conf2(my_rig, rig_token_lookup(my_rig, "write_delay"), val,
+                            sizeof(val));
+
+    if (retcode != RIG_OK)
+    {
+        rig_debug(RIG_DEBUG_ERR, "%s: rig_get_conf2: %s\n", __func__,
+                  rigerror(retcode));
+    }
+
     printf("write_delay=%s\n", val);
 
 //    printf("Port %s opened ok\n", SERIAL_PORT);
@@ -138,7 +153,7 @@ int main(int argc, char *argv[])
 
     if (freq != 29620000)
     {
-        printf("rig_set_freq: error exptect %.0f got %.0f\n", 296290000.0, freq);
+        printf("rig_set_freq: error expect %.0f got %.0f\n", 296290000.0, freq);
     }
 
     if (rmode != RIG_MODE_FM || width != rig_passband_narrow(my_rig, RIG_MODE_FM))
@@ -417,7 +432,7 @@ int main(int argc, char *argv[])
 
     if (retcode == RIG_OK)
     {
-        printf("rig_get_vfo: vfo = %i \n", vfo);
+        printf("rig_get_vfo: vfo = %u \n", vfo);
     }
     else
     {
@@ -439,7 +454,6 @@ int main(int argc, char *argv[])
 
     if (retcode == RIG_OK)
     {
-        // cppcheck-suppress *
         printf("rig_get_mode: mode = %s\n", rig_strrmode(rmode));
     }
     else
